/**
 * MEEEK CUSTOM SCRIPTS - TABLE OF CONTENTS
 * 
 * Link Manipulation
 * Copy to clipboard
 * Builder Element Importer
 * Builder Accordion
 * Builder Repeater
 * Builder Media Uploader
 * Colorpicker Clearer
 * Builder Links Drag and Drop
 * Builder Icon Picker
 * Builder Tooltips
 */

(function ($) {
    'use strict';
    
    jQuery(document).ready(function () {


        /**
         * Link Manipulation
         * Set a new query string on the current website url
         * 
         * @param {string}  key     url query string key
         * @param {string}  value   url query string value
         */ 
        function meeeksaas_setget_param(key,value) {
            if (history.pushState) {
                var params = new URLSearchParams(window.location.search);
                params.set(key, value);
                var newUrl = window.location.origin 
                + window.location.pathname 
                + '?' + params.toString();
                window.history.pushState({path:newUrl},'',newUrl);
            }
        }
        function meeeksaas_setlink_param(){
            var post_id = jQuery('#meeeksaas_post_id').val();
            if(post_id){
                meeeksaas_setget_param('links_page',post_id);
            }
        }
        meeeksaas_setlink_param();

        function meeeksaas_current_builder_tab_param(){

            // Default
            if (!meeeksaas_url_has_param('tab')) {
                meeeksaas_setget_param('tab', 'links');
            }

            jQuery( '.meeek-nav-tabs button' ).click( function(){

                var button = jQuery(this);
                var button_attr = button.attr('data-attr');
                var button_attr_val = button.attr('data-attr-val');

                if(button_attr && button_attr_val){
                    meeeksaas_setget_param(button_attr, button_attr_val);
                }
            });
        }
        meeeksaas_current_builder_tab_param();

        /**
         * Check if current link has a given parameter
         * 
         * @param {string}  parameter     url query string key
         */ 
        function meeeksaas_url_has_param(parameter){
            var currentUrl = window.location.href;
            var searchParams = new URLSearchParams(currentUrl);
            if (searchParams.has(parameter)) {
                return true;
            }else{
                return false;
            }
        }

        /**
         * Removes a query string by parameter
         * 
         * @param {string}  parameter     url query string key
         */ 
        function meeeksaas_remove_param_update_url(parameter){
            // Get the current URL
            var currentURL = window.location.href;

            // Split the URL into base URL and parameters
            var baseURL = currentURL.split('?')[0];
            var params = currentURL.split('?')[1];

            if (params) {
              // Split the parameters into an array
              var paramArray = params.split('&');

              // Create an object to store the parameters you want to keep
              var updatedParams = {};

              // Flag to determine if any parameter needs to be removed
              var removeParameter = false;

              // Iterate through the parameters
              $.each(paramArray, function(index, param) {
                var paramParts = param.split('=');
                var paramName = paramParts[0];

                // Check if you want to keep this parameter (e.g., keep all except "removeParam")
                if (paramName !== parameter) {
                  updatedParams[paramName] = paramParts[1];
                } else {
                  removeParameter = true;
                }
              });

              if (removeParameter) {
                // Build the new parameter string
                var newParamString = $.param(updatedParams);

                // Update the URL with the new parameters
                var newURL = baseURL + (newParamString ? '?' + newParamString : '');

                // Replace the current URL with the new one
                window.history.replaceState({}, document.title, newURL);
              }
            }
        }
        meeeksaas_remove_param_update_url("use_template");



        /**
         * Copy to clipboard
         * 
         * @param {string}  text     clipboard copied text
         */ 
        function meeeksaas_copy_to_clipboard(text) {
            var textField = document.createElement('textarea');
            textField.innerText = text;
            document.body.appendChild(textField);
            textField.select();
            textField.focus(); //SET FOCUS on the TEXTFIELD
            document.execCommand('copy');
            textField.remove();
            jQuery('#meeek-copy-links-page').attr('data-bs-title', 'Copied');
        }
        jQuery( '#meeek-copy-links-page' ).click( function(){
            var clipboardText = "";
            clipboardText = jQuery( '.meeek-links-page-url' ).val(); 
            meeeksaas_copy_to_clipboard( clipboardText );
         });


        function meeeksaas_select2_init(){
            jQuery('.meeeksaas-select2').each(function(){
            jQuery(this).select2({
                ajax: {
                    url: meeeksaas_builder_ajax.url,
                    dataType: 'json',
                    delay: 250, // delay in ms while typing when to perform a AJAX search
                    data: function (params) {
                        return {
                            q: params.term, // search query
                            action: 'meeeksaas_import_cpt_post', // AJAX action for admin-ajax.php
                            post_type: jQuery(this).attr('data-post-type'), // AJAX action for admin-ajax.php
                            nonce: meeeksaas_builder_ajax.nonce
                        };
                    },
                    processResults: function( data ) {
                        var options = [];
                        if ( data ) {
         
                            // data is the array of arrays, and each of them contains ID and the Label of the option
                            $.each( data, function( index, text ) { // do not forget that "index" is just auto incremented value
                                options.push( 
                                    { 
                                        id: text[0], 
                                        text: text[1]  
                                    } 
                                );
                            });
         
                        }
                        return {
                            results: options
                        };
                    },
                    cache: true
                },
                minimumInputLength: 3 // the minimum of symbols to input before perform a search
            });
        });
        }
        meeeksaas_select2_init();

        /**
         * Builder Element Importer
         */ 
        jQuery('.meeek-element-importer-btn').click(function(e) {
            e.preventDefault();

            var element_type = jQuery(this).attr('data-element-type');

            // AJAX request
            jQuery.ajax({
                url: meeeksaas_builder_ajax.url,
                type: 'POST',
                data: {
                    action: 'meeeksaas_import_element',
                    element_type: element_type,
                    nonce: meeeksaas_builder_ajax.nonce
                },
                success: function(response) {
                    // Handle the response
                    if(element_type == 'social-icon'){
                        var append_to = jQuery('.meeek-social-icons-group');
                    }else{
                        var append_to = jQuery('.meeek-buttons-group-inner');
                    }
                    append_to.append(response);
                },
                complete: function(response) {
                    // Re-init functions on ajax success
                    meeeksaas_repeater_init();
                    meeeksaas_accordions_init();
                    meeeksaas_media_uploader_field_init();
                    meeeksaas_gallery_media_uploader_field_init();
                    meeeksaas_select2_init();
                    meeeksaas_coloris_colorpicker_field_init();
                },
                error: function(errorThrown) {
                    console.log(errorThrown);
                }
            });
        });


        /**
         * Builder Accordion
         */ 
        function meeeksaas_accordions_init(){
            var myAccordion = new gianniAccordion({
                elements: ".meeek-accordion-card .meeek-accordion-card-inner",
                trigger: "[data-accordion-element-trigger]",
                content: "[data-accordion-element-content]",
            });

            myAccordion.on("elementSelected", (data)=>{
                //
            });
        }
        meeeksaas_accordions_init();


        /**
         * Builder Repeater
         */ 
        function meeeksaas_repeater_init(){
            jQuery('.meeek-buttons-group, .meeek-sm-group').repeater({
                repeaters: [{
                    selector: '.inner-repeater'
                }],
                show: function () {
                    jQuery(this).slideDown();

                    meeeksaas_iconpicker_init();
                    meeeksaas_datetimepicker_init();
                    meeeksaas_togglers();
                    meeeksaas_accordions_init();
                    meeeksaas_media_uploader_field_init();
                    meeeksaas_gallery_media_uploader_field_init();
                    meeeksaas_coloris_colorpicker_field_init();
                },
                hide: function (deleteElement) {
                    // alert confirmation here
                    jQuery(this).slideUp(deleteElement);
                },
                ready: function (setIndexes) {
                    meeeksaas_iconpicker_init();
                    meeeksaas_datetimepicker_init();
                    meeeksaas_togglers();
                    // $dragAndDrop.on('drop', setIndexes);
                },
                // initEmpty: true,
                isFirstItemUndeletable: false
            });
        }
        meeeksaas_repeater_init();


        /**
         * Builder Coloris Colorpicker
         */ 
        function meeeksaas_coloris_colorpicker_field_init(){
            jQuery('.coloris').each(function( e ) {
                // var current_btn = $(this);
                Coloris.setInstance('.coloris', {
                  theme: 'pill',
                  themeMode: 'dark',
                  formatToggle: true,
                  closeButton: true,
                  clearButton: true,
                  swatches: [
                    '#067bc2',
                    '#84bcda',
                    '#80e377',
                    '#ecc30b',
                    '#f37748',
                    '#d56062'
                  ]
                });
            });
        }
        meeeksaas_coloris_colorpicker_field_init();


    jQuery('#upload_images_button').on('click', function (e) {
        e.preventDefault();

        var customUploader = wp.media({
            title: 'Select Images',
            button: {
                text: 'Use these images'
            },
            multiple: true // Set to true to allow multiple files to be selected
        }).on('select', function () {
            var attachments = customUploader.state().get('selection').toJSON();

            jQuery('#image_preview').empty();

            attachments.forEach(function (attachment) {
                var imgHtml = '<div style="margin-bottom: 10px;">' +
                    '<img src="' + attachment.url + '" style="max-width: 150px; margin: 5px;">' +
                    '<input type="text" placeholder="Enter custom link" class="custom-link" data-id="' + attachment.id + '" style="margin-left: 10px; width: 60%;">' +
                    '</div>';
                jQuery('#image_preview').append(imgHtml);
            });

            // Save the selected images and custom links
            jQuery('#save_images_button').remove();
            jQuery('#image_preview').after('<button id="save_images_button" class="button button-primary">Save Images and Links</button>');

            jQuery('#save_images_button').on('click', function () {
                var imagesData = [];

                jQuery('#image_preview .custom-link').each(function () {
                    var imageId = jQuery(this).data('id');
                    var customLink = jQuery(this).val();
                    imagesData.push({
                        id: imageId,
                        link: customLink
                    });
                });

                jQuery.ajax({
                    url: multiImageUpload.ajax_url,
                    type: 'POST',
                    data: {
                        action: 'handle_image_upload',
                        images: imagesData
                    },
                    success: function (response) {
                        console.log('Uploaded images and links:', response.data);
                    }
                });
            });
        }).open();
    });


        /**
         * Builder Media Uploader
         */ 
        function meeeksaas_media_uploader_field_init(){
            jQuery('.meeeksaas_image_preview_box').each(function( e ) {
                var current_btn = $(this);
                current_btn.click(function(e) {
                    e.preventDefault();
                    var image = wp.media({
                        title: 'Upload Image',
                        multiple: false
                    }).open().on('select', function(e) {
                        var uploadedImage = image.state().get('selection').first();
                        var imageSrc = uploadedImage.toJSON().url;
                        var imageID = uploadedImage.toJSON().id;
                        current_btn.parent().find('input.uploader-pid').val(imageID);
                        current_btn.parent().find('input.uploader-img-url').val(imageSrc);
                        current_btn.parent().find('.meeeksaas_image_preview_box').removeClass('upload-now');
                        current_btn.parent().find('.meeeksaas_image_preview_box').html('<img alt="bio" class="img-rounded" width="80" src="' + imageSrc + '">');
                    });
                });
            });
        }
        meeeksaas_media_uploader_field_init();
        jQuery('.media-uploader-clearer').each(function( e ) {
            var current_btn = jQuery(this);
            current_btn.click(function(e) {
                current_btn.parent().parent().find('.meeeksaas_image_preview_box').html('').addClass('upload-now');
                current_btn.parent().parent().find('input').attr('value', '');
            });
        });

        /**
         * Builder Gallery Media Uploader
         */ 
        function meeeksaas_gallery_media_uploader_field_init(){
            jQuery('.meeeksaas_image_preview_box_gallery').each(function( e ) {
                var current_btn = $(this);

                current_btn.click(function(e) {

                    var link_index = current_btn.parent().parent().find('input[name^="meeek-bio-links-group"]').attr('name').match(/\[(\d+)\]/)[1];

                    e.preventDefault();
                    var image = wp.media({
                        title: 'Upload Image',
                        multiple: true
                    }).open().on('select', function(e) {

                        var attachments = image.state().get('selection').toJSON();

                        current_btn.parent().find('.meeeksaas_image_preview_box_gallery_imgs').empty();
                        attachments.forEach(function (attachment) {
                            var imgHtml = '<div class="meeeksaas_media_gallery_fields"><div class="row mb-2"><div class="col-md-2 col-xs-12">' +
                                '<img src="' + attachment.url + '" style="max-width: 70px;">' +
                                '<input type="hidden" name="meeek-bio-links-group['+link_index+'][gallery_media_id_'+attachment.id+']" value="' + attachment.id + '" class="custom-link" data-id="' + attachment.id + '">' +
                                '</div><div class="col-md-5 col-xs-12"><input type="text" style="width: 100%;" name="meeek-bio-links-group['+link_index+'][gallery_media_url_'+attachment.id+']" placeholder="Link" class="custom-link" data-id="' + attachment.id + '">' +
                                '</div><div class="col-md-5 col-xs-12"><input type="text" style="width: 100%;" name="meeek-bio-links-group['+link_index+'][gallery_media_title_'+attachment.id+']" placeholder="Title" class="custom-link" data-id="' + attachment.id + '">' +
                                '</div></div>';
                            current_btn.parent().find('.meeeksaas_image_preview_box_gallery_imgs').append(imgHtml);
                        });
                    });
                });
            });
        }
        meeeksaas_gallery_media_uploader_field_init();
        jQuery('.media-uploader-clearer').each(function( e ) {
            var current_btn = jQuery(this);
            current_btn.click(function(e) {
                current_btn.parent().parent().find('.meeeksaas_image_preview_box_gallery').html('').addClass('upload-now');
                current_btn.parent().parent().find('input').attr('value', '');
            });
        });

        /**
         * Builder Links Drag and Drop
         */ 
        jQuery(".meeek-buttons-group").sortable({
            handle: ".meeek-reorder-btn",
            items: ".accordion-item",
            containment: ".meeek-buttons-group",
            cursor: 'pointer',
            axis: 'y',
            dropOnEmpty: false,
            start: function (e, ui) {
                ui.item.addClass("selected");
            },
            stop: function (e, ui) {
                ui.item.removeClass("selected");
            }
        });

        /**
         * Builder Social Links Drag and Drop
         */ 
        jQuery(".meeek-sm-group").sortable({
            handle: ".meeek-reorder-btn",
            items: ".accordion-item",
            containment: ".meeek-sm-group",
            cursor: 'pointer',
            axis: 'y',
            dropOnEmpty: false,
            start: function (e, ui) {
                ui.item.addClass("selected");
            },
            stop: function (e, ui) {
                ui.item.removeClass("selected");
            }
        });


        /**
         * Builder Icon Picker
         */ 
        function meeeksaas_iconpicker_init(){
            jQuery('[role="iconpicker"]').iconpicker();
        }
        meeeksaas_iconpicker_init();

        /**
         * Builder Datetime Picker
         */ 
        function meeeksaas_datetimepicker_init(){
            var datetime_picker = jQuery(".meeek-datetime-picker input");
            
            if (datetime_picker.length) {
                jQuery('.meeek-datetime-picker input').datetimepicker({dateFormat: "yy-mm-dd HH:ii:ss"});
            }
        }
        meeeksaas_datetimepicker_init();

        /**
         * Builder Schedule toggle
         */ 
        function meeeksaas_togglers(){
            if (jQuery(".meeeksaas-options-toggler").length) {
                jQuery(".meeeksaas-options-toggler").each(function(){
                    var btn = jQuery(this);
                    var checkbox = btn.find('input');
                    var data_id = btn.attr('data-id');
                    var content = checkbox.parent().parent().parent().find( ".meeeksaas-link-toggles-content > div[data-id='"+data_id+"']" );
                    var button = checkbox.parent().find( "label" );

                    if (checkbox.checked) {
                        // content.fadeIn('slow');
                        // button.addClass('btn-toggler-active');
                    }else{
                        // content.fadeOut('slow');
                        // button.removeClass('btn-toggler-active');
                    }
                    
                    checkbox.change(function(){
                        if (this.checked) {
                            content.fadeIn('slow');
                            button.addClass('btn-toggler-active');
                        }else{
                            content.fadeOut('slow');
                            button.removeClass('btn-toggler-active');
                        }
                    });
                });
            }

        }
        meeeksaas_togglers();



        /**
         * Builder Tooltips
         */ 
        var tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'))
        var tooltipList = tooltipTriggerList.map(function (tooltipTriggerEl) {
            return new bootstrap.Tooltip(tooltipTriggerEl)
        })
        function meeeksaas_tooltips(){
            var tooltip_selector = jQuery('[data-bs-toggle="tooltip"]');
            if (tooltip_selector.length) {
                jQuery('[data-toggle="tooltip"]').tooltip();
            }
        }
        meeeksaas_tooltips();

    });

} (jQuery) );