<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

/**
* CPT Registration
*
*/
function meeeksaas_links_cpt() {
    register_post_type(
        'meeek-link',
        array(
            'labels'      => array(
                'name'          => esc_html__('Meeek Bio Links', 'meeeksaas'),
                'menu_name'          => esc_html__('Meeek Bio Links', 'meeeksaas'),
            ),
            'show_ui'             => true, //false
            'show_in_menu'        => true, //false
            'show_in_nav_menus'   => true, //false
            'show_in_admin_bar'   => true, //false
            'menu_icon' => MEEEKSAAS_PLUGIN_URL.'assets/images/menu-icon.svg',
            'public'      => true,
            'has_archive' => true,
            // 'rewrite' => array(
            //     'slug' => '/', 
            //     'with_front' => false
            // ),
            'capabilities' => array(
                'edit_post' => 'manage_options',
                'edit_posts' => 'manage_options',
                'edit_others_posts' => 'manage_options',
                'publish_posts' => 'manage_options',
                'read_post' => 'manage_options',
                'read_private_posts' => 'manage_options',
                'delete_post' => 'manage_options',
                'create_posts' => 'do_not_allow',
            ),
            'supports'           => array( 'title', 'author' ),

        )
    ); 
}
add_action('init', 'meeeksaas_links_cpt');


/**
* Remove CPT Slug from URL
*
*/
add_filter('post_type_link', 'meeeksaas_remove_cpt_slug', 10, 3);
function meeeksaas_remove_cpt_slug($post_link, $post, $leavename) {
    if ( 'meeek-link' != $post->post_type || 'publish' != $post->post_status ) {
        return $post_link;
    }

    return str_replace( '/' . $post->post_type . '/', '/', $post_link );
}


/**
* Parse Request to recognise the removed slug from meeek links
*
* Just removing the slug isn't enough. Right now, you'll get a 404 page because WordPress only expects posts and pages to behave this way.
* These cases are handled in this filter callback, that runs on the 'pre_handle_404' filter.
*
*/
add_filter('pre_get_posts', 'meeeksaas_parse_request');
function meeeksaas_parse_request($query) {

    if ( ! $query->is_main_query() || 2 != count( $query->query ) || ! isset( $query->query['page'] ) ) {
        return;
    }

    if ( ! empty( $query->query['name'] ) ) {
        $query->set( 'post_type', array( 'post', 'meeek-link', 'page' ) );
    }

}



function meeeksaas_cpt_metabox() {
    add_meta_box(
        'meeeksaas_cpt_switch_mode',         // Unique ID
        'Meeek Builder',         // Box title
        'meeeksaas_cpt_metabox_content',  // Callback function
        'meeek-link',             // Post type
        'normal',             // context
        'high'             // priority
    );
}
add_action( 'add_meta_boxes', 'meeeksaas_cpt_metabox' );

function meeeksaas_cpt_metabox_content( $post ) {
    $builder_url = admin_url('admin.php?page=meeek-page-builder&links_page='.get_the_ID().'&action=edit');
    ?>
    <a id="meeeksaas-switch-mode-button" href="<?php echo esc_url($builder_url); ?>" class="button button-primary button-large">
        <span class="meeeksaas-switch-mode">
            <i class="dashicons-before dashicons-edit-page" aria-hidden="true"></i>
            <?php echo esc_html__( 'Edit with Meeek Builder', 'meeeksaas' ); ?>
        </span>
    </a>
    <?php
}

/**
* Handle 404
*
* This method runs after a page is not found in the database, but before a page is returned as a 404.
* These cases are handled in this filter callback, that runs on the 'pre_handle_404' filter.
*
*/
add_filter( 'pre_handle_404',
    function ($value, $query ) {
        return meeeksaas_parse_request_on_error( $value, $query );
    },
10, 2 );
function meeeksaas_parse_request_on_error($value, $query) {

    global $wp_query;

    if ( $value ) {
        return $value;
    }

    if (! $query->is_main_query() || ! empty( $query->posts ) || ! empty( $query->tax_query->table_aliases ) ) {

        return false;

    }

    if ( ! empty($query->query['name']) ) {

        $new_query = new WP_Query( [
            'post_type' => ['meeek-link'],
            'name' => $query->query['name'],
        ] );

    } else {

        $new_query = new WP_Query( [
            'post_type' => ['meeek-link'],
            'name' => strtolower(preg_replace('/[\W\s\/]+/', '-', ltrim($_SERVER['REQUEST_URI'], '/'))),
        ] );

    }

    if ( ! empty( $new_query->posts ) ) {
        $wp_query = $new_query;
    }

    return false;
}


add_filter( 'post_row_actions', 'meeeeksaas_modify_list_row_actions', 10, 2 );
function meeeeksaas_modify_list_row_actions( $actions, $post ) {
    // Check for your post type.
    if ( $post->post_type == "meeek-link" ) {

        // Build your links URL.
        $url = admin_url( 'admin.php?page=meeek-page-builder&links_page=' . $post->ID );
        $edit_link = add_query_arg( array( 'action' => 'edit' ), $url );

        $actions = array_merge($actions, array(
            'edit' => sprintf( '<a href="%1$s">%2$s</a>',
            esc_url( $edit_link ),
            esc_html( esc_html__( 'Edit', 'meeeksaas' ) ) )
        ));
    }

    return $actions;
}


// WP List Table: Column
add_action('manage_meeek-link_posts_custom_column',  'meeeksaas_custom_show_columns');
function meeeksaas_custom_show_columns($name) {
    global $post;
    switch ($name) {
        case 'meeeksaas_pageviews':
            
            $edit_link = get_admin_url().'admin.php?page=meeek-page-builder&links_page='.$post->ID.'&action=edit&tab=analytics';
            echo meeeksaas_get_alltime_pageviews($post->ID).' <a href="'.esc_url($edit_link).'"><span class="dashicons dashicons-chart-area"></span></a>';
        break;
    }
}

add_filter('manage_edit-meeek-link_columns', 'meeeksaas_custom_columns');
function meeeksaas_custom_columns($columns) {
    $columns['meeeksaas_pageviews'] = __('Views', 'meeeksaas');
    return $columns;
}