<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

/** 
 * Supported Field Types:
 * 
 * input: text, url, number
 * colorpicker
 * textarea
 * alignment_groups
*/


/** 
 * Fieldtype: Input
 * 
 * @param type: string (text/url/number)
 * @param name: input name attribute
 * @param value: input value attribute
 * @param label: label text
 * @param id: id of the input + for of the label
 * @param floating: with/without the bootstrap's floating effect of the placeholder
 * @param div_holder_class:     string      - an extra html class 
*/
function meeeksaas_input($type = '', $name = '', $value = '', $label = '', $id = '', $floating = true, $div_holder_class = ''){
    if ($floating) {
        $holder_class = "form-floating";
    }else{
        $holder_class = "";
    } ?>

    <div class="<?php echo esc_attr($holder_class); ?> mb-3 <?php echo esc_attr($div_holder_class); ?>">
        <?php if(!$floating){ ?>
            <label for="<?php echo esc_attr($id); ?>"><?php echo esc_html($label); ?></label>
        <?php } ?>

        <input type="<?php echo esc_attr($type); ?>" class="form-control" name="<?php echo esc_attr($name); ?>" id="<?php echo esc_attr($id); ?>" placeholder="<?php esc_attr_e($label); ?>" value="<?php echo esc_attr($value); ?>" />
        
        <?php if($floating){ ?>
            <label for="<?php echo esc_attr($id); ?>"><?php echo esc_html($label); ?></label>
        <?php } ?>
    </div>

    <?php 
}

/** 
 * Fieldtype: Input Number
 * 
 * @param name: input name attribute
 * @param value: input value attribute
 * @param label: label text
 * @param id: id of the input + for of the label
 * @param floating: with/without the bootstrap's floating effect of the placeholder
*/
function meeeksaas_input_number($name = '', $value = '', $label = '', $placeholder = '', $id = '', $floating = true){
    if ($floating) {
        $holder_class = "form-floating";
    }else{
        $holder_class = "";
    } ?>
 
    <div class="<?php echo esc_attr($holder_class); ?> mb-3">
        <?php if(!$floating){ ?>
            <label for="<?php echo esc_attr($id); ?>"><?php echo esc_html($label); ?></label>
        <?php } ?>

        <input type="number" class="form-control" name="<?php echo esc_attr($name); ?>" id="<?php echo esc_attr($id); ?>" placeholder="<?php esc_attr_e($placeholder); ?>" value="<?php echo esc_attr($value); ?>" />
        
        <?php if($floating){ ?>
            <label for="<?php echo esc_attr($id); ?>"><?php echo esc_html($label); ?></label>
        <?php } ?>
    </div>

    <?php 
}

/** 
 * Fieldtype: Icon Picker
 * 
 * @param name:                 string      - input name attribute
 * @param value:                string      - input value attribute
 * @param label:                string      - label text
 * @param placeholder:          string      - input placeholder attribute
 * @param id:                   string      - id of the input + for of the label
*/
function meeeksaas_iconpicker($name = '', $value = '', $label = '', $placeholder = '', $id = ''){
    ?>

    <div class="input-group mb-3 relative meeek-icon-picker">
        <span class="input-group-text" id="<?php echo esc_attr($id); ?>"><?php echo esc_html($label); ?></span>
        <input type="text" name="<?php echo esc_attr($name); ?>" value="<?php echo esc_attr($value); ?>" placeholder="<?php echo esc_attr($placeholder); ?>" autocomplete="off" class="form-control iconpicker" aria-label="<?php echo esc_attr($placeholder); ?>" aria-describedby="<?php echo esc_attr($id); ?>" data-iconset="fontawesome5" role="iconpicker" />
    </div>

    <?php 
}

/** 
 * Fieldtype: Colorpicker
 * 
 * @param name:                 string      - input name attribute
 * @param value:                string      - input value attribute
 * @param label:                string      - label text
 * @param id:                   integer     - id of the input + for of the label
 * @param div_holder_class:     string      - an extra html class 
*/
function meeeksaas_colorpicker($name = '', $value = '', $label = '', $id = '', $div_holder_class = ''){
    $id = uniqid($id);
    ?>
    <div class="form-group mb-3 relative <?php echo esc_attr($div_holder_class); ?>">
        <label for="<?php echo esc_attr($id); ?>"><?php echo esc_html($label); ?></label>
        <div class="clearfix"></div>
        <input autocomplete="off" type="text" data-coloris name="<?php echo esc_attr($name); ?>" id="<?php echo esc_attr($id); ?>" value="<?php echo esc_attr($value); ?>" class="coloris form-control form-control-color" />
        <?php //do_action('meeeksaas_builder_field_icons_color'); ?>
    </div>
    <?php 
}

/** 
 * Fieldtype: Textarea
 * 
 * @param name: textarea name attribute
 * @param content: textarea content/value
 * @param label: label text
 * @param id: id of the textarea + for of the label
 * @param floating: with/without the bootstrap's floating effect of the placeholder
*/
function meeeksaas_textarea($name = '', $content = '', $label = '', $id = '', $floating = true){
    if ($floating) {
        $holder_class = "form-floating";
    }else{
        $holder_class = "";
    } ?>
    <div class="<?php echo esc_attr($holder_class); ?> mb-3">
        <textarea rows="4" type="url" class="form-control" name="<?php echo esc_attr($name); ?>" id="<?php echo esc_attr($id); ?>" placeholder="<?php echo esc_attr($label); ?>"><?php echo esc_attr($content); ?></textarea>
        <label for="<?php echo esc_attr($id); ?>"><?php echo esc_html($label); ?></label>
    </div>

    <?php 
}

/** 
 * Fieldtype: Alignment group
 * 
 * @param name: radio name attribute
 * @param value: radio checked value
 * @param label: label text
*/
function meeeksaas_alignment_group($name = '', $value = '', $label = ''){
    $id_left = uniqid('left_');
    $id_center = uniqid('center_');
    $id_right = uniqid('right_');
    ?>

    <div class="form-group mb-3">
        <label><?php echo esc_attr($label); ?></label>
        <div class="clearfix"></div>
        <div class="btn-group" role="group">
          <input <?php if ($value == 'left'){echo 'checked'; } ?> type="radio" class="btn-check" name="<?php echo esc_attr($name); ?>" value="left" id="<?php echo esc_attr($id_left); ?>" />
          <label class="btn btn-outline-secondary me-2" for="<?php echo esc_attr($id_left); ?>"><i class="fas fa-align-left"></i></label>

          <input <?php if ($value == 'center'){echo 'checked'; } ?> type="radio" class="btn-check" name="<?php echo esc_attr($name); ?>" value="center" id="<?php echo esc_attr($id_center); ?>" />
          <label class="btn btn-outline-secondary me-2" for="<?php echo esc_attr($id_center); ?>"><i class="fas fa-align-center"></i></label>

          <input <?php if ($value == 'right'){echo 'checked'; } ?> type="radio" class="btn-check" name="<?php echo esc_attr($name); ?>" value="right" id="<?php echo esc_attr($id_right); ?>" />
          <label class="btn btn-outline-secondary me-2" for="<?php echo esc_attr($id_right); ?>"><i class="fas fa-align-right"></i></label>
        </div>
    </div>

    <?php 
}

/** 
 * Fieldtype: Radius group
 * 
 * @param name: radio name attribute
 * @param value: radio checked value
 * @param label: label text
*/
function meeeksaas_radius_group($name = '', $value = '', $label = ''){
    $id_circle = uniqid('circle_');
    $id_round = uniqid('round_');
    $id_square = uniqid('square_');
    ?>

    <div class="form-group mb-3">
        <label><?php echo esc_attr($label); ?></label>
        <div class="clearfix"></div>
        <div class="btn-group" role="group">
          <input <?php if ($value == 'rounded-circle'){echo 'checked'; } ?> type="radio" class="btn-check" name="<?php echo esc_attr($name); ?>" value="rounded-circle" id="<?php echo esc_attr($id_circle); ?>" autocomplete="off">
          <label class="btn btn-outline-secondary me-2" for="<?php echo esc_attr($id_circle); ?>"><i class="fas fa-circle"></i> <?php esc_html_e('Circle', 'meeeksaas'); ?></label>

          <input <?php if ($value == 'rounded'){echo 'checked'; } ?> type="radio" class="btn-check" name="<?php echo esc_attr($name); ?>" value="rounded" id="<?php echo esc_attr($id_round); ?>" autocomplete="off">
          <label class="btn btn-outline-secondary me-2" for="<?php echo esc_attr($id_round); ?>"><i class="fas fa-square"></i> <?php esc_html_e('Rounded', 'meeeksaas'); ?></label>

          <input <?php if ($value == 'square'){echo 'checked'; } ?> type="radio" class="btn-check" name="<?php echo esc_attr($name); ?>" value="square" id="<?php echo esc_attr($id_square); ?>" autocomplete="off">
          <label class="btn btn-outline-secondary me-2" for="<?php echo esc_attr($id_square); ?>"><i class="fas fa-square-full"></i> <?php esc_html_e('Square', 'meeeksaas'); ?></label>
        </div>
    </div>

    <?php 
}

/** 
 * Fieldtype: Padding group
 * 
 * @param name: radio name attribute
 * @param value: radio checked value
 * @param label: label text
*/
function meeeksaas_padding_group($name = '', $heading = '', $p_left = '', $p_right = '', $p_top = '', $p_bottom = ''){
    ?>

    <div class="form-group mb-3  row relative meeek-padding-group">
        <div class="col-sm-12"><?php echo esc_html($heading); ?></div>
        <div class="col-sm-3">
            <div class="input-group">
                <div class="input-group-text"><?php echo esc_html__('Left', 'meeeksaas'); ?></div>
                <input type="number" name="<?php echo esc_attr($name); ?>[]" value="<?php echo esc_attr($p_left); ?>" class="form-control" min="0" max="200" />
            </div>
        </div>
        <div class="col-sm-3">
            <div class="input-group">
                <div class="input-group-text"><?php echo esc_html__('Right', 'meeeksaas'); ?></div>
                <input type="number" name="<?php echo esc_attr($name); ?>[]" value="<?php echo esc_attr($p_right); ?>" class="form-control" min="0" max="200" />
            </div>
        </div>
        <div class="col-sm-3">
            <div class="input-group">
                <div class="input-group-text"><?php echo esc_html__('Top', 'meeeksaas'); ?></div>
                <input type="number" name="<?php echo esc_attr($name); ?>[]" value="<?php echo esc_attr($p_top); ?>" class="form-control" min="0" max="200" />
            </div>
        </div>
        <div class="col-sm-3">
            <div class="input-group">
                <div class="input-group-text"><?php echo esc_html__('Bottom', 'meeeksaas'); ?></div>
                <input type="number" name="<?php echo esc_attr($name); ?>[]" value="<?php echo esc_attr($p_bottom); ?>" class="form-control" min="0" max="200" />
            </div>
        </div>
    </div>

    <?php 
}


/** 
 * Fieldtype: Media Uploader
 * 
 * @param name: radio name attribute
 * @param value: radio checked value
 * @param label: label text
*/
function meeeksaas_media_uploader($name = '', $attachment_id = '', $attachment_url = '', $label = '', $benefit = ''){

    $photo_image = '';
    if ($attachment_id) {
        if (wp_get_attachment_image_url($attachment_id)) {
            $attachment_url = wp_get_attachment_image_url($attachment_id, 'thumbnail');
        }
        $photo_image = '<img alt="bio" class="img-rounded" width="80" src="'.esc_url($attachment_url).'" />';
        $photo_status = true;
    }else{
        $attachment_id = '';
        $photo_status = false;
    } 

    $this_benefit = $benefit;

    ?>

    <div class="meeek-image-uploader-box mb-3 relative">
        <label><?php echo esc_html($label); ?></label>
        <div class="clearfix"></div>
        <input class="uploader-pid" type="hidden" name="<?php echo esc_attr($name); ?>" value="<?php echo esc_attr($attachment_id); ?>">
        <input class="uploader-img-url" type="hidden" name="<?php echo esc_attr($name); ?>_url" value="<?php echo esc_url($attachment_url); ?>">
        <div class="meeeksaas_image_preview_box <?php if(!$photo_status){ echo 'upload-now'; } ?>"><?php echo $photo_image; ?></div>
        <div class="relative inline-block">
            <span class="media-uploader-clearer far fa-trash-alt"></span>
        </div>
        <?php do_action('meeeksaas_builder_'.$benefit); ?>
    </div>
    <?php 
}


/** 
 * Fieldtype: Media Uploader
 * 
 * @param name: radio name attribute
 * @param id: radio checked value
 * @param label: label text
 * @param status: radio checked value
*/
function meeeksaas_checkbox($name = '', $id = '', $label = '', $status = '', $benefit = ''){
    $id_checkbox = uniqid($id);
    ?>
    <div class="mb-3 relative pb-3 pt-3 meeeksaas-checkbox-field">
        <input <?php if($status == 'on'){ echo 'checked'; } ?> name="<?php echo esc_attr($name); ?>" id="<?php echo esc_attr($id_checkbox); ?>" class="form-check-input mt-0" type="checkbox" />
        <label for="<?php echo esc_attr($id_checkbox); ?>"><?php echo esc_html($label); ?></label>
        <?php 
        if($benefit){
            do_action('meeeksaas_builder_'.$benefit);
        } ?>
    </div>
    <?php 
}



/** 
 * Fieldtype: Media Uploader
 * 
 * @param name: radio name attribute
 * @param id: radio checked value
 * @param label: label text
 * @param selected_option: array current selected options
 * @param benefit: plan benefit needed to unlock this option
*/
function meeeksaas_ajax_select2($name = '', $id = '', $label = '', $selected_options = array(), $post_type = '', $benefit = ''){

    $pids = $selected_options;
    ?>
    <div class="mb-3 relative">
        <label for="<?php echo esc_attr($id); ?>"><?php echo esc_attr($label); ?></label>
        <select data-post-type="<?php echo esc_attr($post_type); ?>" class="meeeksaas-select2 form-control" multiple="multiple" name="<?php echo esc_attr($name); ?>" id="<?php echo esc_attr($id); ?>">
            <?php if($pids){ ?>
                <?php foreach ($pids as $pid) { ?>
                    <option selected value="<?php echo esc_attr($pid); ?>"><?php echo esc_html(get_the_title($pid)); ?></option>
                <?php } ?>
            <?php } ?>
        </select>
        <?php do_action('meeeksaas_builder_'.$benefit); ?>
    </div>
    <?php 
}

/** 
 * Fieldtype: Simple Select
 * 
 * @param name: radio name attribute
 * @param id: radio checked value
 * @param label: label text
 * @param selected_option: array current selected options
*/
function meeeksaas_select($name = '', $id = '', $label = '', $selected_option = ''){

    $options = array(
        'after' => __('After Bio Links', 'meeeksaas'),
        'before' => __('Before Bio Links', 'meeeksaas'),
    );
    ?>
    <div class="mb-3 relative">
        <label for="<?php echo esc_attr($id); ?>"><?php echo esc_attr($label); ?></label>
        <select class="meeeksaas-simple-select form-control" name="<?php echo esc_attr($name); ?>" id="<?php echo esc_attr($id); ?>">
            <?php if($options){ ?>
                <?php foreach ($options as $key => $option) { ?>
                    <option <?php if($selected_option == $key){echo 'selected';} ?> value="<?php echo esc_attr($key); ?>"><?php echo esc_html($option); ?></option>
                <?php } ?>
            <?php } ?>
        </select>
    </div>
    <?php 
}


/** 
 * Fieldtype: Media Uploader
 * 
 * @param name: radio name attribute
 * @param id: radio checked value
 * @param label: label text
 * @param selected_option: array current selected options
 * @param benefit: plan benefit needed to unlock this option
*/
function meeeksaas_timezone_select($name = '', $selected_option = '', $label = '', $id = '', $class = ''){
    $timezones = array(
        'Pacific/Midway'       => "(GMT-11:00) Midway Island",
        'US/Samoa'             => "(GMT-11:00) Samoa",
        'US/Hawaii'            => "(GMT-10:00) Hawaii",
        'US/Alaska'            => "(GMT-09:00) Alaska",
        'US/Pacific'           => "(GMT-08:00) Pacific Time (US &amp; Canada)",
        'America/Tijuana'      => "(GMT-08:00) Tijuana",
        'US/Arizona'           => "(GMT-07:00) Arizona",
        'US/Mountain'          => "(GMT-07:00) Mountain Time (US &amp; Canada)",
        'America/Chihuahua'    => "(GMT-07:00) Chihuahua",
        'America/Mazatlan'     => "(GMT-07:00) Mazatlan",
        'America/Mexico_City'  => "(GMT-06:00) Mexico City",
        'America/Monterrey'    => "(GMT-06:00) Monterrey",
        'Canada/Saskatchewan'  => "(GMT-06:00) Saskatchewan",
        'US/Central'           => "(GMT-06:00) Central Time (US &amp; Canada)",
        'US/Eastern'           => "(GMT-05:00) Eastern Time (US &amp; Canada)",
        'US/East-Indiana'      => "(GMT-05:00) Indiana (East)",
        'America/Bogota'       => "(GMT-05:00) Bogota",
        'America/Lima'         => "(GMT-05:00) Lima",
        'America/Caracas'      => "(GMT-04:30) Caracas",
        'Canada/Atlantic'      => "(GMT-04:00) Atlantic Time (Canada)",
        'America/La_Paz'       => "(GMT-04:00) La Paz",
        'America/Santiago'     => "(GMT-04:00) Santiago",
        'Canada/Newfoundland'  => "(GMT-03:30) Newfoundland",
        'America/Buenos_Aires' => "(GMT-03:00) Buenos Aires",
        'Greenland'            => "(GMT-03:00) Greenland",
        'Atlantic/Stanley'     => "(GMT-02:00) Stanley",
        'Atlantic/Azores'      => "(GMT-01:00) Azores",
        'Atlantic/Cape_Verde'  => "(GMT-01:00) Cape Verde Is.",
        'Africa/Casablanca'    => "(GMT) Casablanca",
        'Europe/Dublin'        => "(GMT) Dublin",
        'Europe/Lisbon'        => "(GMT) Lisbon",
        'Europe/London'        => "(GMT) London",
        'Africa/Monrovia'      => "(GMT) Monrovia",
        'Europe/Amsterdam'     => "(GMT+01:00) Amsterdam",
        'Europe/Belgrade'      => "(GMT+01:00) Belgrade",
        'Europe/Berlin'        => "(GMT+01:00) Berlin",
        'Europe/Bratislava'    => "(GMT+01:00) Bratislava",
        'Europe/Brussels'      => "(GMT+01:00) Brussels",
        'Europe/Budapest'      => "(GMT+01:00) Budapest",
        'Europe/Copenhagen'    => "(GMT+01:00) Copenhagen",
        'Europe/Ljubljana'     => "(GMT+01:00) Ljubljana",
        'Europe/Madrid'        => "(GMT+01:00) Madrid",
        'Europe/Paris'         => "(GMT+01:00) Paris",
        'Europe/Prague'        => "(GMT+01:00) Prague",
        'Europe/Rome'          => "(GMT+01:00) Rome",
        'Europe/Sarajevo'      => "(GMT+01:00) Sarajevo",
        'Europe/Skopje'        => "(GMT+01:00) Skopje",
        'Europe/Stockholm'     => "(GMT+01:00) Stockholm",
        'Europe/Vienna'        => "(GMT+01:00) Vienna",
        'Europe/Warsaw'        => "(GMT+01:00) Warsaw",
        'Europe/Zagreb'        => "(GMT+01:00) Zagreb",
        'Europe/Athens'        => "(GMT+02:00) Athens",
        'Europe/Bucharest'     => "(GMT+02:00) Bucharest",
        'Africa/Cairo'         => "(GMT+02:00) Cairo",
        'Africa/Harare'        => "(GMT+02:00) Harare",
        'Europe/Helsinki'      => "(GMT+02:00) Helsinki",
        'Europe/Istanbul'      => "(GMT+02:00) Istanbul",
        'Asia/Jerusalem'       => "(GMT+02:00) Jerusalem",
        'Europe/Kiev'          => "(GMT+02:00) Kyiv",
        'Europe/Minsk'         => "(GMT+02:00) Minsk",
        'Europe/Riga'          => "(GMT+02:00) Riga",
        'Europe/Sofia'         => "(GMT+02:00) Sofia",
        'Europe/Tallinn'       => "(GMT+02:00) Tallinn",
        'Europe/Vilnius'       => "(GMT+02:00) Vilnius",
        'Asia/Baghdad'         => "(GMT+03:00) Baghdad",
        'Asia/Kuwait'          => "(GMT+03:00) Kuwait",
        'Africa/Nairobi'       => "(GMT+03:00) Nairobi",
        'Asia/Riyadh'          => "(GMT+03:00) Riyadh",
        'Asia/Tehran'          => "(GMT+03:30) Tehran",
        'Europe/Moscow'        => "(GMT+04:00) Moscow",
        'Asia/Baku'            => "(GMT+04:00) Baku",
        'Europe/Volgograd'     => "(GMT+04:00) Volgograd",
        'Asia/Muscat'          => "(GMT+04:00) Muscat",
        'Asia/Tbilisi'         => "(GMT+04:00) Tbilisi",
        'Asia/Yerevan'         => "(GMT+04:00) Yerevan",
        'Asia/Kabul'           => "(GMT+04:30) Kabul",
        'Asia/Karachi'         => "(GMT+05:00) Karachi",
        'Asia/Tashkent'        => "(GMT+05:00) Tashkent",
        'Asia/Kolkata'         => "(GMT+05:30) Kolkata",
        'Asia/Kathmandu'       => "(GMT+05:45) Kathmandu",
        'Asia/Yekaterinburg'   => "(GMT+06:00) Ekaterinburg",
        'Asia/Almaty'          => "(GMT+06:00) Almaty",
        'Asia/Dhaka'           => "(GMT+06:00) Dhaka",
        'Asia/Novosibirsk'     => "(GMT+07:00) Novosibirsk",
        'Asia/Bangkok'         => "(GMT+07:00) Bangkok",
        'Asia/Jakarta'         => "(GMT+07:00) Jakarta",
        'Asia/Krasnoyarsk'     => "(GMT+08:00) Krasnoyarsk",
        'Asia/Chongqing'       => "(GMT+08:00) Chongqing",
        'Asia/Hong_Kong'       => "(GMT+08:00) Hong Kong",
        'Asia/Kuala_Lumpur'    => "(GMT+08:00) Kuala Lumpur",
        'Australia/Perth'      => "(GMT+08:00) Perth",
        'Asia/Singapore'       => "(GMT+08:00) Singapore",
        'Asia/Taipei'          => "(GMT+08:00) Taipei",
        'Asia/Ulaanbaatar'     => "(GMT+08:00) Ulaan Bataar",
        'Asia/Urumqi'          => "(GMT+08:00) Urumqi",
        'Asia/Irkutsk'         => "(GMT+09:00) Irkutsk",
        'Asia/Seoul'           => "(GMT+09:00) Seoul",
        'Asia/Tokyo'           => "(GMT+09:00) Tokyo",
        'Australia/Adelaide'   => "(GMT+09:30) Adelaide",
        'Australia/Darwin'     => "(GMT+09:30) Darwin",
        'Asia/Yakutsk'         => "(GMT+10:00) Yakutsk",
        'Australia/Brisbane'   => "(GMT+10:00) Brisbane",
        'Australia/Canberra'   => "(GMT+10:00) Canberra",
        'Pacific/Guam'         => "(GMT+10:00) Guam",
        'Australia/Hobart'     => "(GMT+10:00) Hobart",
        'Australia/Melbourne'  => "(GMT+10:00) Melbourne",
        'Pacific/Port_Moresby' => "(GMT+10:00) Port Moresby",
        'Australia/Sydney'     => "(GMT+10:00) Sydney",
        'Asia/Vladivostok'     => "(GMT+11:00) Vladivostok",
        'Asia/Magadan'         => "(GMT+12:00) Magadan",
        'Pacific/Auckland'     => "(GMT+12:00) Auckland",
        'Pacific/Fiji'         => "(GMT+12:00) Fiji",
    );
    if (empty($selected_option)) {
        $selected_option = 'Europe/London';
    }
    ?>
    <div class="mb-3 relative <?php echo esc_attr($class); ?>">
        <label for="<?php echo esc_attr($id); ?>"><?php echo esc_html($label); ?></label>
        <select class="form-select" name="<?php echo esc_attr($name); ?>" id="<?php echo esc_attr($id); ?>">
            <?php foreach ($timezones as $key => $timezone) { ?>
                <option <?php if($selected_option == $key){echo "selected";}else{echo "";} ?> value="<?php echo esc_attr($key); ?>"><?php echo esc_html($timezone); ?></option>
            <?php } ?>
        </select>
    </div>
    <?php 
}



/** 
 * Fieldtype: Font Family
 * 
 * @param name:                 string      - input name attribute
 * @param value:                string      - input value attribute
 * @param label:                string      - label text
 * @param id:                   integer     - id of the input + for of the label
 * @param div_holder_class:     string      - an extra html class 
*/
if (!function_exists('meeeksaas_fonts_multiselect')) {
    function meeeksaas_fonts_multiselect($name = '', $value = '', $label = '', $id = '', $cols = ''){
        $fonts = meeeksaas_googlefonts();
        ?>
        <div class="form-group mb-3 <?php echo esc_attr($cols); ?>">
            <label for="<?php echo esc_attr($id); ?>"><?php echo esc_html($label); ?></label>
            <select id="<?php echo esc_attr($name); ?>" name="<?php echo esc_attr($name); ?>" class="form-control"><option value=""><?php echo esc_html__('Select a font', 'meeeksaas'); ?></option><?php 
                if($fonts) { 
                    foreach($fonts as $key => $font) { ?><option value="<?php echo $key; ?>"<?php if ( $value == $key  ) echo ' selected="selected"'; ?>><?php echo esc_html($font); ?></option><?php 
                    }
                } ?>
            </select>
        </div>
        <?php 
    }
}