<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}


require_once('module-overrides.php');


function meeeksaas_get_restricted_elements(){
    $settings = get_option('mt-saas-settings');
    $restricted_elements = array();
    if ($settings) {
        $disable_elements = ((array_key_exists('meeeksaas_disable_elements', $settings))?$settings['meeeksaas_disable_elements']:"off");
        $elements_list = ((array_key_exists('meeeksaas_elements_list', $settings))?$settings['meeeksaas_elements_list']:array());
        if ($disable_elements == 'on') {
            $restricted_elements = $elements_list;
        }
    }

    return $restricted_elements;
}


/**
* Check if an element is disabled or active
* @param $element_id :     string (*Element ID)
*/
function meeeksaas_is_element_restricted($element_id = ''){
    $restricted_elements = meeeksaas_get_restricted_elements();
    if(in_array($element_id, $restricted_elements)){
        return true;
    }else{
        return false;
    }
}



/* search */
if (!function_exists('meeeksaas_page_availablity_ajax_fetch')) {
    add_action( 'admin_footer', 'meeeksaas_page_availablity_ajax_fetch' );
    add_action( 'wp_footer', 'meeeksaas_page_availablity_ajax_fetch' );
    function meeeksaas_page_availablity_ajax_fetch() { ?>
        <script type="text/javascript">
                jQuery(document).ready(function ($) {
                    jQuery('.seo_page_slug').on('input', function () {
                        var seoPageSlug = jQuery(this).val();

                        // AJAX request to check if the post type slug exists
                        jQuery.ajax({
                            type: 'POST',
                            url: '<?php echo admin_url('admin-ajax.php'); ?>',
                            data: {
                                action: 'meeeksaas_page_availablity',
                                seo_page_slug: seoPageSlug,
                                nonce: '<?php echo wp_create_nonce('meeeksaas_slug_availablity'); ?>',
                            },
                            success: function (response) {
                                // Display the response message
                                jQuery('.meeeksaas-page-slug-status').html(response);
                            },
                            error: function (response) {
                                // Display the response message
                                // console.log(response);
                            },
                        });
                    });
                });
        </script>
    <?php
    }
}


function meeeksaas_page_availablity_callback() {

    // Verify the nonce
    if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'meeeksaas_slug_availablity')) {
        die('Permission check failed');
    }

    $slug = sanitize_text_field($_POST['seo_page_slug']);

    // Check if a post with the given slug exists
    $post = get_page_by_path($slug, OBJECT, 'meeek-link');

    if ($post) {
        $response = '<span class="meeeksaas-warning meeeksaas-notice mb-2 mt-2"><i class="fas fa-exclamation-circle"></i> '.esc_html__('This link is currently in use. Kindly choose an alternative.', 'meeeksaas').'</span>';
    } else {
        $response = '<span class="meeeksaas-success meeeksaas-notice mb-2 mt-2"><i class="fas fa-check-circle"></i> '.esc_html__('Congratulations! This link is available. Please proceed to claim it promptly.', 'meeeksaas').'</span>';
    }

    echo wp_kses_post($response, 'notice');
    wp_die();
}
add_action('wp_ajax_meeeksaas_page_availablity', 'meeeksaas_page_availablity_callback');
add_action('wp_ajax_nopriv_meeeksaas_page_availablity', 'meeeksaas_page_availablity_callback');



add_action( 'wp_ajax_meeeksaas_import_cpt_post', 'meeeksaas_get_cpt_post_ajax_callback' ); // wp_ajax_{action}
function meeeksaas_get_cpt_post_ajax_callback(){
 
    check_ajax_referer('meeek_import_element', 'nonce');
 
    // we will pass post IDs and titles to this array
    $return = array();
    $post_type = $_GET['post_type'];
 
    // you can use WP_Query, query_posts() or get_posts() here - it doesn't matter
    $search_results = new WP_Query( array( 
        's'=> $_GET['q'], // the search query
        'post_status' => 'publish', // if you don't want drafts to be returned
        'post_type' => esc_attr($post_type), // if you don't want drafts to be returned
        'ignore_sticky_posts' => 1,
        'posts_per_page' => 50 // how much to show at once
    ) );
    if( $search_results->have_posts() ) :
        while( $search_results->have_posts() ) : $search_results->the_post();   
            
            if ($post_type == 'product') {
                $_product = wc_get_product( $search_results->post->ID );

                if( $_product->is_type( 'simple' ) ) {
                    $title = ( mb_strlen( $search_results->post->post_title ) > 200 ) ? mb_substr( $search_results->post->post_title, 0, 199 ) . '...' : $search_results->post->post_title;
                    $return[] = array( $search_results->post->ID, $title ); // array( Post ID, Post Title )
                }elseif($_product->is_type( 'variable' )){
                    $product = wc_get_product($search_results->post->ID);
                    $variations = $product->get_available_variations();
                    foreach ($variations as $key => $variation) 
                    {
                        $variation_product = wc_get_product($variation['variation_id']);

                        $title = ( mb_strlen( $search_results->post->post_title ) > 200 ) ? mb_substr( $search_results->post->post_title, 0, 199 ) . '...' : $search_results->post->post_title;
                        // $return[] = array( $variation['variation_id'], strip_tags($variation_product->get_formatted_name() ?? '') ); 
                        $return[] = array( $variation['variation_id'], strip_tags($variation_product->get_formatted_name() ?? '') ?: '' );
                    }
                }
            }else{
                $title = ( mb_strlen( $search_results->post->post_title ) > 200 ) ? mb_substr( $search_results->post->post_title, 0, 199 ) . '...' : $search_results->post->post_title;
                $return[] = array( $search_results->post->ID, $title ); // array( Post ID, Post Title )
            }

        endwhile;
        wp_reset_postdata();
    endif;
    echo json_encode( $return );
    die;
}



add_action( 'template_redirect', 'meeeksaas_frontend_social_media_block_reorder' );
function meeeksaas_frontend_social_media_block_reorder(){
    if (is_singular('meeek-link')) {
        $meeek_configuration = get_post_meta( get_the_ID(), 'meeek_configuration', true );
        if ($meeek_configuration) {
            $icons_position = ((array_key_exists('icons_position', $meeek_configuration))?$meeek_configuration['icons_position']:"after");
            if ($icons_position == 'before') {
                remove_action('meeeksaas_page_content', 'meeeksaas_frontend_social_media_block', 30, 2);
                add_action('meeeksaas_page_content', 'meeeksaas_frontend_social_media_block', 10, 2);
            }
        }
    }
}
/**
* Parse Social Link Icons Block
* @param $post_id :     integer (*Meeek Post ID)
* 
*/
add_action('meeeksaas_page_content', 'meeeksaas_frontend_social_media_block', 30, 2);
function meeeksaas_frontend_social_media_block($post_id) {
    if (is_singular('meeek-link')) {
        $configuration = get_post_meta( $post_id, 'meeek_configuration', true );

        if ($configuration) {
            $icons_status = ((array_key_exists('icons_status', $configuration))?$configuration['icons_status']:"");
            $color = ((array_key_exists('meeeksaas_icons_color', $configuration))?$configuration['meeeksaas_icons_color']:"");
            $icons_alignment = ((array_key_exists('icons_alignment', $configuration))?$configuration['icons_alignment']:"");
            $sm_links = ((array_key_exists('meeek-sm-links-group', $configuration))?$configuration['meeek-sm-links-group']:array());

            $sm_links_processed = array();
            foreach($sm_links as $sm_link){
                $sm_links_processed[] = array(
                    'icon' => array(
                        'value' => $sm_link['icon'],
                        'library' => 'fa-solid',
                    ),
                    'link' => array(
                        'url' => $sm_link['link'],
                    )
                );

            }

            $settings = get_option('mt-saas-settings');
            ?>

            <?php if($icons_status == 'on'){ ?>
                <div class="meeek-social-media-links-alignment" style="text-align:<?php echo esc_attr($icons_alignment); ?>;">
                    <div class="meeek-social-media-links-container">
                    
                        <?php 
                        do_action('meeeksaas_before_social_links');

                        if ($settings) {
                            $home_link_status = ((array_key_exists('meeeksaas_home_link', $settings))?$settings['meeeksaas_home_link']:"off");
                            if ($home_link_status == 'on') { ?>
                                <div class="meeek-social-media-links-inner-container meeeksaas-sm-home-link">
                                    <a class="meeek-icon-link" href="<?php echo esc_url(get_site_url()); ?>" style="color:<?php echo esc_attr($color); ?>;">
                                        <i class="fas fa-home"></i>
                                    </a>
                                </div>
                            <?php }
                        }

                        do_action('meeeksaas_before_home_social_link');

                        if ($sm_links_processed) { ?>
                            <?php foreach ( $sm_links_processed as $item ) {
                                $link = $item['link']['url']; ?>   
                                <div class="meeek-social-media-links-inner-container">
                                    <a class="meeek-icon-link" target="_blank" href="<?php echo esc_url($link); ?>" style="color:<?php echo esc_attr($color); ?>;">
                                    <i class="<?php echo esc_attr($item['icon']['value']); ?>"></i>
                                    </a>
                                </div>
                            <?php } 
                        } 

                        $configuration = get_post_meta( get_the_ID(), 'meeek_configuration', true );
                        if ($configuration) {
                            $mailto_sm_link = ((array_key_exists('mailto_sm_link', $configuration))?$configuration['mailto_sm_link']:"");
                            $author_id = get_post_field('post_author', get_the_ID());
                            $author_email = get_the_author_meta('user_email', $author_id);

                            if (!empty($mailto_sm_link)) { ?>
                                <!-- Mail to Link -->
                                <div class="meeek-social-media-links-inner-container meeeksaas-sm-home-link">
                                    <a class="meeek-icon-link" target="_blank" href="mailto:<?php echo esc_attr($author_email); ?>" style="color:<?php echo esc_attr($color); ?>;">
                                        <i class="far fa-envelope"></i>
                                    </a>
                                </div>
                            <?php }
                        } 

                        do_action('meeeksaas_after_social_links'); ?> 

                    </div>
                </div>
            <?php } 
        }
    }
}


/**
* Parse About Me Block
* @param $post_id :     integer (*Meeek Post ID)
*
*/
add_action('meeeksaas_page_content', 'meeeksaas_frontend_about_me_block', 10, 2);
function meeeksaas_frontend_about_me_block($post_id) {
    
    if (is_singular('meeek-link')) {
        $configuration = get_post_meta( $post_id, 'meeek_configuration', true );

        if ($configuration) {
            $photo_id = ((array_key_exists('user_photo_id', $configuration))?$configuration['user_photo_id']:"");
            $photo_radius = ((array_key_exists('user_bio_photo_radius', $configuration))?$configuration['user_bio_photo_radius']:"circle");
            $photo_url = ((array_key_exists('user_photo_id_url', $configuration))?$configuration['user_photo_id_url']:"");
            $about_us_image = '';
            if ($photo_id && wp_get_attachment_image_url($photo_id)) {
                $about_us_image = wp_get_attachment_image_url($photo_id, 'thumbnail');
            }else{
                $about_us_image = $photo_url;
            }
            $user_bio_color = ((array_key_exists('user_bio_color', $configuration))?$configuration['user_bio_color']:"");
            $about_us_title = ((array_key_exists('user_name', $configuration))?$configuration['user_name']:"");
            $about_us_description = ((array_key_exists('user_bio', $configuration))?$configuration['user_bio']:"");
            // alignment
            $title_alignment = ((array_key_exists('user_bio_alignment', $configuration))?$configuration['user_bio_alignment']:"");
            $description_alignment = ((array_key_exists('user_bio_alignment', $configuration))?$configuration['user_bio_alignment']:"");
            $image_alignment = ((array_key_exists('user_bio_alignment', $configuration))?$configuration['user_bio_alignment']:"");
            // sizes
            $image_width = '100';
            $image_height = '100';

            if ($user_bio_color) {
                $bio_color = $user_bio_color;
            }else{
                $bio_color = '#000000';
            }
            ?>

                <div class="meeek-about-me-container">
                <div class="meeek-about-me-img-holder" style="text-align:<?php echo esc_attr($image_alignment); ?>">
                  <?php if($about_us_image){ ?>
                    <img class="<?php echo esc_attr($photo_radius); ?>" src="<?php echo esc_url( $about_us_image ) ?>" width="<?php echo esc_attr( $image_width ); ?>px" height="<?php echo esc_attr( $image_height ); ?>px" alt="<?php echo esc_attr($about_us_title);  ?>" />
                <?php } ?>
                </div>
                <div class="meeek-about-me-content">
                <div class="meeek-about-me-inner-content">
                  <?php if($about_us_title){ ?>
                    <h2 class="meeek-about-me-title" style="text-align:<?php echo esc_attr($title_alignment); ?>; color: <?php echo esc_attr($bio_color); ?>;">
                      <?php echo esc_html($about_us_title); ?>

                      <?php if(
                        (function_exists('mtkyc_check_specific_user_status') && mtkyc_check_specific_user_status(get_post_field('post_author', get_the_ID()))) || 
                        MEEEKSAAS_DEV_MODE == true){ ?>
                        <img width="20" src="<?php echo MEEEKSAAS_PLUGIN_URL.'assets/images/'; ?>verified.svg" alt="<?php esc_html_e('Verified Owner', 'meeek-saas'); ?>" data-bs-toggle="tooltip" data-bs-placement="top" title="<?php echo apply_filters( 'meeeksaas_verified_owner_text', esc_html__('Verified Owner', 'meeek-saas') ); ?>" />
                      <?php } ?>
                    </h2>
                  <?php } ?>
                  
                  <?php if($about_us_description){ ?>
                    <p class="meeek-about-me-description" style="text-align:<?php echo esc_attr($description_alignment); ?>; color: <?php echo esc_attr($bio_color); ?>;">
                      <?php echo preg_replace("/\r\n|\r|\n/", '<br>', $about_us_description);  ?>
                      <?php //echo wp_specialchars_decode($about_us_description);  ?>
                    </p>
                  <?php } ?>
                </div>
                </div>
                </div>
            <?php 
        }
    }
}


/**
* Parse Botton Links Block
* @param $post_id :     integer (*Meeek Post ID)
*
*/
add_action('meeeksaas_page_content', 'meeeksaas_frontend_buttons_block', 20, 2);
function meeeksaas_frontend_buttons_block($post_id) {
    
    if (is_singular('meeek-link')) {
        $configuration = get_post_meta( $post_id, 'meeek_configuration', true );

        if ($configuration) {
            $version = $configuration['version'];
            $buttons_groups = $configuration['meeek-bio-links-group'];
            $buttons = array();
            if ($buttons_groups) {
                foreach ($buttons_groups as $button) {
                   
                    $elements = array(
                        'header',
                        'paypal',
                        'venmo',
                        'phone',
                    );

                    if (in_array($button['btn_type'], $elements)) {
                        $element_type = 'btn_'.$button['btn_type'];
                    }else{
                        $element_type = $button['btn_type'];
                    }

                    $btn_img = ((array_key_exists('btn_photo_id', $button))?wp_get_attachment_url($button['btn_photo_id']):"");
                    $btn_img_url = ((array_key_exists('btn_photo_id_url', $button))?$button['btn_photo_id_url']:"");
                    if (!$btn_img) {
                        $btn_img = $btn_img_url;
                    }

                    $buttons[] = array(
                        'bio_links_description' => ((array_key_exists('title', $button))?$button['title']:""),
                        'card_color' => ((array_key_exists('btn_color', $button))?$button['btn_color']:""),
                        'bio_links_image' => array(
                            'url' => $btn_img
                        ),
                        'type' => $element_type,
                        'icon' => array(
                            'value' => ((array_key_exists('btn_icon', $button))?$button['btn_icon']:""),
                            'library' => '',
                        ),
                        'link' => array(
                            'url' => ((array_key_exists('link', $button))?$button['link']:""),
                        ),
                        // label
                        'btn_title' => ((array_key_exists('label_text', $button))?$button['label_text']:""),
                        'button_color' => ((array_key_exists('btn_label_background', $button))?$button['btn_label_background']:""),
                        'icon_color' => ((array_key_exists('btn_label_color', $button))?$button['btn_label_color']:""),
                        // custom style
                        'link_style' => array(
                            'btn_linkstyle_status' => ((array_key_exists('btn_linkstyle_status', $button))?$button['btn_linkstyle_status']:""),
                            'btn_link_background' => ((array_key_exists('btn_link_background', $button))?$button['btn_link_background']:""),
                            'btn_link_color' => ((array_key_exists('btn_link_color', $button))?$button['btn_link_color']:""),
                            'btn_link_border' => ((array_key_exists('btn_link_border', $button))?$button['btn_link_border']:""),
                            'btn_link_background_hover' => ((array_key_exists('btn_link_background_hover', $button))?$button['btn_link_background_hover']:""),
                            'btn_link_color_hover' => ((array_key_exists('btn_link_color_hover', $button))?$button['btn_link_color_hover']:""),
                            'btn_link_border_hover' => ((array_key_exists('btn_link_border_hover', $button))?$button['btn_link_border_hover']:""),
                        ),
                        // header
                        'header' => ((array_key_exists('title', $button))?$button['title']:""),
                        'header_alignment' => ((array_key_exists('header_alignment', $button))?$button['header_alignment']:"center"),
                        'header_color' => ((array_key_exists('header_color', $button))?$button['header_color']:"#000000"),
                        // paypal
                        'paypal_options' => ((array_key_exists('title', $button))?$button['title']:""),
                        'venmo_options' => ((array_key_exists('title', $button))?$button['title']:""),
                        'phone_number' => ((array_key_exists('title', $button))?$button['title']:""),
                        // dropdown
                        'dropdown_title' => ((array_key_exists('title', $button))?$button['title']:""),
                        'dropdown_text' => ((array_key_exists('content', $button))?$button['content']:""),
                        'vcard' => $button,
                        // schedules
                        'btn_schedule_status' => ((array_key_exists('btn_schedule_status', $button))?$button['btn_schedule_status']:"off"),
                        'btn_schedule_date_start' => ((array_key_exists('btn_schedule_date_start', $button))?$button['btn_schedule_date_start']:""),
                        'btn_schedule_date_end' => ((array_key_exists('btn_schedule_date_end', $button))?$button['btn_schedule_date_end']:""),
                        'btn_schedule_date_timezone' => ((array_key_exists('btn_schedule_date_timezone', $button))?$button['btn_schedule_date_timezone']:"Europe/London"),
                        // label
                        'btn_label_input' => ((array_key_exists('btn_label_input', $button))?$button['btn_label_input']:"off"),
                        // sponsored
                        'btn_sponsored' => ((array_key_exists('btn_sponsored', $button))?$button['btn_sponsored']:"off"),
                        // newtab
                        'btn_target_new_tab' => ((array_key_exists('btn_target_new_tab', $button))?$button['btn_target_new_tab']:"off"),
                    );
                }
            }

            $list = $buttons;            
            $link_css = '';
            // Get the full site URL
            $site_url = get_site_url();
            // Remove the protocol (http:// or https://)
            $site_url = preg_replace('#^https?://#', '', $site_url);
            // Remove 'www.' if present
            $domain = preg_replace('/^www\./', '', $site_url);
            // Optionally remove any trailing slashes or paths if present
            $domain = strtok($domain, '/');
            ?>

            <div class="meeek-bio-links-container meeeksaas-link-<?php echo esc_attr($version); ?>" ref="<?php echo esc_attr($domain); ?>">
                <?php if ($list) {
                    foreach ( $list as $item ) {
                        $card_color = $item['card_color'];
                        $bio_links_image = $item['bio_links_image']['url'];
                        $bio_links_title = $item['bio_links_description'];
                        $icon = $item['icon'];
                        $link = $item['link']['url'];
                        $btn_title = $item['btn_title'];
                        $icon_color = $item['icon_color'];
                        $button_color = $item['button_color'];
                        $type = $item['type'];
                        $header = $item['header'];
                        $header_color = $item['header_color'];
                        $header_alignment = $item['header_alignment'];
                        $phone_number = $item['phone_number'];
                        $paypal_button = $item['paypal_options'];
                        $venmo_button = $item['venmo_options'];
                        $dropdown_title = $item['dropdown_title'];
                        $dropdown_text = $item['dropdown_text'];

                        $toggle_status = ((array_key_exists('toggle_status', $item['vcard']))?$item['vcard']['toggle_status'][0]:'off');
                        $is_whatsapp = ((array_key_exists('is_whatsapp', $item['vcard']))?$item['vcard']['is_whatsapp'][0]:'off');
                        $schedulestatus =           ((array_key_exists('btn_schedule_status', $item))?$item['btn_schedule_status']:'');
                        $schedule_date_start =      ((array_key_exists('btn_schedule_date_start', $item))?$item['btn_schedule_date_start']:'');
                        $schedule_date_end =            ((array_key_exists('btn_schedule_date_end', $item))?$item['btn_schedule_date_end']:'');
                        $schedule_date_timezone =   ((array_key_exists('btn_schedule_date_timezone', $item))?$item['btn_schedule_date_timezone']:'Europe/London');
                        
                        $attr_sponsored =               ((array_key_exists('btn_sponsored', $item))?$item['btn_sponsored']:false);
                        $attr_nsfw =                ((array_key_exists('btn_nsfw', $item['vcard']))?$item['vcard']['btn_nsfw']:false);
                        $attr_target_new_tab =      ((array_key_exists('btn_target_new_tab', $item))?$item['btn_target_new_tab']:false);

                        // nsfw
                        if (is_array($attr_nsfw)) {
                            if ($attr_nsfw[0] == 'on') {
                                $attr_nsfw = true;
                            }else{
                                $attr_nsfw = false;
                            }
                        }else{
                            $attr_nsfw = false;
                        }

                        if (is_array($attr_sponsored)) {
                            if ($attr_sponsored[0] == 'on') {
                                $attr_sponsored = true;
                            }else{
                                $attr_sponsored = false;
                            }
                        }else{
                            $attr_sponsored = false;
                        }
                        if (is_array($attr_target_new_tab)) {
                            if ($attr_target_new_tab[0] == 'on') {
                                $attr_target_new_tab = true;
                            }
                        }
                        $schedule_status = '';
                        
                        if (is_array($schedulestatus)) {
                            if ($schedulestatus[0] == 'on') {
                                date_default_timezone_set($schedule_date_timezone);
                                $now = strtotime(date('Y-m-d H:i:s'));
                                $date_start = strtotime(date($schedule_date_start));
                                $date_end = strtotime(date($schedule_date_end));

                                if ($now >= $date_start && $now <= $date_end) {
                                    $schedule_status = 'visible_link';
                                }else{
                                    $schedule_status = 'hidden_link';
                                }
                            }
                        }

                        // Custom Link Style
                        $link_class = 'meeeksaas-linkid'.meeeksaas_generate_link_id();
                        $link_style = ((array_key_exists('link_style', $item))?$item['link_style']:array());
                        if ($link_style) {

                        $linkstyle_status = ((array_key_exists('btn_linkstyle_status', $link_style))?$link_style['btn_linkstyle_status']:'');
                        if (is_array($linkstyle_status)) {
                            if ($linkstyle_status[0] == 'on') {
                                $link_background = ((array_key_exists('btn_link_background', $link_style))?$link_style['btn_link_background']:"");
                                $link_color = ((array_key_exists('btn_link_color', $link_style))?$link_style['btn_link_color']:"");
                                $link_border = ((array_key_exists('btn_link_border', $link_style))?$link_style['btn_link_border']:"");
                                $link_background_hover = ((array_key_exists('btn_link_background_hover', $link_style))?$link_style['btn_link_background_hover']:"");
                                $link_color_hover = ((array_key_exists('btn_link_color_hover', $link_style))?$link_style['btn_link_color_hover']:"");
                                $link_border_hover = ((array_key_exists('btn_link_border_hover', $link_style))?$link_style['btn_link_border_hover']:"");

                                if ($link_background || $link_color || $link_border || $link_background_hover || $link_color_hover || $link_border_hover) {
                                    // normal - link background
                                    $link_css .= '.'.$link_class.'{';
                                        if ($link_background) {     $link_css .= 'background:'.$link_background.';'; }
                                        if ($link_border) {     $link_css .= 'border-color:'.$link_border.';'; }
                                    $link_css .= '}';
                                    // normal - link color
                                    $link_css .= '.'.$link_class.' .meeek-bio-links-description{';
                                        if ($link_color) {              $link_css .= 'color:'.$link_color.';'; }
                                    $link_css .= '}';
                                    // hover - link background
                                    $link_css .= '.'.$link_class.':hover{';
                                        if ($link_background_hover) {   $link_css .= 'background:'.$link_background_hover.';'; }
                                        if ($link_border_hover) {   $link_css .= 'border-color:'.$link_border_hover.';'; }
                                    $link_css .= '}';
                                    // hover - link color
                                    $link_css .= '.'.$link_class.':hover .meeek-bio-links-description{';
                                        if ($link_color_hover) {                $link_css .= 'color:'.$link_color_hover.';'; }
                                    $link_css .= '}';
                                    // v1 - shadow
                                    $link_css .= '.meeek-bio-links-container-v5.'.$link_class.',
                                    .meeek-bio-links-container-v3.'.$link_class.'{';
                                        if ($link_border) {     $link_css .= 'box-shadow: 10px 10px '.$link_border.';'; }
                                    $link_css .= '}';
                                }
                            }
                        }
                    }

                if($type == "btn_button"){ 
                    $btn_label_cls = '';
                    if (empty($item['icon']['value']) && empty($btn_title)) {
                        $btn_label_cls = 'btn-template-no-label';
                    }
                ?>
                <div class="meeeksaas-simple-link-button meeek-bio-links-inner-container meeek-bio-links-container-<?php echo esc_attr($version); ?> <?php echo esc_attr($btn_label_cls); ?> <?php echo esc_attr($schedule_status); ?> <?php echo esc_attr($link_class); ?>" style="background-color:<?php echo esc_attr($card_color)?>">
                    <?php if($version == 'v1' || $version == 'v2'  || $version == 'v4' || $version == 'v5' || $version == 'v8'){?>
                        <?php if(!empty($bio_links_image)){?>
                                        <div class="meeek-bio-links-img-holder">
                                            <img src="<?php echo esc_url($bio_links_image); ?>" alt="bio-links-image">
                                        </div>
                                        <?php }?>
                                    <?php }?>
                                    <?php if($version == 'v3' || $version == 'v7'){?>
                                        <div class="meeek-bio-links-inner-content ">                            
                                <div class="meeek-bio-links-button" style="background:<?php if(!empty($btn_title)){echo esc_attr($button_color);} ?>; color:<?php echo esc_attr($icon_color); ?>;">
                                        <?php if(!empty($btn_title)){ ?>
                                        <?php echo esc_html($btn_title); ?>
                                    <?php } ?>
                                    <?php if(!empty($icon)){ ?>
                                    <div class="meeek-bio-links-icon" style="color:<?php echo esc_attr($icon_color); ?>">       
                                            <i class="<?php echo esc_attr($item['icon']['value']); ?>"></i>
                                        </div>
                                    <?php } ?>
                                </div>                          
                                      </div>
                          <?php }?>

                          <?php if(!empty($bio_links_title)){ ?>
                                <div class="meeek-bio-links-description">
                                <?php echo wp_kses($bio_links_title, 'title'); ?>
                                <?php if($attr_sponsored == true){?> <i class="fas fa-ad"></i><?php } ?>
                                </div>
                            <?php } ?>

                            <?php if(!empty($item['icon']['value']) || !empty($btn_title)){ ?>
                                <?php if($version == 'v1' || $version == 'v2' || $version == 'v4' || $version == 'v5' || $version == 'v8'){ ?>
                                    <div class="meeek-bio-links-inner-content ">                            
                                    <div class="meeek-bio-links-button" style="background:<?php if(!empty($btn_title)){echo esc_attr($button_color);} ?>; color:<?php echo esc_attr($icon_color); ?>;">
                                        <?php if(!empty($btn_title)){ ?>
                                        <?php echo esc_html($btn_title); ?>
                                    <?php } ?>
                                    <?php if(!empty($icon)){ ?>
                                        <div class="meeek-bio-links-icon" style="color:<?php echo esc_attr($icon_color); ?>">
                                                    <i class="<?php echo esc_attr($item['icon']['value']); ?>"></i>
                                            </div>
                                        <?php } ?>
                                    </div>                          
                                    </div>
                                <?php } ?>
                            <?php } ?>
                                
                            <a <?php if($attr_nsfw == true){?> data-bs-toggle="modal" data-bs-target="#meeeksaas_nsfw_modal" <?php } ?> <?php do_action('meeeksaas_rel_attribute', esc_url($link), $attr_sponsored, $attr_target_new_tab); ?> href="<?php echo esc_url($link); ?>"></a>
                            </div>
                        <?php } ?>

                        <?php if($type == "btn_paypal"){ ?>
                            <?php 
                                $link_atts = '';
                                if($toggle_status == 'on'){
                                    $link_atts = 'data-bs-toggle="modal" data-bs-target="#meeeksaas_paypal_donation"';
                                }
                            ?>

                            <div class="meeek-bio-links-inner-paypal meeek-bio-links-inner-paypal-<?php echo esc_attr($version); ?> <?php echo esc_attr($schedule_status); ?>">
                                <div class="meeek-bio-links-paypal">
                                    <i class="fab fa-paypal"></i>
                                    <?php echo esc_html($paypal_button); ?>
                                    <a <?php do_action('meeeksaas_rel_attribute', esc_url($link), $attr_sponsored, $attr_target_new_tab); ?> href="<?php echo esc_url($link); ?>" <?php echo $link_atts; ?>></a>
                            </div>
                            </div>
                            <?php if($toggle_status == 'on'){ ?>
                                    <div class="modal meeeksaas_paypal_donation fade" id="meeeksaas_paypal_donation" tabindex="-1" aria-labelledby="meeeksaas_share_modalLabel" aria-hidden="true">
                                      <div class="modal-dialog modal-dialog-centered modal-dialog-scrollable modal-xs">
                                        <div class="modal-content">
                                          <div class="modal-header p-4">
                                            <h4 class="modal-title text-center"><?php echo esc_html__('Donate to ', 'meeeksaas').get_the_title(); ?></h4>
                                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="<?php echo esc_attr__('Close', 'meeeksaas'); ?>"></button>
                                          </div>
                                          <div class="modal-body p-4">
                                            <form method="GET" action="https://www.paypal.com/donate">
                                                <input type="hidden" name="business" value="<?php echo esc_attr($link); ?>">
                                                        <input type="hidden" name="no_recurring" value="0">
                                                        <input type="hidden" name="item_name" value="<?php esc_attr_e('Donated through: ', 'meeeksaas') . esc_attr_e(get_bloginfo()); ?>">
                                                        <input type="hidden" name="item_number" value="<?php esc_attr_e(get_the_title()); ?>">
                                                        <input type="hidden" name="currency_code" value="USD">
                                                <div class="row text-center">
                                                    <div class="col-md-12">
                                                            <h5><?php esc_html_e('Choose an Amount', 'meeeksaas'); ?></h5>
                                                                    <div class="meeeksaas-predefined-amount">
                                                                        <?php 
                                                                        $donation_prices = meeeksaas_paypal_donation_prices(); 
                                                                        if ($donation_prices) {
                                                                            foreach ($donation_prices as $key => $price) {
                                                                                ?>
                                                                                    <input type="radio" name="amount" value="<?php echo esc_attr(number_format($price, 2, ".", "")); ?>" id="meeeksaas_pp_<?php echo esc_attr($price); ?>" <?php if ($key == '0') {echo 'checked'; } ?>><label for="meeeksaas_pp_<?php echo esc_attr($price); ?>">$<?php echo esc_attr($price); ?></label>
                                                                                <?php
                                                                            }
                                                                        }
                                                                        ?>
                                                                    </div>
                                                    </div>
                                                </div>
                                                        <div class="text-center">
                                                            <button type="submit" class="btn btn-secondary mt-4" data-bs-dismiss="modal"><i class="fab fa-paypal"></i> <?php esc_html_e('Make Your Donation Now', 'meeeksaas'); ?></button>
                                                            <div class="clearfix"></div>
                                        <i><?php echo esc_html__('You will be redirected to PayPal.com to complete the donation.', 'meeeksaas'); ?></i>
                                                        </div>
                                                    </form>
                                          </div>
                                        </div>
                                      </div>
                                    </div>
                            <?php } ?>
                        <?php } ?>


                        <?php if($type == "btn_venmo"){?>
                            <div class="meeek-bio-links-inner-venmo meeek-bio-links-inner-venmo-<?php echo esc_attr($version); ?> <?php echo esc_attr($schedule_status); ?>">
                                <div class="meeek-bio-links-venmo">
                                        <svg class="meeek-bio-links-venmo-image" fill="currentColor" id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M444.17,32H70.28C49.85,32,32,46.7,32,66.89V441.6C32,461.91,49.85,480,70.28,480H444.06C464.6,480,480,461.8,480,441.61V66.89C480.12,46.7,464.6,32,444.17,32ZM278,387H174.32L132.75,138.44l90.75-8.62,22,176.87c20.53-33.45,45.88-86,45.88-121.87,0-19.62-3.36-33-8.61-44L365.4,124.1c9.56,15.78,13.86,32,13.86,52.57C379.25,242.17,323.34,327.26,278,387Z"/></svg>
                                    <?php echo esc_html($venmo_button); ?>
                                    <a <?php do_action('meeeksaas_rel_attribute', esc_url($link), $attr_sponsored, $attr_target_new_tab); ?> href="<?php echo esc_url($link); ?>"></a>
                            </div>
                            </div>
                        <?php } ?>

                        <?php if($type == "btn_header"){?>
                            <div class="meeek-bio-links-inner-header  <?php echo esc_attr($schedule_status); ?>">
                                <h3 class="meeek-bio-links-inner-header-text" style="color: <?php echo esc_attr($header_color); ?>; text-align:<?php echo esc_attr($header_alignment); ?>;"><?php echo esc_html($header); ?></h3>
                            </div>
                        <?php } ?>

                        <?php if($type == "image"){?>
                            <?php 
                        $attachment_id = ((array_key_exists('attachment_id', $item['vcard']))?$item['vcard']['attachment_id']:'');
                        $attachment_radius = ((array_key_exists('attachment_radius', $item['vcard']))?$item['vcard']['attachment_radius']:'rounded');
                  $title_color =    ((array_key_exists('title_color', $item['vcard']))?$item['vcard']['title_color']:"#000000");
                  $title_alignment =    ((array_key_exists('title_alignment', $item['vcard']))?$item['vcard']['title_alignment']:"center");
                             ?>
                            <?php $image_url = wp_get_attachment_image_url($attachment_id, 'full'); ?>
                            <div class="meeek-bio-links-inner-header  <?php echo esc_attr($schedule_status); ?>">
                                <h3 class="meeek-bio-links-inner-header-text" style="color: <?php echo esc_attr($title_color); ?>; text-align:<?php echo esc_attr($title_alignment); ?>;"><?php echo esc_html($header); ?></h3>
                                <?php if($link){ ?><a <?php do_action('meeeksaas_rel_attribute', esc_url($link), $attr_sponsored, $attr_target_new_tab); ?> href="<?php echo esc_url($link); ?>"><?php } ?>
                                    <img src="<?php echo esc_url($image_url); ?>" alt="<?php echo esc_attr($btn_title); ?>" class="<?php echo esc_attr($attachment_radius); ?>">
                                <?php if($link){ ?></a><?php } ?>
                            </div>
                        <?php } ?>

                        <?php 
                        $phone_button_icon = 'fas fa-phone';
                        $phone_button_link = 'tel:'.$phone_number;
                        $phone_button_type = '';
                        if ($is_whatsapp == 'on') {
                            $phone_button_icon = 'fab fa-whatsapp';
                            $phone_button_link = 'https://wa.me/'.$phone_number;
                            $phone_button_type = 'meeek-phone-is-whatsapp';
                        } ?>
                        <?php if($type == "btn_phone"){ ?>
                            <div class="meeek-bio-links-inner-phone meeek-bio-links-inner-phone-<?php echo esc_attr($version); ?> <?php echo esc_attr($schedule_status); ?> <?php echo esc_attr($phone_button_type); ?>">
                                <div class="meeek-bio-links-phone">
                                    <i class="<?php echo esc_attr($phone_button_icon); ?>"></i>
                                    <u><?php echo esc_html($phone_number); ?></u>
                                    <a <?php do_action('meeeksaas_rel_attribute', esc_url($link), $attr_sponsored, $attr_target_new_tab); ?> href="<?php echo esc_attr($phone_button_link); ?>"></a>
                            </div>
                            </div>
                        <?php } ?>

                        <?php if($type == "email"){ ?>
                            <?php
                        $title = ((array_key_exists('title', $item['vcard']))?$item['vcard']['title']:'');
                        $email_to = ((array_key_exists('email_to', $item['vcard']))?$item['vcard']['email_to']:'');
                        $subject = ((array_key_exists('email_subject', $item['vcard']))?$item['vcard']['email_subject']:'');
                        $body = ((array_key_exists('email_body', $item['vcard']))?$item['vcard']['email_body']:'');

                        $query_args = array(
                                        'subject' => esc_attr($subject),
                                        'body' => esc_attr($body),
                                    );
                            ?>
                            <div class="meeek-bio-links-inner-phone meeek-bio-links-inner-phone-<?php echo esc_attr($version); ?> <?php echo esc_attr($schedule_status); ?>">
                                <div class="meeek-bio-links-phone meeek-bio-links-email">
                                    <i class="far fa-envelope"></i>
                                    <u><?php echo esc_html($title); ?></u>
                                    <a href="<?php echo add_query_arg( $query_args, 'mailto:'.esc_attr($email_to) ); ?>"></a>
                            </div>
                            </div>
                        <?php } ?>

                    <?php //Dropdown Element type ?>
                    <?php if($type == "dropdown"){ ?>
                        <div class="meeek-bio-links-inner-dropdown meeek-accordion-card <?php echo esc_attr($schedule_status); ?>">
                              <div class="meeek-accordion-card-inner">
                                <div class="meeek-accordion-title" data-accordion-element-trigger>
                                    <?php echo esc_html($dropdown_title); ?>
                                </div>
                                <div data-accordion-element-content class="meeek-accordion-content">
                                    <?php echo esc_html($dropdown_text); ?>
                                </div>
                              </div>
                            </div>
                      <?php } ?>

                    <?php //Shortcode Element type ?>
                    <?php if($type == "shortcode"){ ?>
                        <?php if($toggle_status == 'on'){ ?>
                            <h4><?php echo esc_html($dropdown_title); ?></h4>
                            <?php echo do_shortcode($dropdown_text); ?>
                        <?php }else{ ?>
                            <div class="meeek-bio-links-inner-dropdown meeek-accordion-card  <?php echo esc_attr($schedule_status); ?>">
                                  <div class="meeek-accordion-card-inner">
                                    <div class="meeek-accordion-title" data-accordion-element-trigger>
                                        <?php echo esc_html($dropdown_title); ?>
                                    </div>
                                    <div data-accordion-element-content class="meeek-accordion-content">
                                        <?php echo do_shortcode($dropdown_text); ?>
                                    </div>
                                  </div>
                                </div>
                        <?php } ?>
                      <?php } ?>

                    <?php //Block Element type ?>
                    <?php if($type == "block"){ ?>
                        <?php if($toggle_status == 'on'){ ?>
                            <h4><?php echo esc_html($dropdown_title); ?></h4>
                            <?php echo do_blocks($dropdown_text); ?>
                        <?php }else{ ?>
                            <div class="meeek-bio-links-inner-dropdown meeek-accordion-card  <?php echo esc_attr($schedule_status); ?>">
                                  <div class="meeek-accordion-card-inner">
                                    <div class="meeek-accordion-title" data-accordion-element-trigger>
                                        <?php echo esc_html($dropdown_title); ?>
                                    </div>
                                    <div data-accordion-element-content class="meeek-accordion-content">
                                        <?php echo do_blocks($dropdown_text); ?>
                                    </div>
                                  </div>
                                </div>
                        <?php } ?>
                      <?php } ?>

                      <?php 
                      if ($type == 'vcard') {
                        $link = $item['vcard'];
                      } ?>

                      <?php if(!$schedule_status == 'hidden'){ ?>
                        <?php do_action('meeeksaas_bio_links_bottom', $type, $bio_links_title, $link, $toggle_status); ?>
                        <?php do_action('meeeksaas_bio_gallery_bottom', $type, $item); ?>
                        <?php do_action('meeeksaas_bio_item_bottom', $type, $item); ?>
                        <?php do_action('meeeksaas_bio_link_element', $item['vcard'], $version); ?>
                      <?php } ?>

                <?php } ?>
                <?php } ?>
            </div>

            <div class="modal fade text-center meeeksaas-modal-nsfw" id="meeeksaas_nsfw_modal" tabindex="-1" aria-labelledby="meeeksaas_nsfw_modalLabel" aria-hidden="true">
                <div class="modal-dialog modal-dialog-centered modal-dialog-scrollable">
                    <div class="modal-content text-center">
                        <div class="modal-header p-4">
                            <h5 class="modal-title"><?php esc_html_e('Age Verification', 'meeeksaas'); ?></h5>
                        </div>
                        <div class="modal-body p-4">
                            <p><?php _e('To access this website, you must be over <strong>18</strong> years of age.', 'meeeksaas'); ?></p>
                            <a href="#" class="meeeksaas-nsfw-yes"><?php esc_html_e("Yes, I'm over 18 years old", "meeeksaas"); ?></a>
                            <div class="clearfix"></div>
                            <a href="#" class="meeeksaas-nsfw-no" data-bs-dismiss="modal"><?php esc_html_e("I'm under 18 years old.", "meeeksaas"); ?></a>
                        </div>
                    </div>
                </div>
            </div>

            <style type="text/css">
                <?php echo meeeksaas_minify_css($link_css); ?>
            </style><?php

        }
    }
}


/**
* Minifying the CSS
* @param $css :     string (CSS rules)
*
*/
function meeeksaas_minify_css($css){
    if ($css) {
        $css = str_replace(array("\r\n", "\r", "\n", "\t", '  ', '    ', '    '), '', $css);
        return $css;
    }
}


/**
* Pricing No active plans notice (user account)
* @param $type :     string
*
*/
function meeeksaas_no_active_plans_notice($type = ''){
    $builder_url = '';
    $plans_url = '';
    if (function_exists('wc_get_endpoint_url')) {
        $builder_url = wc_get_endpoint_url('bio-link-builder', '', wc_get_page_permalink( 'myaccount' ));
        $plans_url = wc_get_endpoint_url('pricing-plan', '', wc_get_page_permalink( 'myaccount' ));
    }
    ?>
        <div class="woocommerce-MyAccount-pricing-plan">
            <?php if($type == 'builder') { ?>
                <p><i class="fas fa-exclamation-triangle"></i>
                    <?php if(meeeksaas_user_is_author()){ ?>
                        <?php echo esc_html__('No Subscriptions Found! To access the builder you have to purchase a subscription.','meeeksaas') ?> 
                        <?php if(function_exists('meeek_saas_benefits_list')){ ?>
                            <a href="<?php echo esc_url($plans_url.'/#purchase'); ?>"><?php echo esc_html__('Purchase Subscription','meeeksaas') ?></a>
                        <?php }else{ ?>
                            <?php echo esc_html__('The Pricing Plans Addon is missing.','meeeksaas') ?> 
                        <?php } ?>
                    <?php }else{ ?>
                        <?php echo esc_html__('You are not the owner & author of this link-in-bio page.','meeeksaas') ?> 
                    <?php } ?>
                </p>
            <?php }else { ?>
                <p><?php echo esc_html__('No pages found!','meeeksaas') ?> <a href="<?php echo esc_url($builder_url); ?>"><?php echo esc_html__('Start Creating','meeeksaas') ?></a></p>
            <?php } ?>
        </div>


    <?php
}
add_action('meeeksaas_no_active_plans_notice', 'meeeksaas_no_active_plans_notice');
add_action('meeeksaas_no_links_pages_notice', 'meeeksaas_no_active_plans_notice');

/**
* Pricing: Upgrade Package block (user account)
*
*/
function meeeksaas_upgrade_subscription(){
    $plans_url = '';
    if (function_exists('wc_get_endpoint_url')) {
        $plans_url = wc_get_endpoint_url('pricing-plan', '', wc_get_page_permalink( 'myaccount' ));
    }
    ?>
        <div class="meeek-upgrade-notice">
            <div class="meeeksaas-blurred-bg"></div>
            <a href="<?php echo esc_url($plans_url.'/#purchase'); ?>" class="btn btn-light btn-sm meeek-upgrade-subscription align-middle">
                <svg xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" version="1.0" width="28" viewBox="0 0 128 128" height="28"><g><path d="m 64.000012,31.484944 28.902346,36.127871 28.902242,-36.127871 -7.22553,65.030147 -101.158086,0 L 6.1954237,31.484944 35.0977,67.612815 64.000012,31.484944 z" style="fill: rgb(255, 205, 0); fill-opacity: 1; fill-rule: evenodd; stroke: rgb(0, 0, 0); stroke-width: 4.33535; stroke-linecap: butt; stroke-linejoin: miter; stroke-miterlimit: 4; stroke-opacity: 1; stroke-dasharray: none;"></path></g></svg>
                <?php echo esc_html__('Upgrade','meeeksaas') ?> <i data-bs-toggle="tooltip" data-bs-placement="top" data-bs-title="<?php echo esc_attr__('This feature requires a subscription package upgrade', 'meeeksaas'); ?>" class="fas fa-question-circle"></i></a>
        </div>
    <?php
}
// elements
add_action('meeeksaas_builder_allow_youtube', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_twitter', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_tiktok', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_facebook', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_spotify', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_header', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_image', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_payment', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_phone', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_email', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_dropdown', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_social_icons', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_branding', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_bg', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_body_bg', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_button_label', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_bio', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_seo_prevent_index', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_seo_clean_url', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_templates', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_qr', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_blog', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_woocommerce', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_vcard', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_g_analytiics', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_metrics', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_shortcode', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_block', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_newsletter', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_gallery', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_booking', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_waitlist', 'meeeksaas_upgrade_subscription');
add_action('meeeksaas_builder_allow_ticket', 'meeeksaas_upgrade_subscription');


function meeeksaas_user_has_active_plans(){
    if(function_exists('user_has_active_plans') && user_has_active_plans()){
        return true;
    }else{
        return false;
    }
}

function meeeksaas_pages_limit_notice(){
    $settings = get_option('mt-saas-settings');
    $limit = ((array_key_exists('meeeksaas_free_accounts_limit', $settings))?$settings['meeeksaas_free_accounts_limit']:"3");
    if (meeeksaas_free_accounts_enabled()) { ?>
        <div class="woocommerce-MyAccount-pricing-plan">
            <p><i class="fas fa-exclamation-triangle"></i> <?php 
                echo sprintf(
                    /* translators: %s: Name of a city */
                    esc_html__('Bio Link pages limit reached. Free accounts can create max %1$s bio link pages. To create more pages, please upgrade your plan or delete 1 or more existing bio link pages.','meeeksaas'),
                    esc_html( $limit )
                );
            ?></p>
        </div><?php 
    }
}
add_action('meeeksaas_builder_notice', 'meeeksaas_pages_limit_notice');


function meeeksaas_user_is_author(){
    $current_user = wp_get_current_user();
    $user_id = $current_user->ID;

    if (isset($_GET['links_page'])) {
        $post_id = $_GET['links_page'];
    }else{
        if (isset($_POST['post_id'])) {
            $post_id = $_POST['post_id'];
        }else{
            $post_id = '';
        }
    }

    $author_id = get_post_field('post_author', $post_id);

    if (empty($post_id)) {
        return true;
    }
    
    if ($author_id != $user_id) {
        return false;
    }else{
        return true;
    }
}


function meeeksaas_user_has_builder_access(){
    if (
        is_admin() || 
        // (function_exists('user_has_active_plans') && user_has_active_plans() && !meeeksaas_user_pages_limit_reached()) ||
        // (function_exists('user_has_active_plans') && user_has_active_plans()) ||
        // (!is_admin() && function_exists('user_has_active_plans') && user_has_active_plans() && !meeeksaas_user_pages_limit_reached()) ||
        (!is_admin() && function_exists('user_has_active_plans') && user_has_active_plans() && meeeksaas_user_is_author()) ||
        (!is_admin() && meeeksaas_free_accounts_enabled() && !meeeksaas_user_pages_limit_reached() && meeeksaas_user_is_author())
    ) {
        return true;
    }else{
        return false;
    }
}


function meeeksaas_user_pages_limit_reached(){
    if ( is_user_logged_in() ) {

        $current_user = wp_get_current_user();
        $user_id = $current_user->ID;

        $user_pages = count_user_posts( $user_id , "meeek-link"  );

        $settings = get_option('mt-saas-settings');
        $limit = ((array_key_exists('meeeksaas_free_accounts_limit', $settings))?$settings['meeeksaas_free_accounts_limit']:"3");
        
        if ($settings) {
            if (($user_pages <= $limit) && meeeksaas_free_accounts_enabled()) {
                return false;
            }else{
                return true;
            }
        }else{
            return false;
        }
    }

}

function meeeksaas_all_benefits(){
    // meeek_saas_benefits_list -> function from the pricing plan
    // meeeksaas_free_accounts_benefits -> function from free accounts plan/fallback
    if (meeeksaas_free_accounts_enabled() && meeeksaas_user_has_active_plans()) {
        $all_benefits = meeek_saas_benefits_list();
        // free account + paid account
    }elseif(meeeksaas_free_accounts_enabled() && !meeeksaas_user_has_active_plans()){
        $all_benefits = meeeksaas_benefits_list_override();
        // free account + NO paid account
    }elseif(!meeeksaas_free_accounts_enabled() && meeeksaas_user_has_active_plans()){
        $all_benefits = meeeksaas_benefits_list_override();
    }elseif(!meeeksaas_free_accounts_enabled() && !meeeksaas_user_has_active_plans()){
        $all_benefits = meeeksaas_benefits_list_override();
    }else{
        $all_benefits = meeeksaas_benefits_list_override();
    }

    return $all_benefits;
}

function meeeksaas_user_benefits(){
    // meeek_saas_benefits_list -> function from the pricing plan
    // meeeksaas_free_accounts_benefits -> function from free accounts plan/fallback
    if (meeeksaas_free_accounts_enabled() && meeeksaas_user_has_active_plans()) {
        $user_benefits = ppfa_get_user_plan_benefits_array();
        // free account + paid account
    }elseif(meeeksaas_free_accounts_enabled() && !meeeksaas_user_has_active_plans()){
        $user_benefits = meeeksaas_free_accounts_benefits();
        // free account + NO paid account
    }elseif(!meeeksaas_free_accounts_enabled() && meeeksaas_user_has_active_plans()){
        $user_benefits = ppfa_get_user_plan_benefits_array();
    }elseif(!meeeksaas_free_accounts_enabled() && !meeeksaas_user_has_active_plans()){
        $user_benefits = array();
    }else{
        $user_benefits = array();
    }

    return $user_benefits;
}


function meeeksaas_user_has_benefit($benefit = ''){
    if ($benefit) {
        $user_benefits = meeeksaas_user_benefits();
        if (in_array($benefit, $user_benefits)) {
            return true;
        }else{
            return false;
        }
    }
}


/**
* Pricing: Limitations
*
*/
function meeeksaas_package_limitations() {

    $all_benefits = meeeksaas_all_benefits();
    $user_benefits = meeeksaas_user_benefits();

    if (!is_admin()) {
        foreach ($all_benefits as $key => $value) {
            if (in_array($key, $user_benefits)) {
                remove_action('meeeksaas_builder_'.$key, 'meeeksaas_upgrade_subscription');
            }
        }
    }else{
        foreach ($all_benefits as $key => $value) {
            remove_action('meeeksaas_builder_'.$key, 'meeeksaas_upgrade_subscription');
        }
    }
}
add_action( 'after_setup_theme', 'meeeksaas_package_limitations' );


/**
* Pricing: Element data removal (builder)
* @param $element:  string (element type ID)
* 
*/
function meeeksaas_element_data_type_removal($element) {

    if ($element == 'venmo' || $element == 'paypal') {
        $el = 'payment';
    }else{
        $el = $element;
    }

    $available_elements = meeeksaas_available_element_types();
    $user_benefits = meeeksaas_user_benefits();

    if (!is_admin()) {
        if (in_array($element, $available_elements)) { 
            if (in_array('allow_'.$el, $user_benefits)) { ?>
                <button class="btn btn-outline-success btn-sm meeek-element-importer-btn" data-element-type="<?php echo esc_attr($element); ?>"><?php esc_html_e('Add', 'meeeksaas'); ?></button>
                <?php 
            }
        }
    }else{
        ?>
        <button class="btn btn-outline-success btn-sm meeek-element-importer-btn" data-element-type="<?php echo esc_attr($element); ?>"><?php esc_html_e('Add', 'meeeksaas'); ?></button>
        <?php 
    }
 

}
add_action( 'meeeksaas_element_add_button', 'meeeksaas_element_data_type_removal' );


/**
* Page link generate unique ID
* 
*/
function meeeksaas_generate_link_id(){
    $link_id = uniqid('-', true);
    $link_slug = substr($link_id, strlen($link_id) - 5, strlen($link_id));

    return '-'.$link_slug;
}


/**
* Builder Template Importer
* @param $template_version:  string (v1, v2, v3 etc...)
* 
*/
function meeeksaas_template_importer($template_version){
    global $wp;
    if (is_admin()) {
        $current_url = admin_url('admin.php'.add_query_arg($_GET, $wp->request));
    }else{
        $current_url = home_url(add_query_arg($_GET, $wp->request));
    }
    $current_url = add_query_arg(array('use_template' => $template_version), $current_url);

    if (!is_admin()) {
        if (function_exists('ppfa_get_user_plan_benefits_array')) {
            $user_benefits = meeeksaas_user_benefits();
            if (in_array('allow_templates', $user_benefits)) { ?>
                <div class="meeek-template-importer">
                    <a href="<?php echo esc_url($current_url); ?>" class="btn btn-light btn-sm meeek-template-importer-btn align-middle" data-template="<?php echo esc_attr($template_version); ?>"><i class="fas fa-cloud-download-alt"></i> <?php echo esc_html__('Use Template','meeeksaas') ?></a>
                </div>
            <?php }
        }else{ ?>
            <div class="meeek-template-importer">
                <a href="<?php echo esc_url($current_url); ?>" class="btn btn-light btn-sm meeek-template-importer-btn align-middle" data-template="<?php echo esc_attr($template_version); ?>"><i class="fas fa-cloud-download-alt"></i> <?php echo esc_html__('Use Template','meeeksaas') ?></a>
            </div>
            <?php 
        }
    }else{ ?>
        <div class="meeek-template-importer">
            <a href="<?php echo esc_url($current_url); ?>" class="btn btn-light btn-sm meeek-template-importer-btn align-middle" data-template="<?php echo esc_attr($template_version); ?>"><i class="fas fa-cloud-download-alt"></i> <?php echo esc_html__('Use Template','meeeksaas') ?></a>
        </div>
        <?php 
    }

}
add_action('meeeksaas_builder_allow_templates_importer', 'meeeksaas_template_importer');


function meeeksaas_page_builder_license_notice(){
    $status = MEEEK_SAAS\Activator\mt_lic_helper_is_license_active();
    if (is_admin()) {
        $current_url = admin_url('edit.php?post_type=meeek-link&page=mt-activator');
    }else{
        $current_url = site_url();
    }
    if (!$status) {
        ?>
        <div class="meeeksaas-blurred-bg"></div>
        <div class="meeek-license-status">
            <a href="<?php echo esc_url($current_url); ?>" class="btn btn-light btn-lg align-middle"><i class="fas fa-stamp"></i> <?php echo esc_html__('Activate Plugin License', 'meeeksaas') ?></a>
        </div>
        <?php 
    }
}

function meeeksaas_qr_code_generator($post_id = '', $width_x_height = ''){
    $size = '500x500';
    if (!empty($width_x_height)) {
        $size = $width_x_height;
    }

    $qr_link = 'https://api.qrserver.com/v1/create-qr-code/?size=500x500&qzone=2&data='.get_permalink($post_id).'&choe=UTF-8';
    ?>
        <a href="<?php echo esc_url($qr_link); ?>" target="_blank"><img class="meeek-qr" src="<?php echo esc_url($qr_link); ?>" alt="qr" /></a>
    <?php
}
add_action('meeeksaas_builder_qr', 'meeeksaas_qr_code_generator', 10, 2);
add_action('meeeksaas_sharing_panel_qr', 'meeeksaas_qr_code_generator', 10, 2);


function meeeksaas_builder_active_tab(){
    if (isset($_GET['tab']) && !empty($_GET['tab'])) {
        return $_GET['tab'];
    }else{
        return 'links';
    }
}


/**
* Builder Element Type next to accordion title
* @param $element_type:  string (button, paypal, dropdown etc...)
* 
*/
function meeeksaas_element_type_accordion_title($element_type = ''){
    if ($element_type == 'btn_button') {
        $element_type = 'button';
    }
    ?>
        <label class="meeeksass-label meeeksass-label-<?php echo esc_attr($element_type); ?>"><?php echo esc_html($element_type); ?></label>
    <?php
}
add_action('meeeksaas_builder_after_accordion_title', 'meeeksaas_element_type_accordion_title');


function meeeksaas_element_add_duplicate_icon(){
    ?>
        <i data-repeater-clone class="far fa-clone"></i>
    <?php
}
// add_action('meeeksaas_builder_after_accordion_title', 'meeeksaas_element_add_duplicate_icon');


//Check if user has any plans active
function meeeksaas_free_accounts_enabled(){
    $settings = get_option('mt-saas-settings');
    if ($settings) {
        $meeeksaas_user_trial_status = ((array_key_exists('meeeksaas_user_trial_status', $settings))?$settings['meeeksaas_user_trial_status']:"off");
        if ($meeeksaas_user_trial_status == 'on') {
            return true;
        }else{
            return false;
        }
    }else{
        return false;
    }
}
//Check if user has any plans active
function meeeksaas_free_accounts_benefits(){
    $settings = get_option('mt-saas-settings');
    if ($settings) {
        $user_trial_benefits = ((array_key_exists('meeeksaas_user_trial_benefits', $settings))?$settings['meeeksaas_user_trial_benefits']:array());
        return $user_trial_benefits;
    }
}



function meeeksaas_add_rel_attr_to_link($link_url = '', $sponsored = '', $open_in_new_tab = '') {
    // Get the base URL of your WordPress site
    $base_url = home_url();

    // Parse the URLs to get their hosts (domains)
    $parsed_base_url = parse_url($base_url);
    $parsed_link_url = parse_url($link_url);

    $rel_extern = array();
    $rel_intern = array();
    $target = '_self';
    // Check if the hosts (domains) match
    if ($sponsored) {
        array_push($rel_extern, 'sponsored');
        array_push($rel_intern, 'sponsored');
    }
    if ($open_in_new_tab) {
        array_push($rel_extern, 'noopener');
        array_push($rel_extern, 'noreferrer');
        $target = '_blank';
    }
    array_push($rel_extern, 'nofollow');

    if(isset($parsed_base_url['host']) && isset($parsed_link_url['host']) && $parsed_base_url['host'] !== $parsed_link_url['host']){
        echo 'rel="'.implode(" ", $rel_extern).'"'. ' target="'.esc_attr($target).'"';
    }else{
        echo 'rel="'.implode(" ", $rel_intern).'"';
    }

}
add_action('meeeksaas_rel_attribute', 'meeeksaas_add_rel_attr_to_link', 10, 3);


function meeeksaas_custom_templates(){
    $settings = get_option('mt-saas-settings');
    if ($settings) {
        $templates = ((array_key_exists('meeeksaas_custom_templates', $settings))?$settings['meeeksaas_custom_templates']:array());
        foreach ($templates as $template) {
            $media_id = ((array_key_exists('media_id', $template))?$template['media_id']:'');
            if ($media_id) {
                $image_url = wp_get_attachment_image_url( $media_id, 'large' );
                $post_id = $template['template_id'];
                ?>
                <div class="list-inline col-md-6 mb-4">
                    <div class="relative">
                        <img src="<?php echo esc_url($image_url); ?>" alt="<?php esc_attr_e('Template', 'meeeksaas'); ?>" />
                        <?php do_action('meeeksaas_builder_allow_templates'); ?>
                        <?php do_action('meeeksaas_builder_allow_templates_importer', $post_id); ?>
                    </div>
                </div>
                <?php 
            }
        }

    }
}
add_action('meeeksaas_builder_after_premade_templates', 'meeeksaas_custom_templates');


function meeeksaas_googlefonts(){
    $google_fonts_list = array(
        'ABeeZee:regular,italic,latin' => 'ABeeZee',
        'Abel:regular,latin' => 'Abel',
        'Abril+Fatface:regular,latin-ext,latin' => 'Abril Fatface',
        'Aclonica:regular,latin' => 'Aclonica',
        'Acme:regular,latin' => 'Acme',
        'Actor:regular,latin' => 'Actor',
        'Bebas+Neue:regular,latin' => 'Bebas Neue',
        'Adamina:regular,latin' => 'Adamina',
        'Advent+Pro:100,200,300,regular,500,600,700,greek,latin-ext,latin' => 'Advent Pro',
        'Aguafina+Script:regular,latin-ext,latin' => 'Aguafina Script',
        'Akronim:regular,latin-ext,latin' => 'Akronim',
        'Aladin:regular,latin-ext,latin' => 'Aladin',
        'Aldrich:regular,latin' => 'Aldrich',
        'Alef:regular,700,latin,hebrew' => 'Alef',
        'Alegreya:regular,italic,700,700italic,900,900italic,latin-ext,latin' => 'Alegreya',
        'Alegreya+SC:regular,italic,700,700italic,900,900italic,latin-ext,latin' => 'Alegreya SC',
        'Alegreya+Sans:100,100italic,300,300italic,regular,italic,500,500italic,700,700italic,800,800italic,900,900italic,vietnamese,latin-ext,latin' => 'Alegreya Sans',
        'Alegreya+Sans+SC:100,100italic,300,300italic,regular,italic,500,500italic,700,700italic,800,800italic,900,900italic,vietnamese,latin-ext,latin' => 'Alegreya Sans SC',
        'Alex+Brush:regular,latin-ext,latin' => 'Alex Brush',
        'Alfa+Slab+One:regular,latin' => 'Alfa Slab One',
        'Alice:regular,latin' => 'Alice',
        'Alike:regular,latin' => 'Alike',
        'Alike+Angular:regular,latin' => 'Alike Angular',
        'Allan:regular,700,latin-ext,latin' => 'Allan',
        'Allerta:regular,latin' => 'Allerta',
        'Allerta+Stencil:regular,latin' => 'Allerta Stencil',
        'Allura:regular,latin-ext,latin' => 'Allura',
        'Almendra:regular,italic,700,700italic,latin-ext,latin' => 'Almendra',
        'Almendra+Display:regular,latin-ext,latin' => 'Almendra Display',
        'Almendra+SC:regular,latin' => 'Almendra SC',
        'Amarante:regular,latin-ext,latin' => 'Amarante',
        'Amaranth:regular,italic,700,700italic,latin' => 'Amaranth',
        'Amatic+SC:regular,700,latin-ext,latin' => 'Amatic SC',
        'Amethysta:regular,latin' => 'Amethysta',
        'Amiri:regular,italic,700,700italic,arabic,latin' => 'Amiri',
        'Amita:regular,700,latin-ext,latin,devanagari' => 'Amita',
        'Anaheim:regular,latin-ext,latin' => 'Anaheim',
        'Andada:regular,latin-ext,latin' => 'Andada',
        'Andika:regular,latin-ext,cyrillic-ext,latin,cyrillic' => 'Andika',
        'Angkor:regular,khmer' => 'Angkor',
        'Annie+Use+Your+Telescope:regular,latin' => 'Annie Use Your Telescope',
        'Anonymous+Pro:regular,italic,700,700italic,greek,latin-ext,latin,cyrillic' => 'Anonymous Pro',
        'Antic:regular,latin' => 'Antic',
        'Antic+Didone:regular,latin' => 'Antic Didone',
        'Antic+Slab:regular,latin' => 'Antic Slab',
        'Anton:regular,latin-ext,latin' => 'Anton',
        'Arapey:regular,italic,latin' => 'Arapey',
        'Arbutus:regular,latin-ext,latin' => 'Arbutus',
        'Arbutus+Slab:regular,latin-ext,latin' => 'Arbutus Slab',
        'Architects+Daughter:regular,latin' => 'Architects Daughter',
        'Archivo+Black:regular,latin-ext,latin' => 'Archivo Black',
        'Archivo+Narrow:regular,italic,700,700italic,latin-ext,latin' => 'Archivo Narrow',
        'Arimo:regular,italic,700,700italic,vietnamese,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic,hebrew' => 'Arimo',
        'Arizonia:regular,latin-ext,latin' => 'Arizonia',
        'Armata:regular,latin-ext,latin' => 'Armata',
        'Artifika:regular,latin' => 'Artifika',
        'Arvo:regular,italic,700,700italic,latin' => 'Arvo',
        'Arya:regular,700,latin-ext,latin,devanagari' => 'Arya',
        'Asap:regular,italic,700,700italic,latin-ext,latin' => 'Asap',
        'Asar:regular,latin-ext,latin,devanagari' => 'Asar',
        'Asset:regular,latin' => 'Asset',
        'Astloch:regular,700,latin' => 'Astloch',
        'Asul:regular,700,latin' => 'Asul',
        'Atomic+Age:regular,latin' => 'Atomic Age',
        'Aubrey:regular,latin' => 'Aubrey',
        'Audiowide:regular,latin-ext,latin' => 'Audiowide',
        'Autour+One:regular,latin-ext,latin' => 'Autour One',
        'Average:regular,latin-ext,latin' => 'Average',
        'Average+Sans:regular,latin-ext,latin' => 'Average Sans',
        'Averia+Gruesa+Libre:regular,latin-ext,latin' => 'Averia Gruesa Libre',
        'Averia+Libre:300,300italic,regular,italic,700,700italic,latin' => 'Averia Libre',
        'Averia+Sans+Libre:300,300italic,regular,italic,700,700italic,latin' => 'Averia Sans Libre',
        'Averia+Serif+Libre:300,300italic,regular,italic,700,700italic,latin' => 'Averia Serif Libre',
        'Bad+Script:regular,latin,cyrillic' => 'Bad Script',
        'Balthazar:regular,latin' => 'Balthazar',
        'Bangers:regular,latin' => 'Bangers',
        'Basic:regular,latin-ext,latin' => 'Basic',
        'Battambang:regular,700,khmer' => 'Battambang',
        'Baumans:regular,latin' => 'Baumans',
        'Bayon:regular,khmer' => 'Bayon',
        'Belgrano:regular,latin' => 'Belgrano',
        'Belleza:regular,latin-ext,latin' => 'Belleza',
        'BenchNine:300,regular,700,latin-ext,latin' => 'BenchNine',
        'Bentham:regular,latin' => 'Bentham',
        'Berkshire+Swash:regular,latin-ext,latin' => 'Berkshire Swash',
        'Bevan:regular,latin' => 'Bevan',
        'Bigelow+Rules:regular,latin-ext,latin' => 'Bigelow Rules',
        'Bigshot+One:regular,latin' => 'Bigshot One',
        'Bilbo:regular,latin-ext,latin' => 'Bilbo',
        'Bilbo+Swash+Caps:regular,latin-ext,latin' => 'Bilbo Swash Caps',
        'Biryani:200,300,regular,600,700,800,900,latin-ext,latin,devanagari' => 'Biryani',
        'Bitter:regular,italic,700,latin-ext,latin' => 'Bitter',
        'Black+And+White+Picture:regular,latin-ext,latin' => 'Black And White Picture',
        'Bokor:regular,khmer' => 'Bokor',
        'Bonbon:regular,latin' => 'Bonbon',
        'Boogaloo:regular,latin' => 'Boogaloo',
        'Bowlby+One:regular,latin' => 'Bowlby One',
        'Bowlby+One+SC:regular,latin-ext,latin' => 'Bowlby One SC',
        'Brawler:regular,latin' => 'Brawler',
        'Bree+Serif:regular,latin-ext,latin' => 'Bree Serif',
        'Bubblegum+Sans:regular,latin-ext,latin' => 'Bubblegum Sans',
        'Bubbler+One:regular,latin-ext,latin' => 'Bubbler One',
        'Buda:300,latin' => 'Buda',
        'Bungee+Shade:regular,700,latin-ext,latin' => 'Bungee Shade',
        'Butcherman:regular,latin-ext,latin' => 'Butcherman',
        'Butterfly+Kids:regular,latin-ext,latin' => 'Butterfly Kids',
        'Cabin:regular,italic,500,500italic,600,600italic,700,700italic,latin' => 'Cabin',
        'Cabin+Condensed:regular,500,600,700,latin' => 'Cabin Condensed',
        'Cabin+Sketch:regular,700,latin' => 'Cabin Sketch',
        'Caesar+Dressing:regular,latin' => 'Caesar Dressing',
        'Cagliostro:regular,latin' => 'Cagliostro',
        'Calligraffitti:regular,latin' => 'Calligraffitti',
        'Cambay:regular,italic,700,700italic,latin-ext,latin,devanagari' => 'Cambay',
        'Cambo:regular,latin' => 'Cambo',
        'Candal:regular,latin' => 'Candal',
        'Cantarell:regular,italic,700,700italic,latin' => 'Cantarell',
        'Cantata+One:regular,latin-ext,latin' => 'Cantata One',
        'Cantora+One:regular,latin-ext,latin' => 'Cantora One',
        'Capriola:regular,latin-ext,latin' => 'Capriola',
        'Cardo:regular,italic,700,greek,latin-ext,greek-ext,latin' => 'Cardo',
        'Carme:regular,latin' => 'Carme',
        'Carrois+Gothic:regular,latin' => 'Carrois Gothic',
        'Carrois+Gothic+SC:regular,latin' => 'Carrois Gothic SC',
        'Carter+One:regular,latin' => 'Carter One',
        'Catamaran:100,200,300,regular,500,600,700,800,900,latin-ext,latin,tamil' => 'Catamaran',
        'Caudex:regular,italic,700,700italic,greek,latin-ext,greek-ext,latin' => 'Caudex',
        'Caveat:regular,700,latin-ext,latin' => 'Caveat',
        'Caveat+Brush:regular,latin-ext,latin' => 'Caveat Brush',
        'Cedarville+Cursive:regular,latin' => 'Cedarville Cursive',
        'Ceviche+One:regular,latin' => 'Ceviche One',
        'Changa+One:regular,italic,latin' => 'Changa One',
        'Chango:regular,latin-ext,latin' => 'Chango',
        'Chau+Philomene+One:regular,italic,latin-ext,latin' => 'Chau Philomene One',
        'Chela+One:regular,latin-ext,latin' => 'Chela One',
        'Chelsea+Market:regular,latin-ext,latin' => 'Chelsea Market',
        'Chenla:regular,khmer' => 'Chenla',
        'Cherry+Cream+Soda:regular,latin' => 'Cherry Cream Soda',
        'Cherry+Swash:regular,700,latin-ext,latin' => 'Cherry Swash',
        'Charmonman:regular,latin' => 'Charmonman',
        'Chicle:regular,latin-ext,latin' => 'Chicle',
        'Chivo:regular,italic,900,900italic,latin' => 'Chivo',
        'Chonburi:regular,vietnamese,latin-ext,thai,latin' => 'Chonburi',
        'Cinzel:regular,700,900,latin' => 'Cinzel',
        'Cinzel+Decorative:regular,700,900,latin' => 'Cinzel Decorative',
        'Clicker+Script:regular,latin-ext,latin' => 'Clicker Script',
        'Coda:regular,800,latin-ext,latin' => 'Coda',
        'Coda+Caption:800,latin-ext,latin' => 'Coda Caption',
        'Codystar:300,regular,latin-ext,latin' => 'Codystar',
        'Combo:regular,latin-ext,latin' => 'Combo',
        'Comfortaa:300,regular,700,greek,latin-ext,cyrillic-ext,latin,cyrillic' => 'Comfortaa',
        'Coming+Soon:regular,latin' => 'Coming Soon',
        'Concert+One:regular,latin-ext,latin' => 'Concert One',
        'Condiment:regular,latin-ext,latin' => 'Condiment',
        'Content:regular,700,khmer' => 'Content',
        'Contrail+One:regular,latin' => 'Contrail One',
        'Convergence:regular,latin' => 'Convergence',
        'Cookie:regular,latin' => 'Cookie',
        'Copse:regular,latin' => 'Copse',
        'Corben:regular,700,latin-ext,latin' => 'Corben',
        'Courgette:regular,latin-ext,latin' => 'Courgette',
        'Cousine:regular,italic,700,700italic,vietnamese,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic,hebrew' => 'Cousine',
        'Coustard:regular,900,latin' => 'Coustard',
        'Covered+By+Your+Grace:regular,latin' => 'Covered By Your Grace',
        'Crafty+Girls:regular,latin' => 'Crafty Girls',
        'Creepster:regular,latin' => 'Creepster',
        'Crete+Round:regular,italic,latin-ext,latin' => 'Crete Round',
        'Crimson+Text:regular,italic,600,600italic,700,700italic,latin' => 'Crimson Text',
        'Croissant+One:regular,latin-ext,latin' => 'Croissant One',
        'Crushed:regular,latin' => 'Crushed',
        'Cuprum:regular,italic,700,700italic,latin-ext,latin,cyrillic' => 'Cuprum',
        'Cutive:regular,latin-ext,latin' => 'Cutive',
        'Cutive+Mono:regular,latin-ext,latin' => 'Cutive Mono',
        'Damion:regular,latin' => 'Damion',
        'Dancing+Script:regular,700,latin' => 'Dancing Script',
        'Dangrek:regular,khmer' => 'Dangrek',
        'Dawning+of+a+New+Day:regular,latin' => 'Dawning of a New Day',
        'Days+One:regular,latin' => 'Days One',
        'Dekko:regular,latin-ext,latin,devanagari' => 'Dekko',
        'Delius:regular,latin' => 'Delius',
        'Delius+Swash+Caps:regular,latin' => 'Delius Swash Caps',
        'Delius+Unicase:regular,700,latin' => 'Delius Unicase',
        'Della+Respira:regular,latin' => 'Della Respira',
        'Denk+One:regular,latin-ext,latin' => 'Denk One',
        'Devonshire:regular,latin-ext,latin' => 'Devonshire',
        'Dhurjati:regular,telugu,latin' => 'Dhurjati',
        'Didact+Gothic:regular,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic' => 'Didact Gothic',
        'Diplomata:regular,latin-ext,latin' => 'Diplomata',
        'Diplomata+SC:regular,latin-ext,latin' => 'Diplomata SC',
        'Domine:regular,700,latin-ext,latin' => 'Domine',
        'Donegal+One:regular,latin-ext,latin' => 'Donegal One',
        'Dokdo:regular,latin-ext,latin' => 'Dokdo',
        'Dorsa:regular,latin' => 'Dorsa',
        'Dosis:200,300,regular,500,600,700,800,latin-ext,latin' => 'Dosis',
        'Dr+Sugiyama:regular,latin-ext,latin' => 'Dr Sugiyama',
        'Droid+Sans:regular,700,latin' => 'Droid Sans',
        'Droid+Sans+Mono:regular,latin' => 'Droid Sans Mono',
        'Droid+Serif:regular,italic,700,700italic,latin' => 'Droid Serif',
        'Duru+Sans:regular,latin-ext,latin' => 'Duru Sans',
        'Dynalight:regular,latin-ext,latin' => 'Dynalight',
        'EB+Garamond:regular,vietnamese,latin-ext,cyrillic-ext,latin,cyrillic' => 'EB Garamond',
        'Eagle+Lake:regular,latin-ext,latin' => 'Eagle Lake',
        'Eater:regular,latin-ext,latin' => 'Eater',
        'Economica:regular,italic,700,700italic,latin-ext,latin' => 'Economica',
        'Eczar:regular,500,600,700,800,latin-ext,latin,devanagari' => 'Eczar',
        'Ek+Mukta:200,300,regular,500,600,700,800,latin-ext,latin,devanagari' => 'Ek Mukta',
        'Electrolize:regular,latin' => 'Electrolize',
        'Elsie:regular,900,latin-ext,latin' => 'Elsie',
        'Elsie+Swash+Caps:regular,900,latin-ext,latin' => 'Elsie Swash Caps',
        'Emblema+One:regular,latin-ext,latin' => 'Emblema One',
        'Emilys+Candy:regular,latin-ext,latin' => 'Emilys Candy',
        'Engagement:regular,latin' => 'Engagement',
        'Englebert:regular,latin-ext,latin' => 'Englebert',
        'Enriqueta:regular,700,latin-ext,latin' => 'Enriqueta',
        'Erica+One:regular,latin' => 'Erica One',
        'Esteban:regular,latin-ext,latin' => 'Esteban',
        'Euphoria+Script:regular,latin-ext,latin' => 'Euphoria Script',
        'Ewert:regular,latin-ext,latin' => 'Ewert',
        'Exo:100,100italic,200,200italic,300,300italic,regular,italic,500,500italic,600,600italic,700,700italic,800,800italic,900,900italic,latin-ext,latin' => 'Exo',
        'Exo+2:100,100italic,200,200italic,300,300italic,regular,italic,500,500italic,600,600italic,700,700italic,800,800italic,900,900italic,latin-ext,latin,cyrillic' => 'Exo 2',
        'Expletus+Sans:regular,italic,500,500italic,600,600italic,700,700italic,latin' => 'Expletus Sans',
        'Fanwood+Text:regular,italic,latin' => 'Fanwood Text',
        'Fascinate:regular,latin' => 'Fascinate',
        'Fascinate+Inline:regular,latin' => 'Fascinate Inline',
        'Faster+One:regular,latin' => 'Faster One',
        'Fasthand:regular,khmer' => 'Fasthand',
        'Fauna+One:regular,latin-ext,latin' => 'Fauna One',
        'Federant:regular,latin' => 'Federant',
        'Federo:regular,latin' => 'Federo',
        'Felipa:regular,latin-ext,latin' => 'Felipa',
        'Fenix:regular,latin-ext,latin' => 'Fenix',
        'Finger+Paint:regular,latin' => 'Finger Paint',
        'Fira+Mono:regular,700,greek,latin-ext,cyrillic-ext,latin,cyrillic' => 'Fira Mono',
        'Fira+Sans:300,300italic,regular,italic,500,500italic,700,700italic,greek,latin-ext,cyrillic-ext,latin,cyrillic' => 'Fira Sans',
        'Fjalla+One:regular,latin-ext,latin' => 'Fjalla One',
        'Fjord+One:regular,latin' => 'Fjord One',
        'Flamenco:300,regular,latin' => 'Flamenco',
        'Flavors:regular,latin' => 'Flavors',
        'Fondamento:regular,italic,latin-ext,latin' => 'Fondamento',
        'Fontdiner+Swanky:regular,latin' => 'Fontdiner Swanky',
        'Forum:regular,latin-ext,cyrillic-ext,latin,cyrillic' => 'Forum',
        'Francois+One:regular,latin-ext,latin' => 'Francois One',
        'Freckle+Face:regular,latin-ext,latin' => 'Freckle Face',
        'Fredericka+the+Great:regular,latin' => 'Fredericka the Great',
        'Fredoka+One:regular,latin' => 'Fredoka One',
        'Freehand:regular,khmer' => 'Freehand',
        'Fresca:regular,latin-ext,latin' => 'Fresca',
        'Frijole:regular,latin' => 'Frijole',
        'Fruktur:regular,latin-ext,latin' => 'Fruktur',
        'Fugaz+One:regular,latin' => 'Fugaz One',
        'GFS+Didot:regular,greek' => 'GFS Didot',
        'GFS+Neohellenic:regular,italic,700,700italic,greek' => 'GFS Neohellenic',
        'Gabriela:regular,latin-ext,latin' => 'Gabriela',
        'Gafata:regular,latin-ext,latin' => 'Gafata',
        'Galdeano:regular,latin' => 'Galdeano',
        'Galindo:regular,latin-ext,latin' => 'Galindo',
        'Gentium+Basic:regular,italic,700,700italic,latin-ext,latin' => 'Gentium Basic',
        'Gentium+Book+Basic:regular,italic,700,700italic,latin-ext,latin' => 'Gentium Book Basic',
        'Geo:regular,italic,latin' => 'Geo',
        'Geostar:regular,latin' => 'Geostar',
        'Geostar+Fill:regular,latin' => 'Geostar Fill',
        'Germania+One:regular,latin' => 'Germania One',
        'Gidugu:regular,telugu,latin' => 'Gidugu',
        'Gilda+Display:regular,latin-ext,latin' => 'Gilda Display',
        'Give+You+Glory:regular,latin' => 'Give You Glory',
        'Glass+Antiqua:regular,latin-ext,latin' => 'Glass Antiqua',
        'Glegoo:regular,700,latin-ext,latin,devanagari' => 'Glegoo',
        'Gloria+Hallelujah:regular,latin' => 'Gloria Hallelujah',
        'Goblin+One:regular,latin' => 'Goblin One',
        'Gochi+Hand:regular,latin' => 'Gochi Hand',
        'Gorditas:regular,700,latin' => 'Gorditas',
        'Goudy+Bookletter+1911:regular,latin' => 'Goudy Bookletter 1911',
        'Graduate:regular,latin' => 'Graduate',
        'Grand+Hotel:regular,latin-ext,latin' => 'Grand Hotel',
        'Gravitas+One:regular,latin' => 'Gravitas One',
        'Great+Vibes:regular,latin-ext,latin' => 'Great Vibes',
        'Griffy:regular,latin-ext,latin' => 'Griffy',
        'Gruppo:regular,latin-ext,latin' => 'Gruppo',
        'Gudea:regular,italic,700,latin-ext,latin' => 'Gudea',
        'Gurajada:regular,telugu,latin' => 'Gurajada',
        'Habibi:regular,latin-ext,latin' => 'Habibi',
        'Hachi+Maru+Pop:300,regular,500,600,700,latin-ext,latin,devanagari' => 'Hachi Maru Pop',
        'Hammersmith+One:regular,latin-ext,latin' => 'Hammersmith One',
        'Hanalei:regular,latin-ext,latin' => 'Hanalei',
        'Hanalei+Fill:regular,latin-ext,latin' => 'Hanalei Fill',
        'Handlee:regular,latin' => 'Handlee',
        'Hanuman:regular,700,khmer' => 'Hanuman',
        'Happy+Monkey:regular,latin-ext,latin' => 'Happy Monkey',
        'Headland+One:regular,latin-ext,latin' => 'Headland One',
        'Henny+Penny:regular,latin' => 'Henny Penny',
        'Herr+Von+Muellerhoff:regular,latin-ext,latin' => 'Herr Von Muellerhoff',
        'Hind:300,regular,500,600,700,latin-ext,latin,devanagari' => 'Hind',
        'Hind+Siliguri:300,regular,500,600,700,bengali,latin-ext,latin' => 'Hind Siliguri',
        'Hind+Vadodara:300,regular,500,600,700,gujarati,latin-ext,latin' => 'Hind Vadodara',
        'Holtwood+One+SC:regular,latin' => 'Holtwood One SC',
        'Homemade+Apple:regular,latin' => 'Homemade Apple',
        'Homenaje:regular,latin-ext,latin' => 'Homenaje',
        'IM+Fell+DW+Pica:regular,italic,latin' => 'IM Fell DW Pica',
        'IM+Fell+DW+Pica+SC:regular,latin' => 'IM Fell DW Pica SC',
        'IM+Fell+Double+Pica:regular,italic,latin' => 'IM Fell Double Pica',
        'IM+Fell+Double+Pica+SC:regular,latin' => 'IM Fell Double Pica SC',
        'IM+Fell+English:regular,italic,latin' => 'IM Fell English',
        'IM+Fell+English+SC:regular,latin' => 'IM Fell English SC',
        'IM+Fell+French+Canon:regular,italic,latin' => 'IM Fell French Canon',
        'IM+Fell+French+Canon+SC:regular,latin' => 'IM Fell French Canon SC',
        'IM+Fell+Great+Primer:regular,italic,latin' => 'IM Fell Great Primer',
        'IM+Fell+Great+Primer+SC:regular,latin' => 'IM Fell Great Primer SC',
        'Iceberg:regular,latin' => 'Iceberg',
        'Iceland:regular,latin' => 'Iceland',
        'Imprima:regular,latin-ext,latin' => 'Imprima',
        'Inconsolata:regular,700,latin-ext,latin' => 'Inconsolata',
        'Inder:regular,latin-ext,latin' => 'Inder',
        'Indie+Flower:regular,latin' => 'Indie Flower',
        'Inika:regular,700,latin-ext,latin' => 'Inika',
        'Inspiration:300,regular,500,600,700,800,900,latin-ext,latin,devanagari' => 'Inspiration',
        'Irish+Grover:regular,latin' => 'Irish Grover',
        'Istok+Web:regular,italic,700,700italic,latin-ext,cyrillic-ext,latin,cyrillic' => 'Istok Web',
        'Italiana:regular,latin' => 'Italiana',
        'Italianno:regular,latin-ext,latin' => 'Italianno',
        'Itim:regular,vietnamese,latin-ext,thai,latin' => 'Itim',
        'Jacques+Francois:regular,latin' => 'Jacques Francois',
        'Jacques+Francois+Shadow:regular,latin' => 'Jacques Francois Shadow',
        'Jaldi:regular,700,latin-ext,latin,devanagari' => 'Jaldi',
        'Jim+Nightshade:regular,latin-ext,latin' => 'Jim Nightshade',
        'Jockey+One:regular,latin-ext,latin' => 'Jockey One',
        'Jost:regular,300,400,500,600,700,bold' => 'Jost',
        'Jolly+Lodger:regular,latin-ext,latin' => 'Jolly Lodger',
        'Josefin+Sans:100,100italic,300,300italic,regular,italic,600,600italic,700,700italic,latin-ext,latin' => 'Josefin Sans',
        'Josefin+Slab:100,100italic,300,300italic,regular,italic,600,600italic,700,700italic,latin' => 'Josefin Slab',
        'Joti+One:regular,latin-ext,latin' => 'Joti One',
        'Judson:regular,italic,700,vietnamese,latin-ext,latin' => 'Judson',
        'Julee:regular,latin' => 'Julee',
        'Julius+Sans+One:regular,latin-ext,latin' => 'Julius Sans One',
        'Junge:regular,latin' => 'Junge',
        'Jura:300,regular,500,600,greek,latin-ext,cyrillic-ext,latin,cyrillic' => 'Jura',
        'Just+Another+Hand:regular,latin' => 'Just Another Hand',
        'Just+Me+Again+Down+Here:regular,latin-ext,latin' => 'Just Me Again Down Here',
        'Kadwa:regular,700,latin,devanagari' => 'Kadwa',
        'Kalam:300,regular,700,latin-ext,latin,devanagari' => 'Kalam',
        'Kameron:regular,700,latin' => 'Kameron',
        'Kantumruy:300,regular,700,khmer' => 'Kantumruy',
        'Karla:regular,italic,700,700italic,latin-ext,latin' => 'Karla',
        'Karma:300,regular,500,600,700,latin-ext,latin,devanagari' => 'Karma',
        'Kaushan+Script:regular,latin-ext,latin' => 'Kaushan Script',
        'Kavoon:regular,latin-ext,latin' => 'Kavoon',
        'Kdam+Thmor:regular,khmer' => 'Kdam Thmor',
        'Keania+One:regular,latin-ext,latin' => 'Keania One',
        'Kelly+Slab:regular,latin-ext,latin,cyrillic' => 'Kelly Slab',
        'Kenia:regular,latin' => 'Kenia',
        'Khand:300,regular,500,600,700,latin-ext,latin,devanagari' => 'Khand',
        'Khmer:regular,khmer' => 'Khmer',
        'Khula:300,regular,600,700,800,latin-ext,latin,devanagari' => 'Khula',
        'Kite+One:regular,latin' => 'Kite One',
        'Knewave:regular,latin-ext,latin' => 'Knewave',
        'Kotta+One:regular,latin-ext,latin' => 'Kotta One',
        'Koulen:regular,khmer' => 'Koulen',
        'Kranky:regular,latin' => 'Kranky',
        'Kreon:300,regular,700,latin' => 'Kreon',
        'Kristi:regular,latin' => 'Kristi',
        'Krona+One:regular,latin-ext,latin' => 'Krona One',
        'Kurale:regular,latin-ext,latin,cyrillic,devanagari' => 'Kurale',
        'La+Belle+Aurore:regular,latin' => 'La Belle Aurore',
        'Laila:300,regular,500,600,700,latin-ext,latin,devanagari' => 'Laila',
        'Lakki+Reddy:regular,telugu,latin' => 'Lakki Reddy',
        'Lancelot:regular,latin-ext,latin' => 'Lancelot',
        'Lateef:regular,arabic,latin' => 'Lateef',
        'Lato:100,100italic,300,300italic,regular,italic,700,700italic,900,900italic,latin-ext,latin' => 'Lato',
        'League+Script:regular,latin' => 'League Script',
        'Leckerli+One:regular,latin' => 'Leckerli One',
        'Ledger:regular,latin-ext,latin,cyrillic' => 'Ledger',
        'Lekton:regular,italic,700,latin-ext,latin' => 'Lekton',
        'Lemon:regular,latin' => 'Lemon',
        'Libre+Baskerville:regular,italic,700,latin-ext,latin' => 'Libre Baskerville',
        'Life+Savers:regular,700,latin-ext,latin' => 'Life Savers',
        'Lilita+One:regular,latin-ext,latin' => 'Lilita One',
        'Lily+Script+One:regular,latin-ext,latin' => 'Lily Script One',
        'Limelight:regular,latin-ext,latin' => 'Limelight',
        'Linden+Hill:regular,italic,latin' => 'Linden Hill',
        'Lobster:regular,vietnamese,latin-ext,latin,cyrillic' => 'Lobster',
        'Lobster+Two:regular,italic,700,700italic,latin' => 'Lobster Two',
        'Londrina+Outline:regular,latin' => 'Londrina Outline',
        'Londrina+Shadow:regular,latin' => 'Londrina Shadow',
        'Londrina+Sketch:regular,latin' => 'Londrina Sketch',
        'Londrina+Solid:regular,latin' => 'Londrina Solid',
        'Lora:regular,italic,700,700italic,latin-ext,latin,cyrillic' => 'Lora',
        'Love+Ya+Like+A+Sister:regular,latin' => 'Love Ya Like A Sister',
        'Loved+by+the+King:regular,latin' => 'Loved by the King',
        'Lovers+Quarrel:regular,latin-ext,latin' => 'Lovers Quarrel',
        'Luckiest+Guy:regular,latin' => 'Luckiest Guy',
        'Lusitana:regular,700,latin' => 'Lusitana',
        'Lustria:regular,latin' => 'Lustria',
        'Macondo:regular,latin' => 'Macondo',
        'Macondo+Swash+Caps:regular,latin' => 'Macondo Swash Caps',
        'Magra:regular,700,latin-ext,latin' => 'Magra',
        'Maiden+Orange:regular,latin' => 'Maiden Orange',
        'Mako:regular,latin' => 'Mako',
        'Mallanna:regular,telugu,latin' => 'Mallanna',
        'Mandali:regular,telugu,latin' => 'Mandali',
        'Marcellus:regular,latin-ext,latin' => 'Marcellus',
        'Marcellus+SC:regular,latin-ext,latin' => 'Marcellus SC',
        'Marck+Script:regular,latin-ext,latin,cyrillic' => 'Marck Script',
        'Margarine:regular,latin-ext,latin' => 'Margarine',
        'Marko+One:regular,latin' => 'Marko One',
        'Marmelad:regular,latin-ext,latin,cyrillic' => 'Marmelad',
        'Martel:200,300,regular,600,700,800,900,latin-ext,latin,devanagari' => 'Martel',
        'Martel+Sans:200,300,regular,600,700,800,900,latin-ext,latin,devanagari' => 'Martel Sans',
        'Marvel:regular,italic,700,700italic,latin' => 'Marvel',
        'Mate:regular,italic,latin' => 'Mate',
        'Mate+SC:regular,latin' => 'Mate SC',
        'Maven+Pro:regular,500,700,900,latin' => 'Maven Pro',
        'McLaren:regular,latin-ext,latin' => 'McLaren',
        'Meddon:regular,latin' => 'Meddon',
        'MedievalSharp:regular,latin-ext,latin' => 'MedievalSharp',
        'Medula+One:regular,latin' => 'Medula One',
        'Megrim:regular,latin' => 'Megrim',
        'Meie+Script:regular,latin-ext,latin' => 'Meie Script',
        'Merienda:regular,700,latin-ext,latin' => 'Merienda',
        'Merienda+One:regular,latin' => 'Merienda One',
        'Merriweather:300,300italic,regular,italic,700,700italic,900,900italic,latin-ext,latin' => 'Merriweather',
        'Merriweather+Sans:300,300italic,regular,italic,700,700italic,800,800italic,latin-ext,latin' => 'Merriweather Sans',
        'Metal:regular,khmer' => 'Metal',
        'Metal+Mania:regular,latin-ext,latin' => 'Metal Mania',
        'Metamorphous:regular,latin-ext,latin' => 'Metamorphous',
        'Metrophobic:regular,latin' => 'Metrophobic',
        'Michroma:regular,latin' => 'Michroma',
        'Milonga:regular,latin-ext,latin' => 'Milonga',
        'Miltonian:regular,latin' => 'Miltonian',
        'Miltonian+Tattoo:regular,latin' => 'Miltonian Tattoo',
        'Miniver:regular,latin' => 'Miniver',
        'Miss+Fajardose:regular,latin-ext,latin' => 'Miss Fajardose',
        'Modak:regular,latin-ext,latin,devanagari' => 'Modak',
        'Modern+Antiqua:regular,latin-ext,latin' => 'Modern Antiqua',
        'Molengo:regular,latin-ext,latin' => 'Molengo',
        'Molle:italic,latin-ext,latin' => 'Molle',
        'Monda:regular,700,latin-ext,latin' => 'Monda',
        'Monofett:regular,latin' => 'Monofett',
        'Monoton:regular,latin' => 'Monoton',
        'Monsieur+La+Doulaise:regular,latin-ext,latin' => 'Monsieur La Doulaise',
        'Montaga:regular,latin' => 'Montaga',
        'Montez:regular,latin' => 'Montez',
        'Montserrat:regular,500,600,700,800,900,latin' => 'Montserrat',
        'Twinkle+Star:regular,500,600,700,800,900,latin' => 'Twinkle Star',
        'Montserrat+Subrayada:regular,700,latin' => 'Montserrat Subrayada',
        'Moul:regular,khmer' => 'Moul',
        'Moulpali:regular,khmer' => 'Moulpali',
        'Mountains+of+Christmas:regular,700,latin' => 'Mountains of Christmas',
        'Mouse+Memoirs:regular,latin-ext,latin' => 'Mouse Memoirs',
        'Mr+Bedfort:regular,latin-ext,latin' => 'Mr Bedfort',
        'Mr+Dafoe:regular,latin-ext,latin' => 'Mr Dafoe',
        'Mr+De+Haviland:regular,latin-ext,latin' => 'Mr De Haviland',
        'Mrs+Saint+Delafield:regular,latin-ext,latin' => 'Mrs Saint Delafield',
        'Mrs+Sheppards:regular,latin-ext,latin' => 'Mrs Sheppards',
        'Muli:300,300italic,regular,italic,latin' => 'Muli',
        'Mystery+Quest:regular,latin-ext,latin' => 'Mystery Quest',
        'NTR:regular,telugu,latin' => 'NTR',
        'Neucha:regular,latin,cyrillic' => 'Neucha',
        'Neuton:200,300,regular,italic,700,800,latin-ext,latin' => 'Neuton',
        'New+Rocker:regular,latin-ext,latin' => 'New Rocker',
        'News+Cycle:regular,700,latin-ext,latin' => 'News Cycle',
        'Niconne:regular,latin-ext,latin' => 'Niconne',
        'Nixie+One:regular,latin' => 'Nixie One',
        'Nobile:regular,italic,700,700italic,latin' => 'Nobile',
        'Nokora:regular,700,khmer' => 'Nokora',
        'Norican:regular,latin-ext,latin' => 'Norican',
        'Nosifer:regular,latin-ext,latin' => 'Nosifer',
        'Nothing+You+Could+Do:regular,latin' => 'Nothing You Could Do',
        'Noticia+Text:regular,italic,700,700italic,vietnamese,latin-ext,latin' => 'Noticia Text',
        'Noto+Sans:regular,italic,700,700italic,vietnamese,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic,devanagari' => 'Noto Sans',
        'Noto+Serif:regular,italic,700,700italic,vietnamese,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic' => 'Noto Serif',
        'Nova+Cut:regular,latin' => 'Nova Cut',
        'Nova+Flat:regular,latin' => 'Nova Flat',
        'Nova+Mono:regular,greek,latin' => 'Nova Mono',
        'Nova+Oval:regular,latin' => 'Nova Oval',
        'Nova+Round:regular,latin' => 'Nova Round',
        'Nova+Script:regular,latin' => 'Nova Script',
        'Nova+Slim:regular,latin' => 'Nova Slim',
        'Nova+Square:regular,latin' => 'Nova Square',
        'Numans:regular,latin' => 'Numans',
        'Nunito:300,regular,700,latin' => 'Nunito',
        'Nunito Sans:300,regular,700,latin' => 'Nunito Sans',
        'Odor+Mean+Chey:regular,khmer' => 'Odor Mean Chey',
        'Offside:regular,latin' => 'Offside',
        'Old+Standard+TT:regular,italic,700,latin' => 'Old Standard TT',
        'Oldenburg:regular,latin-ext,latin' => 'Oldenburg',
        'Oleo+Script:regular,700,latin-ext,latin' => 'Oleo Script',
        'Oleo+Script+Swash+Caps:regular,700,latin-ext,latin' => 'Oleo Script Swash Caps',
        'Open+Sans:300,300italic,regular,italic,600,600italic,700,700italic,800,800italic,vietnamese,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic' => 'Open Sans',
        'Open+Sans+Condensed:300,300italic,700,vietnamese,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic' => 'Open Sans Condensed',
        'Oranienbaum:regular,latin-ext,cyrillic-ext,latin,cyrillic' => 'Oranienbaum',
        'Orbitron:regular,500,700,900,latin' => 'Orbitron',
        'Oregano:regular,italic,latin-ext,latin' => 'Oregano',
        'Orienta:regular,latin-ext,latin' => 'Orienta',
        'Original+Surfer:regular,latin' => 'Original Surfer',
        'Oswald:300,regular,700,latin-ext,latin' => 'Oswald',
        'Over+the+Rainbow:regular,latin' => 'Over the Rainbow',
        'Overlock:regular,italic,700,700italic,900,900italic,latin-ext,latin' => 'Overlock',
        'Overlock+SC:regular,latin-ext,latin' => 'Overlock SC',
        'Ovo:regular,latin' => 'Ovo',
        'Oxygen:300,regular,700,latin-ext,latin' => 'Oxygen',
        'Oxygen+Mono:regular,latin-ext,latin' => 'Oxygen Mono',
        'PT+Mono:regular,latin-ext,cyrillic-ext,latin,cyrillic' => 'PT Mono',
        'PT+Sans:regular,italic,700,700italic,latin-ext,cyrillic-ext,latin,cyrillic' => 'PT Sans',
        'PT+Sans+Caption:regular,700,latin-ext,cyrillic-ext,latin,cyrillic' => 'PT Sans Caption',
        'PT+Sans+Narrow:regular,700,latin-ext,cyrillic-ext,latin,cyrillic' => 'PT Sans Narrow',
        'PT+Serif:regular,italic,700,700italic,latin-ext,cyrillic-ext,latin,cyrillic' => 'PT Serif',
        'PT+Serif+Caption:regular,italic,latin-ext,cyrillic-ext,latin,cyrillic' => 'PT Serif Caption',
        'Pacifico:regular,latin' => 'Pacifico',
        'Palanquin:100,200,300,regular,500,600,700,latin-ext,latin,devanagari' => 'Palanquin',
        'Palanquin+Dark:regular,500,600,700,latin-ext,latin,devanagari' => 'Palanquin Dark',
        'Paprika:regular,latin' => 'Paprika',
        'Padyakke+Expanded+One:regular,latin-ext,latin' => 'Padyakke Expanded One',
        'Passero+One:regular,latin-ext,latin' => 'Passero One',
        'Passion+One:regular,700,900,latin-ext,latin' => 'Passion One',
        'Pathway+Gothic+One:regular,latin-ext,latin' => 'Pathway Gothic One',
        'Patrick+Hand:regular,vietnamese,latin-ext,latin' => 'Patrick Hand',
        'Patrick+Hand+SC:regular,vietnamese,latin-ext,latin' => 'Patrick Hand SC',
        'Patua+One:regular,latin' => 'Patua One',
        'Paytone+One:regular,latin' => 'Paytone One',
        'Peddana:regular,telugu,latin' => 'Peddana',
        'Peralta:regular,latin-ext,latin' => 'Peralta',
        'Permanent+Marker:regular,latin' => 'Permanent Marker',
        'Petit+Formal+Script:regular,latin-ext,latin' => 'Petit Formal Script',
        'Petrona:regular,latin' => 'Petrona',
        'Philosopher:regular,italic,700,700italic,latin,cyrillic' => 'Philosopher',
        'Piedra:regular,latin-ext,latin' => 'Piedra',
        'Pinyon+Script:regular,latin' => 'Pinyon Script',
        'Pirata+One:regular,latin-ext,latin' => 'Pirata One',
        'Plaster:regular,latin-ext,latin' => 'Plaster',
        'Play:regular,700,greek,latin-ext,cyrillic-ext,latin,cyrillic' => 'Play',
        'Playball:regular,latin-ext,latin' => 'Playball',
        'Playfair+Display:regular,italic,700,700italic,900,900italic,latin-ext,latin,cyrillic' => 'Playfair Display',
        'Playfair+Display+SC:regular,italic,700,700italic,900,900italic,latin-ext,latin,cyrillic' => 'Playfair Display SC',
        'Podkova:regular,700,latin' => 'Podkova',
        'Poiret+One:regular,latin-ext,latin,cyrillic' => 'Poiret One',
        'Poller+One:regular,latin' => 'Poller One',
        'Poly:regular,italic,latin' => 'Poly',
        'Pompiere:regular,latin' => 'Pompiere',
        'Pontano+Sans:regular,latin-ext,latin' => 'Pontano Sans',
        'Poppins:300,regular,500,600,700,latin-ext,latin,devanagari' => 'Poppins',
        'Port+Lligat+Sans:regular,latin' => 'Port Lligat Sans',
        'Port+Lligat+Slab:regular,latin' => 'Port Lligat Slab',
        'Pragati+Narrow:regular,700,latin-ext,latin,devanagari' => 'Pragati Narrow',
        'Prata:regular,latin' => 'Prata',
        'Preahvihear:regular,khmer' => 'Preahvihear',
        'Press+Start+2P:regular,greek,latin-ext,latin,cyrillic' => 'Press Start 2P',
        'Princess+Sofia:regular,latin-ext,latin' => 'Princess Sofia',
        'Prociono:regular,latin' => 'Prociono',
        'Prosto+One:regular,latin-ext,latin,cyrillic' => 'Prosto One',
        'Puritan:regular,italic,700,700italic,latin' => 'Puritan',
        'Purple+Purse:regular,latin-ext,latin' => 'Purple Purse',
        'Quando:regular,latin-ext,latin' => 'Quando',
        'Quantico:regular,italic,700,700italic,latin' => 'Quantico',
        'Quattrocento:regular,700,latin-ext,latin' => 'Quattrocento',
        'Quattrocento+Sans:regular,italic,700,700italic,latin-ext,latin' => 'Quattrocento Sans',
        'Questrial:regular,latin' => 'Questrial',
        'Quicksand:300,regular,700,latin' => 'Quicksand',
        'Quintessential:regular,latin-ext,latin' => 'Quintessential',
        'Qwigley:regular,latin-ext,latin' => 'Qwigley',
        'Racing+Sans+One:regular,latin-ext,latin' => 'Racing Sans One',
        'Radley:regular,italic,latin-ext,latin' => 'Radley',
        'Radio+Canada:300,regular,500,600,700,latin-ext,latin,devanagari' => 'Radio Canada',
        'Rampart+One:100,200,300,regular,500,600,700,800,900,latin' => 'Rampart One',
        'Raleway+Dots:regular,latin-ext,latin' => 'Raleway Dots',
        'Ramabhadra:regular,telugu,latin' => 'Ramabhadra',
        'Ramaraja:regular,telugu,latin' => 'Ramaraja',
        'Rambla:regular,italic,700,700italic,latin-ext,latin' => 'Rambla',
        'Rammetto+One:regular,latin-ext,latin' => 'Rammetto One',
        'Ranchers:regular,latin-ext,latin' => 'Ranchers',
        'Rancho:regular,latin' => 'Rancho',
        'Ranga:regular,700,latin-ext,latin,devanagari' => 'Ranga',
        'Rationale:regular,latin' => 'Rationale',
        'Ravi+Prakash:regular,telugu,latin' => 'Ravi Prakash',
        'Redressed:regular,latin' => 'Redressed',
        'Reenie+Beanie:regular,latin' => 'Reenie Beanie',
        'Revalia:regular,latin-ext,latin' => 'Revalia',
        'Rhodium+Libre:regular,latin-ext,latin,devanagari' => 'Rhodium Libre',
        'Ribeye:regular,latin-ext,latin' => 'Ribeye',
        'Ribeye+Marrow:regular,latin-ext,latin' => 'Ribeye Marrow',
        'Righteous:regular,latin-ext,latin' => 'Righteous',
        'Risque:regular,latin-ext,latin' => 'Risque',
        'Roboto:100,100italic,300,300italic,regular,italic,500,500italic,700,700italic,900,900italic,vietnamese,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic' => 'Roboto',
        'Roboto+Condensed:300,300italic,regular,italic,700,700italic,vietnamese,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic' => 'Roboto Condensed',
        'Roboto+Mono:100,100italic,300,300italic,regular,italic,500,500italic,700,700italic,vietnamese,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic' => 'Roboto Mono',
        'Roboto+Slab:100,300,regular,700,vietnamese,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic' => 'Roboto Slab',
        'Rochester:regular,latin' => 'Rochester',
        'Rock+Salt:regular,latin' => 'Rock Salt',
        'Rokkitt:regular,700,latin' => 'Rokkitt',
        'Romanesco:regular,latin-ext,latin' => 'Romanesco',
        'Ropa+Sans:regular,italic,latin-ext,latin' => 'Ropa Sans',
        'Rosario:regular,italic,700,700italic,latin' => 'Rosario',
        'Rosarivo:regular,italic,latin-ext,latin' => 'Rosarivo',
        'Rouge+Script:regular,latin' => 'Rouge Script',
        'Rozha+One:regular,latin-ext,latin,devanagari' => 'Rozha One',
        'Rubik:300,300italic,regular,italic,500,500italic,700,700italic,900,900italic,latin-ext,latin,cyrillic' => 'Rubik',
        'Rubik+Mono+One:regular,latin-ext,latin,cyrillic' => 'Rubik Mono One',
        'Rubik+One:regular,latin-ext,latin,cyrillic' => 'Rubik One',
        'Ruda:regular,700,900,latin-ext,latin' => 'Ruda',
        'Rufina:regular,700,latin-ext,latin' => 'Rufina',
        'Ruge+Boogie:regular,latin-ext,latin' => 'Ruge Boogie',
        'Ruluko:regular,latin-ext,latin' => 'Ruluko',
        'Rum+Raisin:regular,latin-ext,latin' => 'Rum Raisin',
        'Ruslan+Display:regular,latin-ext,latin,cyrillic' => 'Ruslan Display',
        'Russo+One:regular,latin-ext,latin,cyrillic' => 'Russo One',
        'Ruthie:regular,latin-ext,latin' => 'Ruthie',
        'Rye:regular,latin-ext,latin' => 'Rye',
        'Sacramento:regular,latin-ext,latin' => 'Sacramento',
        'Sahitya:regular,700,latin,devanagari' => 'Sahitya',
        'Sail:regular,latin' => 'Sail',
        'Salsa:regular,latin' => 'Salsa',
        'Sanchez:regular,italic,latin-ext,latin' => 'Sanchez',
        'Sancreek:regular,latin-ext,latin' => 'Sancreek',
        'Sansita+One:regular,latin' => 'Sansita One',
        'Sarala:regular,700,latin-ext,latin,devanagari' => 'Sarala',
        'Sarina:regular,latin-ext,latin' => 'Sarina',
        'Sarpanch:regular,500,600,700,800,900,latin-ext,latin,devanagari' => 'Sarpanch',
        'Satisfy:regular,latin' => 'Satisfy',
        'Scada:regular,italic,700,700italic,latin-ext,latin,cyrillic' => 'Scada',
        'Scheherazade:regular,700,arabic,latin' => 'Scheherazade',
        'Schoolbell:regular,latin' => 'Schoolbell',
        'Seaweed+Script:regular,latin-ext,latin' => 'Seaweed Script',
        'Sevillana:regular,latin-ext,latin' => 'Sevillana',
        'Seymour+One:regular,latin-ext,latin,cyrillic' => 'Seymour One',
        'Shadows+Into+Light:regular,latin' => 'Shadows Into Light',
        'Shadows+Into+Light+Two:regular,latin-ext,latin' => 'Shadows Into Light Two',
        'Shanti:regular,latin' => 'Shanti',
        'Share:regular,italic,700,700italic,latin-ext,latin' => 'Share',
        'Share+Tech:regular,latin' => 'Share Tech',
        'Share+Tech+Mono:regular,latin' => 'Share Tech Mono',
        'Shojumaru:regular,latin-ext,latin' => 'Shojumaru',
        'Short+Stack:regular,latin' => 'Short Stack',
        'Siemreap:regular,khmer' => 'Siemreap',
        'Sigmar+One:regular,latin' => 'Sigmar One',
        'Signika:300,regular,600,700,latin-ext,latin' => 'Signika',
        'Signika+Negative:300,regular,600,700,latin-ext,latin' => 'Signika Negative',
        'Simonetta:regular,italic,900,900italic,latin-ext,latin' => 'Simonetta',
        'Sintony:regular,700,latin-ext,latin' => 'Sintony',
        'Sirin+Stencil:regular,latin' => 'Sirin Stencil',
        'Six+Caps:regular,latin' => 'Six Caps',
        'Skranji:regular,700,latin-ext,latin' => 'Skranji',
        'Slabo+13px:regular,latin-ext,latin' => 'Slabo 13px',
        'Slabo+27px:regular,latin-ext,latin' => 'Slabo 27px',
        'Slackey:regular,latin' => 'Slackey',
        'Smokum:regular,latin' => 'Smokum',
        'Smythe:regular,latin' => 'Smythe',
        'Sniglet:regular,800,latin-ext,latin' => 'Sniglet',
        'Snippet:regular,latin' => 'Snippet',
        'Snowburst+One:regular,latin-ext,latin' => 'Snowburst One',
        'Sofadi+One:regular,latin' => 'Sofadi One',
        'Sofia:regular,latin' => 'Sofia',
        'Sonsie+One:regular,latin-ext,latin' => 'Sonsie One',
        'Sorts+Mill+Goudy:regular,italic,latin-ext,latin' => 'Sorts Mill Goudy',
        'Source+Code+Pro:200,300,regular,500,600,700,900,latin-ext,latin' => 'Source Code Pro',
        'Source+Sans+Pro:200,200italic,300,300italic,regular,italic,600,600italic,700,700italic,900,900italic,vietnamese,latin-ext,latin' => 'Source Sans Pro',
        'Source+Serif+Pro:regular,600,700,latin-ext,latin' => 'Source Serif Pro',
        'Special+Elite:regular,latin' => 'Special Elite',
        'Spicy+Rice:regular,latin' => 'Spicy Rice',
        'Spinnaker:regular,latin-ext,latin' => 'Spinnaker',
        'Spirax:regular,latin' => 'Spirax',
        'Squada+One:regular,latin' => 'Squada One',
        'Sree+Krushnadevaraya:regular,telugu,latin' => 'Sree Krushnadevaraya',
        'Stalemate:regular,latin-ext,latin' => 'Stalemate',
        'Stalinist+One:regular,latin-ext,latin,cyrillic' => 'Stalinist One',
        'Stardos+Stencil:regular,700,latin' => 'Stardos Stencil',
        'Stint+Ultra+Condensed:regular,latin-ext,latin' => 'Stint Ultra Condensed',
        'Stint+Ultra+Expanded:regular,latin-ext,latin' => 'Stint Ultra Expanded',
        'Stoke:300,regular,latin-ext,latin' => 'Stoke',
        'Strait:regular,latin' => 'Strait',
        'Sue+Ellen+Francisco:regular,latin' => 'Sue Ellen Francisco',
        'Sumana:regular,700,latin-ext,latin,devanagari' => 'Sumana',
        'Sunshiney:regular,latin' => 'Sunshiney',
        'Supermercado+One:regular,latin' => 'Supermercado One',
        'Sura:regular,700,latin-ext,latin,devanagari' => 'Sura',
        'Suranna:regular,telugu,latin' => 'Suranna',
        'Suravaram:regular,telugu,latin' => 'Suravaram',
        'Suwannaphum:regular,khmer' => 'Suwannaphum',
        'Swanky+and+Moo+Moo:regular,latin' => 'Swanky and Moo Moo',
        'Syncopate:regular,700,latin' => 'Syncopate',
        'Tangerine:regular,700,latin' => 'Tangerine',
        'Taprom:regular,khmer' => 'Taprom',
        'Tauri:regular,latin-ext,latin' => 'Tauri',
        'Teko:300,regular,500,600,700,latin-ext,latin,devanagari' => 'Teko',
        'Telex:regular,latin' => 'Telex',
        'Tenali+Ramakrishna:regular,telugu,latin' => 'Tenali Ramakrishna',
        'Tenor+Sans:regular,latin-ext,latin,cyrillic' => 'Tenor Sans',
        'Text+Me+One:regular,latin-ext,latin' => 'Text Me One',
        'The+Girl+Next+Door:regular,latin' => 'The Girl Next Door',
        'Tienne:regular,700,900,latin' => 'Tienne',
        'Tillana:regular,500,600,700,800,latin-ext,latin,devanagari' => 'Tillana',
        'Timmana:regular,telugu,latin' => 'Timmana',
        'Tinos:regular,italic,700,700italic,vietnamese,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic,hebrew' => 'Tinos',
        'Titan+One:regular,latin-ext,latin' => 'Titan One',
        'Titillium+Web:200,200italic,300,300italic,regular,italic,600,600italic,700,700italic,900,latin-ext,latin' => 'Titillium Web',
        'Trade+Winds:regular,latin' => 'Trade Winds',
        'Trocchi:regular,latin-ext,latin' => 'Trocchi',
        'Trochut:regular,italic,700,latin' => 'Trochut',
        'Trykker:regular,latin-ext,latin' => 'Trykker',
        'Tulpen+One:regular,latin' => 'Tulpen One',
        'Ubuntu:300,300italic,regular,italic,500,500italic,700,700italic,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic' => 'Ubuntu',
        'Ubuntu+Condensed:regular,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic' => 'Ubuntu Condensed',
        'Ubuntu+Mono:regular,italic,700,700italic,greek,latin-ext,greek-ext,cyrillic-ext,latin,cyrillic' => 'Ubuntu Mono',
        'Ultra:regular,latin' => 'Ultra',
        'Uncial+Antiqua:regular,latin' => 'Uncial Antiqua',
        'Underdog:regular,latin-ext,latin,cyrillic' => 'Underdog',
        'Unica+One:regular,latin-ext,latin' => 'Unica One',
        'UnifrakturCook:700,latin' => 'UnifrakturCook',
        'UnifrakturMaguntia:regular,latin' => 'UnifrakturMaguntia',
        'Unkempt:regular,700,latin' => 'Unkempt',
        'Unlock:regular,latin' => 'Unlock',
        'Unna:regular,latin' => 'Unna',
        'VT323:regular,latin' => 'VT323',
        'Vampiro+One:regular,latin-ext,latin' => 'Vampiro One',
        'Varela:regular,latin-ext,latin' => 'Varela',
        'Varela+Round:regular,latin' => 'Varela Round',
        'Vast+Shadow:regular,latin' => 'Vast Shadow',
        'Vesper+Libre:regular,500,700,900,latin-ext,latin,devanagari' => 'Vesper Libre',
        'Vibur:regular,latin' => 'Vibur',
        'Vidaloka:regular,latin' => 'Vidaloka',
        'Viga:regular,latin-ext,latin' => 'Viga',
        'Voces:regular,latin-ext,latin' => 'Voces',
        'Volkhov:regular,italic,700,700italic,latin' => 'Volkhov',
        'Vollkorn:regular,italic,700,700italic,latin' => 'Vollkorn',
        'Voltaire:regular,latin' => 'Voltaire',
        'Waiting+for+the+Sunrise:regular,latin' => 'Waiting for the Sunrise',
        'Wallpoet:regular,latin' => 'Wallpoet',
        'Walter+Turncoat:regular,latin' => 'Walter Turncoat',
        'Warnes:regular,latin-ext,latin' => 'Warnes',
        'Wellfleet:regular,latin-ext,latin' => 'Wellfleet',
        'Wendy+One:regular,latin-ext,latin' => 'Wendy One',
        'Wire+One:regular,latin' => 'Wire One',
        'Work+Sans:100,200,300,regular,500,600,700,800,900,latin-ext,latin' => 'Work Sans',
        'Yanone+Kaffeesatz:200,300,regular,700,latin-ext,latin' => 'Yanone Kaffeesatz',
        'Yantramanav:100,300,regular,500,700,900,latin-ext,latin,devanagari' => 'Yantramanav',
        'Yellowtail:regular,latin' => 'Yellowtail',
        'Yeseva+One:regular,latin-ext,latin,cyrillic' => 'Yeseva One',
        'Yesteryear:regular,latin' => 'Yesteryear',
        'Zeyada:regular,latin' => 'Zeyada'
    );

    return apply_filters('meeeksaas_googlefonts', $google_fonts_list);
}

if (!function_exists('meeeksaas_create_page_views_table')) {
    function meeeksaas_create_page_views_table() {
        global $wpdb;

        $table_name = $wpdb->prefix . 'meeeksaas_page_views';

        $charset_collate = $wpdb->get_charset_collate();

        $sql = "CREATE TABLE IF NOT EXISTS $table_name (
            id INT AUTO_INCREMENT PRIMARY KEY,
            page_id INT NOT NULL,
            link VARCHAR(255) NOT NULL,
            view_date DATE NOT NULL,
            views_count INT NOT NULL DEFAULT 1
        ) $charset_collate;";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
    }
    add_action('after_setup_theme', 'meeeksaas_create_page_views_table');
}

if (!function_exists('meeeksaas_record_page_view')) {
    function meeeksaas_record_page_view($page_id) {
        global $wpdb;

        $link = get_the_permalink($page_id);

        $table_name = $wpdb->prefix . 'meeeksaas_page_views';
        $date = current_time('Y-m-d');

        $existing_record = $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE link = %s AND view_date = %s", $link, $date));

        if ($existing_record) {
            // If a record already exists for the link and date, increment the views_count
            $wpdb->update(
                $table_name,
                array('views_count' => $existing_record->views_count + 1),
                array('id' => $existing_record->id)
            );
        } else {
            // If no record exists, insert a new record
            $wpdb->insert(
                $table_name,
                array(
                    'page_id' => $page_id, 
                    'link' => $link, 
                    'view_date' => $date
                )
            );
        }
    }
}

if(!function_exists('meeeksaas_set_page_views')){
    function meeeksaas_set_page_views($page_id = ''){
        if ($page_id) {
            meeeksaas_record_page_view(get_the_ID());
        }
    }
    add_action('meeeksaas_before_page_content', 'meeeksaas_set_page_views', 1);
}


if(!function_exists('meeeksaas_get_pageviews_by_date')){
    function meeeksaas_get_pageviews_by_date($page_id = '', $date = ''){
        global $wpdb;

        // Your custom table name
        $table_name = $wpdb->prefix . 'meeeksaas_page_views';

        // Page ID and view date values
        $page_id = $page_id; // Replace with your actual page ID
        $view_date = $date; // Replace with your actual view date

        // SQL query to retrieve views_count for a specific page_id and view_date
        $query = $wpdb->prepare(
            "SELECT views_count FROM $table_name WHERE page_id = %d AND view_date = %s LIMIT 1",
            $page_id,
            $view_date
        );

        // Fetch result
        $result = $wpdb->get_var($query);

        // Check if result is not empty
        if ($result !== null) {
            // $result contains the views_count value
            echo $result;
        }
    }
}


if(!function_exists('meeeksaas_get_alltime_pageviews')){
    function meeeksaas_get_alltime_pageviews($page_id = ''){
        global $wpdb;

        // Your custom table name
        $table_name = $wpdb->prefix . 'meeeksaas_page_views';

        // Page ID and view date values
        $page_id = $page_id; // Replace with your actual page ID

        // SQL query to retrieve views_count for a specific page_id and view_date
        $query = $wpdb->prepare(
            "SELECT SUM(`views_count`) from $table_name WHERE `page_id` LIKE %d",
            $page_id
        );

        // Fetch result
        $result = $wpdb->get_var($query);

        // Check if result is not empty
        if ($result !== null) {
            // $result contains the views_count value
            echo $result;
        }else{
            echo '0';
        }
    }
}

if(!function_exists('meeeksaas_get_pageviews_by_month')){
    function meeeksaas_get_pageviews_by_month($page_id = '', $month = '', $year = ''){
        global $wpdb;

        // Your custom table name
        $table_name = $wpdb->prefix . 'meeeksaas_page_views';

        $page_id = $page_id;
        $month = $month;
        $year = $year;

        // SQL query to retrieve views_count for a specific page_id and view_date
        $query = $wpdb->prepare(
            "SELECT view_date as day, views_count as views FROM ( SELECT view_date, views_count FROM $table_name WHERE page_id = %d AND view_date BETWEEN DATE_SUB(CURDATE(), INTERVAL 1 MONTH) AND CURDATE() ) AS subquery GROUP BY view_date ORDER BY view_date ASC",
            $page_id,
        );

        // Fetch result
        $results = $wpdb->get_results($query, ARRAY_A);
        // Check if result is not empty
        if ($results !== null) {

            // Create an associative array with dates as keys
            $date_views = array_column($results, 'views', 'day');

            // Create an array of the last 30 days
            $date_range = array_map(
                function ($i) {
                    return date('Y-m-d', strtotime("-{$i} days"));
                },
                range(0, 29)
            );

            // Fill in missing days with 0 views
            $complete_data = array_map(
                function ($date) use ($date_views) {
                    return [
                        'day' => $date,
                        'views' => isset($date_views[$date]) ? $date_views[$date] : 0,
                    ];
                },
                $date_range
            );

            // Sort the final array ascending by date
            usort($complete_data, function ($a, $b) {
                return strtotime($a['day']) - strtotime($b['day']);
            });

            // $result contains the views_count value
            return json_encode($complete_data);
        }
    }
}


// Function to render Metrics chart
if(!function_exists('meeeksaas_metrics_chart')){
    function meeeksaas_metrics_chart($page_id = '') {

        $id = $page_id;
        $year = date('Y');
        $month = date('m');

        $footer_text = esc_html__('The page is not published yet! As soon as it gets live, metrics will be listed here.', 'meeeksaas');
        if ($page_id) {
            $footer_text = esc_html__('*Pageviews represent the total number of times a webpage has been viewed.', 'meeeksaas');
        }
        ?>
        <fieldset class="meeeksaas-metrics border p-2 relative">
            <legend class="float-none w-auto"><?php esc_html_e('Page Metrics (Past 30 days)', 'meeeksaas'); ?></legend>
            <div id="meeeksaas-metrics"></div>
            <p><i><?php echo esc_html($footer_text); ?></i></p>
            <?php do_action('meeeksaas_builder_allow_metrics'); ?>
        </fieldset>
        <?php

        if ($page_id) { ?>
            <script type="text/javascript">
                jQuery( document ).ready(function() {
                    function meeeksaas_page_metrics_chart(){
                        var data_json = <?php echo meeeksaas_get_pageviews_by_month($id, $year, $month); ?>;
                        new Morris.Area({
                            element: 'meeeksaas-metrics',
                            parseTime: false,
                            data: data_json,
                            xkey: 'day',
                            ykeys: ['views'],
                            labels: ['Visits'],
                            lineColors: ['#A855F7'],
                            fillOpacity: '0.2',
                            lineWidth: 3,
                            // ymax: 'auto 100',
                            gridLineColor: '#F3E8FF',
                            gridStrokeWidth: 1,
                            gridTextSize: 11,
                            hideHover: 'auto',
                            resize: true
                        });
                    }
                    var analytics = jQuery('.meeek-nav-tabs button[data-attr-val="analytics"]');
                    if (!analytics.hasClass("active")) {
                        jQuery('.meeek-nav-tabs button[data-attr-val="analytics"]').on('click', function() {
                            if ( jQuery('#meeeksaas-metrics').length){
                                meeeksaas_page_metrics_chart();
                            }
                        });
                    }else{
                        if ( jQuery('#meeeksaas-metrics').length){
                            meeeksaas_page_metrics_chart();
                        }
                    }
                });
            </script>
            <?php
        }
    }
    add_action( 'meeeksaas_builder_analytics_tab', 'meeeksaas_metrics_chart', 1); // For back-end
}


/**
* Package Benefits list override (from the SaaS module)
*
*/
if (!function_exists('meeeksaas_paypal_donation_prices')) {
    function meeeksaas_paypal_donation_prices(){
        $donation_prices = array(
            '10',
            '20',
            '30',
            '50',
            '100',
        );
        return apply_filters('meeeksaas_paypal_donation_prices', $donation_prices);
    }
}


/**
* Expired plan notice
*
*/
if (!function_exists('meeeksaas_expired_plans_notice')) {
    function meeeksaas_expired_plans_notice(){
        ob_start(); ?>
        
        <?php
        $settings = get_option('mt-saas-settings');
        if($settings){
            $content = ((array_key_exists('meeeksaas_expired_plans_content', $settings))?$settings['meeeksaas_expired_plans_content']:"");
            ?>
            <?php if(!$content){ ?>
                <div class="alert alert-warning" role="alert">
                    <h4 class="alert-heading"><?php esc_html_e('Subscription Expired!', 'meeeksaas'); ?></h4>
                    <p><?php esc_html_e('If you are the owner of this bio links page, please renew your subscription and the page will be automatically re-activated.', 'meeeksaas'); ?></p>
                    <hr>
                    <p class="mb-0">@<?php echo get_bloginfo(); ?></p>
                </div>
            <?php }else{ ?>
                <?php echo $content; ?>
            <?php } ?>
        <?php } ?>

        <?php return ob_get_clean();
    }
}


function meeeksaas_white_label_links($button){
    
    $element = $button['btn_type'];

    $links = array(
        'youtube' => array(
            'text' => esc_html__('Check the supported', 'meeeksaas'),
            'link_text' => esc_html__('Link Types List', 'meeeksaas'),
            'link' => 'https://docs.modeltheme.com/meeek-saas/#youtube',
        ),
        'twitter' => array(
            'text' => esc_html__('Check the supported', 'meeeksaas'),
            'link_text' => esc_html__('Link Types List', 'meeeksaas'),
            'link' => 'https://docs.modeltheme.com/meeek-saas/#twitter',
        ),
        'tiktok' => array(
            'text' => esc_html__('Check the supported', 'meeeksaas'),
            'link_text' => esc_html__('Link Types List', 'meeeksaas'),
            'link' => 'https://docs.modeltheme.com/meeek-saas/#tiktok',
        ),
        'facebook' => array(
            'text' => esc_html__('Check the supported', 'meeeksaas'),
            'link_text' => esc_html__('Link Types List', 'meeeksaas'),
            'link' => 'https://docs.modeltheme.com/meeek-saas/#facebook',
        ),
        'spotify' => array(
            'text' => esc_html__('Check the supported', 'meeeksaas'),
            'link_text' => esc_html__('Link Types List', 'meeeksaas'),
            'link' => 'https://docs.modeltheme.com/meeek-saas/#spotify',
        ),
        'header' => array(
            'text' => '',
            'link_text' => '',
            'link' => '',
        ),
        'paypal' => array(
            'text' => esc_html__('Add a link when the donation popup is disabled or a PayPal email when the popup donation is enabled.', 'meeeksaas'),
            'link_text' => '',
            'link' => '',
        ),
        'venmo' => array(
            'text' => esc_html__('Add a link when the donation popup is disabled or a PayPal email when the popup donation is enabled.', 'meeeksaas'),
            'link_text' => '',
            'link' => '',
        ),
        'phone' => array(
            'text' => esc_html__('If the WhatsApp is selected please enter the WhatsApp number without any "-" or spaces. Example: 43534534534.', 'meeeksaas'),
            'link_text' => '',
            'link' => '',
        ),
        'dropdown' => array(
            'text' => '',
            'link_text' => '',
            'link' => '',
        ),
        'blog' => array(
            'text' => '',
            'link_text' => '',
            'link' => '',
        ),
        'shortcode' => array(
            'text' => esc_html__('A full list of available shortcodes should be provided by the website.', 'meeeksaas'),
            'link_text' => '',
            'link' => '',
        ),
        'block' => array(
            'text' => esc_html__('A full list of available blocks should be provided by the website.', 'meeeksaas'),
            'link_text' => '',
            'link' => '',
        ),
        'woocommerce' => array(
            'text' => '',
            'link_text' => '',
            'link' => '',
        ),
        'vcard' => array(
            'text' => '',
            'link_text' => '',
            'link' => '',
        ),
        //other texts
        'google-analytics' => array(
            'text' => esc_html__('Add your Google Analtyics tracking code ID (GA-4). Example: G-C72AAABBBC', 'meeeksaas'),
            'link_text' => esc_html__('Tutorial', 'meeeksaas'),
            'link' => 'https://docs.modeltheme.com/meeek-saas/#google-analytics',
        ),
        'button-label' => array(
            'text' => esc_html__('*Not all the button styles supports labels. If the label is not shown it means that the button style is not supporting labels.', 'meeeksaas'),
            'link_text' => esc_html__('Supported Options', 'meeeksaas'),
            'link' => 'https://docs.modeltheme.com/meeek-saas/#link-styles-options',
        ),

    ); 

    if (!array_key_exists($button['btn_type'], $links)) {
        return;
    }
    ?>

    <?php if(!empty($links[$element]['text'])){ ?>
        <p class="mb-0"><i><?php echo esc_html($links[$element]['text']); ?><?php if(!empty($links[$element]['link'])){ ?> <a href="<?php echo esc_url($links[$element]['link']); ?>" target="_blank"><?php echo esc_html($links[$element]['link_text']); ?></a><?php } ?></i></p>
    <?php }

}
add_action('meeeksaas_builder_after_element_fields', 'meeeksaas_white_label_links');
add_action('meeeksaas_builder_after_button_label', 'meeeksaas_white_label_links');
add_action('meeeksaas_builder_after_ga_fields', 'meeeksaas_white_label_links');



if (!function_exists('meeeksaas_kses_allowed_html')) {
    function meeeksaas_kses_allowed_html($tags, $context) {
      switch($context) {
        case 'notice':
            $tags = array(
                'span' => array(
                    'class' => array(),
                ),
            );
            return $tags;
        break;
        case 'title':
            $tags = array(
                'br' => array(),
            );
            return $tags;
        break;
        
        default: 
            return $tags;
      }
    }
    add_filter( 'wp_kses_allowed_html', 'meeeksaas_kses_allowed_html', 10, 2);
}



function meeeksaas_get_default_settings(){

    $data = array (
      'meeeksaas_sharing' => 'on',
      'meeeksaas_user_trial_benefits' => 
      array (
        0 => 'allow_branding',
        1 => 'allow_bg',
        2 => 'allow_body_bg',
        3 => 'allow_button_label',
        4 => 'allow_seo_clean_url',
        5 => 'allow_seo_clean_title',
        6 => 'allow_templates',
        7 => 'allow_bio',
        8 => 'allow_seo',
        9 => 'allow_seo_prevent_index',
        10 => 'allow_social_icons',
        11 => 'allow_qr',
        12 => 'allow_payment',
        13 => 'allow_header',
        14 => 'allow_dropdown',
        15 => 'allow_youtube',
        16 => 'allow_spotify',
        17 => 'allow_phone',
        18 => 'allow_twitter',
        19 => 'allow_facebook',
        20 => 'allow_tiktok',
        21 => 'allow_metrics',
        22 => 'allow_support',
        23 => 'allow_2step_auth',
      ),
      'meeeksaas_user_trial_status' => 'on',
      'meeeksaas_logo_width' => '80',
      'meeeksaas_css' => '.meeek-bio-links-page-2374 .meeek-bio-links-img-holder img {
            border-radius: 50% !important;
    }
    .meeek-bio-links-page-2374 .meeek-bio-links-container-v2:hover .meeek-bio-links-icon {
            color: #000;
    }
    .twitter-timeline.twitter-timeline-rendered{
        width: 100% !important;
    }',
      'meeeksaas_free_accounts_limit' => '33',
      'meeeksaas_custom_templates' => 
      array (
      ),
      'meeeksaas_builder_preview' => 'responsive',
      'meeeksaas_expired_plans_content' => '&nbsp;
    <div class="alert alert-warning" role="alert">
    <h4 class="alert-heading">Subscription Expired!</h4>
    If you are the owner of this bio links page, please renew your subscription and the page will be automatically re-activated.

    <hr />
    <p class="mb-0">@Meeek</p>

    </div>',
      'meeeksaas_splashscreen_status' => 'on',
      'meeeksaas_splashscreen_logo' => 'light',
      'meeeksaas_splashscreen_bg' => '#e9f3fd',
    );

    return $data;
}
