<?php
/**
 * Plugin Name: Meeek - SaaS Bio Links Plugin
 * Description: The 1st SaaS for Bio Links Plugin
 * Plugin URI:  https://meeek.me/
 * Version:     2.2.4
 * Author:      ModelTheme
 * Author URI:  https://meeeksaas.com/
 * Text Domain: meeeksaas
 * Domain Path: /languages/
*/


if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

include_once ABSPATH . 'wp-admin/includes/plugin.php';

// Function to run on plugin activation
function meeeksaas_plugin_activate() {
    if (get_option('mt-saas-settings') === false) {
        update_option('mt-saas-settings ', meeeksaas_get_default_settings());
    }
    // WooCommerce registration fields:
    update_option('woocommerce_enable_guest_checkout', 'no');
    update_option('woocommerce_enable_checkout_login_reminder', 'yes');
    update_option('woocommerce_enable_myaccount_registration', 'yes');
    update_option('woocommerce_registration_generate_password', 'no');
}
register_activation_hook(__FILE__, 'meeeksaas_plugin_activate');



if( is_plugin_active('meeek/meeek.php') ){
     add_action('update_option_active_plugins', 'meeeksaas_deactivate_meeek');
}
function meeeksaas_deactivate_meeek(){
   deactivate_plugins('meeek/meeek.php');
}

DEFINE('MEEEKSAAS_PLUGIN_FILE', __FILE__);
DEFINE('MEEEKSAAS_PLUGIN_URL', plugin_dir_url( __FILE__ ));
define('MEEEKSAAS_LOGO_PATH', MEEEKSAAS_PLUGIN_URL.'assets/images/logo.png');
define('MEEEKSAAS_LOGO_DARK_PATH', MEEEKSAAS_PLUGIN_URL.'assets/images/logo-dark.png');
define('MEEEKSAAS_PLUGIN_PATH', dirname(MEEEKSAAS_PLUGIN_FILE));
define('MEEEKSAAS_PLUGIN_INC', trailingslashit(path_join(MEEEKSAAS_PLUGIN_PATH, 'inc')));
define('MEEEKSAAS_PLUGIN_VIEW', trailingslashit(path_join(MEEEKSAAS_PLUGIN_PATH, 'view')));
define('MEEEKSAAS_PLUGIN_MODULES', trailingslashit(path_join(MEEEKSAAS_PLUGIN_PATH, 'modules')));
define('MEEEKSAAS_PLUGIN_ELEMENTS', trailingslashit(path_join(MEEEKSAAS_PLUGIN_INC, 'builder/elements')));
define('MEEEKSAAS_DEV_MODE', false);



add_action( 'admin_init', function () {
    remove_menu_page( 'mt-saas-settings' );
    remove_menu_page( 'post-new.php?post_type=meeek-link' );
}, 90);


global $pagenow;
$nocmb = array('user-edit.php', 'profile.php', 'nav-menus.php', 'widgets.php');
if (!in_array($pagenow, $nocmb)) {
    if ( ! class_exists( 'CMB2_Bootstrap_2101', false ) ) {
        require_once plugin_dir_path(__FILE__) .'vendor/cmb2/init.php';
    }
    if ( ! class_exists( 'CMB2_Conditionals', false ) ) {
        require_once plugin_dir_path(__FILE__) .'vendor/cmb2-conditionals/cmb2-conditionals.php';
    }

    if ( ! class_exists( 'CMB2_Post_Search_field_025', false ) ) {
        require_once plugin_dir_path(__FILE__) .'vendor/CMB2-Post-Search-field-master/cmb2_post_search_field.php';
    }
}
    

require_once('inc/admin/settings.php');
require_once('inc/admin/admin-notices.php');
require_once('inc/CPT.php');
require_once('inc/helpers.php');
require_once('inc/helpers.customizer.php');
require_once('inc/helpers.footer-toggles.php');
require_once('inc/builder/builder.php');
require_once('inc/builder/elements/inc.php');
require_once(MEEEKSAAS_PLUGIN_MODULES.'include.php');
require_once('inc/woocommerce/woocommerce.php');
require_once('view/frontend.parts.php');
require_once('view/frontend.parts.dev.php');


add_action( 'init', 'meeeksaas_load_textdomain' );
function meeeksaas_load_textdomain() {
    $domain = 'meeeksaas';
    load_plugin_textdomain( $domain, false, dirname( plugin_basename( __FILE__ ) ) . '/languages' ); 
}



add_filter('template_include', 'meeeksaas_page_template');
function meeeksaas_page_template($single_template ) {
    global $post;

    if ( is_front_page() || is_home() ) {
        // $single_template = MEEEKSAAS_PLUGIN_VIEW . 'page_template.php';
    } elseif ( isset($post->post_type) && $post->post_type === 'meeek-link' && ! is_search() ) {
        $single_template = MEEEKSAAS_PLUGIN_VIEW . 'page_template.php';
    }

    if (is_singular('meeek-link')) {

        $bio_link = get_the_ID();
        $configuration = get_post_meta( $bio_link, 'meeek_configuration', true );
        if ($configuration) {
            $seo_indexable =        ((array_key_exists('seo_indexable', $configuration))?$configuration['seo_indexable']:"off");
            if ($seo_indexable == 'on') {
                add_filter( 'wp_robots', 'wp_robots_no_robots' );
            }
        }
    }

    return $single_template;
}

function meeeksaas_enqueue_admin_scripts($hook) {
    $hooks = array(
        'admin_page_meeek-page-builder',
        'meeek-link_page_mt-activator',
        'toplevel_page_mt-saas-settings',
        'meeek-link_page_pricing',
        'meeek-link_page_mt-saas-regular-vs-extended',
        'meeek-link_page_mt-saas-docs',
    );

    if (in_array($hook, $hooks)) {
        wp_enqueue_style('bootstrap', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrap/css/bootstrap.min.css');
        wp_enqueue_style('meeek-custom', MEEEKSAAS_PLUGIN_URL . 'assets/custom-style.css');
    }

    if ($hook == 'admin_page_meeek-page-builder') {
        // CSS
        wp_enqueue_style('meeek-custom', MEEEKSAAS_PLUGIN_URL . 'assets/custom-style.css');
        wp_enqueue_style('bootstrap', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrap/css/bootstrap.min.css');
        wp_enqueue_style('bootstrap-icons', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrap/font/bootstrap-icons.min.css');
        wp_enqueue_style('fontawesome', 'https://use.fontawesome.com/releases/v6.5.1/css/all.css');
        wp_enqueue_style('bootstrapicon-iconpicker', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrapicon-iconpicker/bootstrapicons-iconpicker.min.css');
        wp_enqueue_style('select2', MEEEKSAAS_PLUGIN_URL . 'vendor/select2/select2.min.css');
        wp_enqueue_style('jquery-datetimepicker', MEEEKSAAS_PLUGIN_URL . 'vendor/jquery.datetimepicker/jquery.datetimepicker.min.css');
        wp_enqueue_style('coloris', MEEEKSAAS_PLUGIN_URL . 'vendor/coloris/coloris.min.css');
        wp_enqueue_style('morrisjs', MEEEKSAAS_PLUGIN_URL . 'vendor/morrisjs/morris.min.css');

        // JS
        wp_enqueue_media();
        wp_enqueue_script('bootstrap', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrap/js/bootstrap.bundle.min.js', array('jquery'), '5.3.0', true);
        wp_enqueue_script('gianniAccordion', MEEEKSAAS_PLUGIN_URL . 'vendor/gianniAccordion/gianniAccordion.min.js', array('jquery'), '1.0.0', true);
        wp_enqueue_script('jquery-repeater', MEEEKSAAS_PLUGIN_URL . 'vendor/jquery.repeater/jquery.repeater.min.js', array('jquery'), '1.2.2', true);
        wp_enqueue_script('bootstrapicon-iconpicker', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrapicon-iconpicker/bootstrapicon-iconpicker.js', array('jquery'), '1.10.0', true);
        wp_enqueue_script('select2', MEEEKSAAS_PLUGIN_URL . 'vendor/select2/select2.full.min.js', array('jquery'), '4.0.3', true);
        wp_enqueue_script('jquery-datetimepicker', MEEEKSAAS_PLUGIN_URL . 'vendor/jquery.datetimepicker/jquery.datetimepicker.full.min.js', array('jquery'), '1.0.0', true);
        wp_enqueue_script('coloris', MEEEKSAAS_PLUGIN_URL . 'vendor/coloris/coloris.min.js', array('jquery'), '1.0.0', true);
        wp_enqueue_script('raphael', MEEEKSAAS_PLUGIN_URL . 'vendor/raphael/raphael.min.js', array('jquery'), '1.0.0', true);
        wp_enqueue_script('morrisjs', MEEEKSAAS_PLUGIN_URL . 'vendor/morrisjs/morris.min.js', array('jquery'), '0.5.0', true);
        wp_enqueue_script('jquery-ui-touch-punch', '//cdnjs.cloudflare.com/ajax/libs/jqueryui-touch-punch/0.2.3/jquery.ui.touch-punch.min.js', array('jquery'), '0.2.3', true);
        $script_data_array = array(
            'url' => admin_url( 'admin-ajax.php' ),
            'nonce' => wp_create_nonce( 'meeek_import_element' )
        );
        wp_enqueue_script('meeek-custom', MEEEKSAAS_PLUGIN_URL . 'assets/custom-scripts.js', array('jquery'), '1.0', true);
        wp_localize_script( 'meeek-custom', 'meeeksaas_builder_ajax', $script_data_array );
    }
}
add_action('admin_enqueue_scripts', 'meeeksaas_enqueue_admin_scripts');


function meeeksaas_frontend_enqueue_scripts() {

    $builder_endpoints = array(
        'bio-link-builder',
        'my-link-pages'
    );

    global $wp;
    $current_vars = $wp->query_vars;

    if ( class_exists( 'WooCommerce' ) && is_account_page() ) {

        $builder_url = wc_get_account_endpoint_url('bio-link-builder');
        $links_page_url = wc_get_account_endpoint_url('my-link-pages');
        
        if(array_key_exists('bio-link-builder', $current_vars) || array_key_exists('my-link-pages', $current_vars) || array_key_exists('pricing-plan', $current_vars)){
            // CSS
            wp_enqueue_style('meeek-custom', MEEEKSAAS_PLUGIN_URL . 'assets/custom-style.css');
            wp_enqueue_style('bootstrap', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrap/css/bootstrap.min.css');
            wp_enqueue_style('bootstrap-icons', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrap/font/bootstrap-icons.min.css');
            wp_enqueue_style('fontawesome', 'https://use.fontawesome.com/releases/v6.5.1/css/all.css');
            wp_enqueue_style('bootstrapicon-iconpicker', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrapicon-iconpicker/bootstrapicons-iconpicker.min.css');
            wp_enqueue_style('select2', MEEEKSAAS_PLUGIN_URL . 'vendor/select2/select2.min.css');
            wp_enqueue_style('jquery-datetimepicker', MEEEKSAAS_PLUGIN_URL . 'vendor/jquery.datetimepicker/jquery.datetimepicker.min.css');
            wp_enqueue_style('coloris', MEEEKSAAS_PLUGIN_URL . 'vendor/coloris/coloris.min.css');
            wp_enqueue_style('morrisjs', MEEEKSAAS_PLUGIN_URL . 'vendor/morrisjs/morris.min.css');

            // JS
            wp_enqueue_media();
            wp_enqueue_script('bootstrap', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrap/js/bootstrap.bundle.min.js', array('jquery'), '5.3.0', true);
            wp_enqueue_script('gianniAccordion', MEEEKSAAS_PLUGIN_URL . 'vendor/gianniAccordion/gianniAccordion.min.js', array('jquery'), '1.0.0', true);
            wp_enqueue_script('jquery-repeater', MEEEKSAAS_PLUGIN_URL . 'vendor/jquery.repeater/jquery.repeater.min.js', array('jquery'), '1.2.2', true);
            wp_enqueue_script('bootstrapicon-iconpicker', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrapicon-iconpicker/bootstrapicon-iconpicker.js', array('jquery'), '1.10.0', true);
            wp_enqueue_script('select2', MEEEKSAAS_PLUGIN_URL . 'vendor/select2/select2.full.min.js', array('jquery'), '4.0.3', true);
            wp_enqueue_script('jquery-datetimepicker', MEEEKSAAS_PLUGIN_URL . 'vendor/jquery.datetimepicker/jquery.datetimepicker.full.min.js', array('jquery'), '1.0.0', true);
            wp_enqueue_script('coloris', MEEEKSAAS_PLUGIN_URL . 'vendor/coloris/coloris.min.js', array('jquery'), '1.0.0', true);
            wp_enqueue_script('raphael', MEEEKSAAS_PLUGIN_URL . 'vendor/raphael/raphael.min.js', array('jquery'), '1.0.0', true);
            wp_enqueue_script('morrisjs', MEEEKSAAS_PLUGIN_URL . 'vendor/morrisjs/morris.min.js', array('jquery'), '0.5.0', true);
            wp_enqueue_script('jquery-ui-touch-punch', '//cdnjs.cloudflare.com/ajax/libs/jqueryui-touch-punch/0.2.3/jquery.ui.touch-punch.min.js', array('jquery'), '0.2.3', true);
            $script_data_array = array(
                'url' => admin_url( 'admin-ajax.php' ),
                'nonce' => wp_create_nonce( 'meeek_import_element' )
            );
            wp_enqueue_script('meeek-custom', MEEEKSAAS_PLUGIN_URL . 'assets/custom-scripts.js', array('jquery'), '1.0', true);
            wp_localize_script( 'meeek-custom', 'meeeksaas_builder_ajax', $script_data_array );
        }
    }
    if (is_singular('meeek-link')) {
        wp_enqueue_script('gianniAccordion', MEEEKSAAS_PLUGIN_URL . 'vendor/gianniAccordion/gianniAccordion.min.js', array('jquery'), '1.0.0', true);
        wp_enqueue_style('bootstrap', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrap/css/bootstrap.min.css');
        wp_enqueue_style('meeeksaas-custom-template-style', MEEEKSAAS_PLUGIN_URL . 'assets/custom-template-style.css');
        wp_enqueue_style('bootstrap-icons', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrap/font/bootstrap-icons.min.css');
        wp_enqueue_style('fontawesome', 'https://use.fontawesome.com/releases/v6.5.1/css/all.css');
        wp_enqueue_script('bootstrap', MEEEKSAAS_PLUGIN_URL . 'vendor/bootstrap/js/bootstrap.bundle.min.js', array('jquery'), '5.3.0', true);
        wp_enqueue_style('owl-carousel', MEEEKSAAS_PLUGIN_URL . 'vendor/owl-carousel/owl.carousel.min.css');
        wp_enqueue_script('owl-carousel', MEEEKSAAS_PLUGIN_URL . 'vendor/owl-carousel/owl.carousel.min.js', array('jquery'), '2.3.4', true);
        wp_enqueue_script('meeeksaas-custom-template-scripts', MEEEKSAAS_PLUGIN_URL . 'assets/custom-template-scripts.js', array('jquery'), '1.0', true);
    }
}
add_action('wp_enqueue_scripts', 'meeeksaas_frontend_enqueue_scripts');


function meeeksaas_enable_customer_upload_capability() {
    $role = get_role( 'customer' );
    if ($role) {
        if ( ! $role->has_cap( 'upload_files' ) ) {
            $role->add_cap( 'upload_files' );
        }
        if ( ! $role->has_cap( 'delete_posts' ) ) {
            $role->add_cap( 'delete_posts' );
        }
        if ( ! $role->has_cap( 'edit_posts' ) ) {
            $role->add_cap( 'edit_posts' );
        }
        if ( ! $role->has_cap( 'publish_posts' ) ) {
            $role->add_cap( 'publish_posts' );
        }
    }
}
add_action( 'init', 'meeeksaas_enable_customer_upload_capability' );


function meeeksaas_restrict_media_library( $query ) {
    if ( ! current_user_can( 'manage_options' ) ) {
        global $pagenow;
        if ( 'upload.php' == $pagenow || 'admin-ajax.php' == $pagenow ) {
            $query->set( 'author', get_current_user_id() );
        }
    }
}
add_action( 'pre_get_posts', 'meeeksaas_restrict_media_library' );

add_action('after_setup_theme', 'meeeksaas_disable_admin_bar');
function meeeksaas_disable_admin_bar() {
    if (!current_user_can('administrator') && !is_admin()) {
        show_admin_bar(false);
    }
}


//Nextend Social Links
if (class_exists('NextendSocialLogin') && !class_exists('NextendSocialLoginPRO')) {
    if (!function_exists('meeeksaas_get_social_btns_form')) {
        function meeeksaas_get_social_btns_form() {
            $options = array(
                'nsl_facebook',
                'nsl_twitter',
                'nsl_google',
            );
            if (get_option('nsl_facebook') || get_option('nsl_twitter') || get_option('nsl_google')) {
                echo do_shortcode('[nextend_social_login]');
            }
        }
        add_action('woocommerce_after_customer_login_form', 'meeeksaas_get_social_btns_form');
    }
}
