<?php
if ( ! defined( 'ABSPATH' ) ) exit; 

class MeeekSaaS_Links_Directory_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'links_directory_widget';
    }

    public function get_title() {
        return __('Meeek SaaS: Creators Directory', 'meeeksaas');
    }

    public function get_icon() {
        return 'eicon-link';
    }

    public function get_categories() {
        return ['custom-widgets'];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __('Settings', 'meeeksaas'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'columns',
            [
                'label' => __('Number of Columns', 'meeeksaas'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '3',
                'options' => [
                    '12' => '1 Column',
                    '6' => '2 Columns',
                    '4' => '3 Columns',
                    '3' => '4 Columns',
                    '2' => '6 Columns',
                ],
                'description' => __('Select the number of columns for the links grid.', 'meeeksaas'),
            ]
        );

        $this->add_control(
            'link_text_color',
            [
                'label' => __('Link Text Color', 'meeeksaas'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#000',  // Default color
                'selectors' => [
                    '{{WRAPPER}} .meeek-link-item-title a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'link_text_color_hover',
            [
                'label' => __('Link Text Color Hover', 'meeeksaas'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#000',  // Default color
                'selectors' => [
                    '{{WRAPPER}} .meeek-link-item-title a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'image_border_radius',
            [
                'label' => __('Image Border Radius', 'meeeksaas'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 50,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 10,
                ],
                'selectors' => [
                    '{{WRAPPER}} .meeek-link-item-img img' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'show_search',
            [
                'label' => __('Show Search Bar', 'meeeksaas'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'meeeksaas'),
                'label_off' => __('Hide', 'meeeksaas'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'search_title',
            [
                'label' => esc_html__( 'Search Title', 'meeeksaas' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Search Links', 'meeeksaas' ),
                'placeholder' => esc_html__( 'Type your title here', 'meeeksaas' ),
                'condition' => [
                    'show_search' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'search_placeholder',
            [
                'label' => esc_html__( 'Search Placeholder', 'meeeksaas' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Search....', 'meeeksaas' ),
                'placeholder' => esc_html__( 'Type your title here', 'meeeksaas' ),
                'condition' => [
                    'show_search' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'input_text_color',
            [
                'label' => __('Input Text Color', 'meeeksaas'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#000',
                'selectors' => [
                    '{{WRAPPER}} .meeeksaas-rest-search input' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'show_search' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'input_bg_color',
            [
                'label' => __('Input Background Color', 'meeeksaas'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#fff',
                'selectors' => [
                    '{{WRAPPER}} .meeeksaas-rest-search input' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'show_search' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'input_hover_bg_color',
            [
                'label' => __('Input Hover Background Color', 'meeeksaas'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#f1f1f1',
                'selectors' => [
                    '{{WRAPPER}} .meeeksaas-rest-search input:hover' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'show_search' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'input_focus_outline_color',
            [
                'label' => __('Input Focus Outline Color', 'meeeksaas'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#0073aa',
                'selectors' => [
                    '{{WRAPPER}} .meeeksaas-rest-search input:focus' => 'box-shadow: 0 0 0 .25rem {{VALUE}} !important;',
                ],
                'condition' => [
                    'show_search' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $column_class = 'col-md-' . esc_attr($settings['columns']); 
        $show_search = $settings['show_search'] === 'yes';
        $search_title = $settings['search_title'];
        $search_placeholder = $settings['search_placeholder'];

        ?>
        <div class="meeeksaas-links-directory container">
            <?php if ($show_search): ?>
            <div class="meeeksaas-rest-search row text-center">
                <h2><?php echo esc_html($search_title); ?></h2>
                <form class="rest-search-form">
                    <input type="text" class="form-control" placeholder="<?php echo esc_attr($search_placeholder); ?>" id="meeek_search_field">
                </form>
            </div>
            <?php endif; ?>

            <div id="link-listed" class="row">
                <?php
                $args = array(
                    'post_type'      => 'meeek-link',
                    'posts_per_page' => -1,
                );
                $query = new WP_Query($args);

                if ($query->have_posts()) :
                    while ($query->have_posts()) : $query->the_post();
                        $configuration = get_post_meta(get_the_ID(), 'meeek_configuration', true);

                        $user_name = !empty($configuration['user_name']) ? $configuration['user_name'] : get_the_title();
                        $photo_id = !empty($configuration['user_photo_id']) ? $configuration['user_photo_id'] : '';
                        $photo_url = !empty($configuration['user_photo_id_url']) ? $configuration['user_photo_id_url'] : '';

                        if ($photo_id) {
                            $about_us_image = wp_get_attachment_image_url($photo_id, 'thumbnail');
                        } elseif($photo_url) {
                            $about_us_image = $photo_url;
                        }else{
                            $about_us_image = '';
                        }

                        $body_bg_image = isset($configuration['body_bg_image']) ? $configuration['body_bg_image'] : '';
                        $body_bg_image_url = isset($configuration['body_bg_image_url']) ? $configuration['body_bg_image_url'] : '';
                        $body_bg_color = isset($configuration['body_bg_color']) ? $configuration['body_bg_color'] : '';

                        // Check for background image URL
                        $bg_image_url = $body_bg_image ? wp_get_attachment_url($body_bg_image) : $body_bg_image_url;

                        $bg_style = '';
                        if ($bg_image_url) {
                            $bg_style = 'background-image: url(' . esc_url($bg_image_url) . ');';
                            if ($body_bg_color) {
                                $bg_style .= ' background-color: ' . esc_attr($body_bg_color) . ';';
                            }
                        } elseif ($body_bg_color) {
                            $bg_style = 'background-color: ' . esc_attr($body_bg_color) . ';';
                        }else{
                            $bg_style = 'background-image: url(' . esc_url(MEEEKSAAS_PLUGIN_URL.'assets/images/placeholder-bg.jpg') . ');';
                        }
                        ?>
                        <div class="meeek-link-item <?php echo esc_attr($column_class); ?>">
                            <div class="meeek-link-item-wrapper" style="<?php echo esc_attr($bg_style); ?>">
                                <?php if($about_us_image){ ?>
                                    <div class="meeek-link-item-img">
                                        <a href="<?php echo esc_url(get_permalink()); ?>">
                                            <img src="<?php echo esc_url($about_us_image); ?>" alt="<?php echo esc_attr($user_name); ?>" />
                                        </a>
                                    </div>
                                <?php } ?>

                                <h5 class="meeek-link-item-title">
                                    <a href="<?php echo esc_url(get_permalink()); ?>">
                                        <?php echo esc_html($user_name); ?>
                                    </a>
                                </h5>
                            </div>
                        </div>
                    <?php
                    endwhile;
                    wp_reset_postdata();
                else :
                    echo esc_html__('No pages found!', 'meeeksaas');
                endif;
                ?>
            </div>
        </div>

        <script>
        jQuery(document).ready(function($) {
            $('#meeek_search_field').on('keyup', function() {
                var value = $(this).val().toLowerCase();

                $('#link-listed').find('.meeek-link-item').each(function() {
                    var $item = $(this);
                    if ($item.find('h5').text().toLowerCase().indexOf(value) === -1) {
                        $item.hide();
                    } else {
                        $item.show();
                    }
                });
            });
        });
        </script>
        <?php
    }
}

