<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

/**
 * Add the new element on the Elements importable modal
 * 
 */
function meeeksaas_youtube_element(){ ?>
  <div class="list-inline col-md-6 mb-4">
    <div class="relative">
      <div class="list-inline-item align-middle">
        <div class="feature-icon bg-youtube">
          <i class="fab fa-youtube"></i>
        </div>
      </div>
      <div class="list-inline-item align-middle">
        <h5 class="mb-0"><?php esc_html_e('YouTube', 'meeeksaas'); ?></h5>
        <p class="m-0"><?php esc_html_e('Embed a YouTube Video', 'meeeksaas'); ?></p>
      </div>
      <div class="list-inline-item align-middle float-end mt-2">
        <?php do_action('meeeksaas_element_add_button', 'youtube'); ?>
      </div>
      <?php do_action('meeeksaas_builder_allow_youtube'); ?>
    </div>
  </div><?php
}


/**
 * Map the new element on the import accepted elements array
 * 
 * @param $all_elements: array containing all the default elements
 */
function meeeksaas_add_youtube_el_to_els($all_elements){
  array_push($all_elements, 'youtube');
  
  return $all_elements;
}

/**
 * Map the new element on the import accepted elements array
 * 
 * @param $all_elements: array containing all the default elements
 */
function meeeksaas_add_youtube_builder_fields($meeek_configuration){
  
    $item = $meeek_configuration;
    if ($item['btn_type'] == 'youtube') {
        $title = ((array_key_exists('title', $item))?$item['title']:esc_html__('Button Text', 'meeeksaas'));
        $title_color = ((array_key_exists('title_color', $item))?$item['title_color']:"#000000");
        $title_alignment = ((array_key_exists('title_alignment', $item))?$item['title_alignment']:"left");
        $link = ((array_key_exists('link', $item))?$item['link']:'');
        $toggle_status = ((array_key_exists('toggle_status', $item))?$item['toggle_status'][0]:"off");
        
        echo meeeksaas_input('text', 'title', $title, esc_html__('Title', 'meeeksaas'), 'meeeksaas_title', true);
        echo meeeksaas_colorpicker('title_color', $title_color, esc_html__('Title Color', 'meeeksaas'), 'title_color');
        echo meeeksaas_alignment_group('title_alignment', $title_alignment, esc_html__('Title Alignment', 'meeeksaas'));
        echo meeeksaas_input('url', 'link', $link, esc_html__('Video Link', 'meeeksaas'), 'meeeksaas_link', true);
        echo meeeksaas_checkbox('toggle_status', 'toggle_status', esc_html__('Video Outside Toggle', 'meeeksaas'), $toggle_status);
    }
}



function meeeksaas_youtube_frontend($type = '', $item = array()){

    if($type == 'youtube'){
      $title = ((array_key_exists('bio_links_description', $item))?$item['bio_links_description']:esc_html__('Button Text', 'meeeksaas'));
      $link = ((array_key_exists('link', $item['vcard']))?$item['vcard']['link']:'');
      $toggle_status = ((array_key_exists('toggle_status', $item['vcard']))?$item['vcard']['toggle_status'][0]:"off");
      $title_color = ((array_key_exists('title_color', $item['vcard']))?$item['vcard']['title_color']:"#000000");
      $title_alignment = ((array_key_exists('title_alignment', $item['vcard']))?$item['vcard']['title_alignment']:"left");

      if ($link) {
        $video = preg_match("/^(?:http(?:s)?:\/\/)?(?:www\.)?(?:m\.)?(?:youtu\.be\/|youtube\.com\/(?:(?:watch)?\?(?:.*&)?v(?:i)?=|(?:embed|v|vi|user|shorts)\/))([^\?&\"'>]+)/", $link, $matches);
        if ($video) {
          $id = $matches[1];
        }
      }else{
        $id = 'Zv11L-ZfrSg';
      }
    ?>
    <?php if($toggle_status == 'on'){ ?>
        <div class="meeek-toggle-off-holder">
            <h3 style="color: <?php echo esc_attr($title_color); ?>;" class="text-<?php echo esc_attr($title_alignment); ?>"><?php echo esc_html($title); ?></h3>
            <div class="embed-responsive embed-responsive-16by9 meeek-iframe-outside">
                <iframe class="embed-responsive-item" src="https://www.youtube.com/embed/<?php echo esc_attr($id); ?>?rel=0" allowfullscreen></iframe>
            </div>
        </div>
    <?php }else{ ?>
        <div class="meeek-bio-links-inner-dropdown meeek-accordion-card meeek-accordion-youtube  mb-3">
            <div class="meeek-accordion-card-inner">
                <div class="meeek-accordion-title" data-accordion-element-trigger>
                    <?php echo esc_html($title); ?>
                </div>
                <div data-accordion-element-content class="meeek-accordion-content">
                    <div class="embed-responsive embed-responsive-16by9">
                        <iframe class="embed-responsive-item" src="https://www.youtube.com/embed/<?php echo esc_attr($id); ?>?rel=0" allowfullscreen></iframe>
                    </div>
                </div>
            </div>
        </div>
    <?php } 
    }
}


// check if the el is restricted
if(!meeeksaas_is_element_restricted('youtube')){
    // add the element on the elements modal
    add_action('meeeksaas_before_elements_list', 'meeeksaas_youtube_element');
    // add the element on the elements list for plans
    add_filter('meeeksaas_available_elements', 'meeeksaas_add_youtube_el_to_els');
    // add the element fields on builder
    add_action('meeeksaas_builder_element_fields', 'meeeksaas_add_youtube_builder_fields');
    // frontend
    add_action('meeeksaas_bio_item_bottom', 'meeeksaas_youtube_frontend', 10, 4);
}