<?php 
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}



/**
* Function to generate custom dynamic CSS on the frontend template
*
*/
if (!function_exists('meeeksaas_dynamic_css')) {
    function meeeksaas_dynamic_css(){

        $css = '';
        if (is_singular('meeek-link')) {
            
            wp_enqueue_style('meeek-custom', MEEEKSAAS_PLUGIN_URL . 'assets/custom-style.css');

            $configuration = get_post_meta( get_the_ID(), 'meeek_configuration', true );
            $settings = get_option('mt-saas-settings');

            if ($configuration) {
                $photo_id = ((array_key_exists('body_bg_image', $configuration))?$configuration['body_bg_image']:"");
                $photo_url = ((array_key_exists('body_bg_image_url', $configuration))?$configuration['body_bg_image_url']:"");
                $attachment_url = wp_get_attachment_url($photo_id); 
                $body_bg_color = ((array_key_exists('body_bg_color', $configuration))?$configuration['body_bg_color']:"");
                $pagename_font = ((array_key_exists('style_pagename_font', $configuration))?$configuration['style_pagename_font']:"");
                $headings_font = ((array_key_exists('style_headings_font', $configuration))?$configuration['style_headings_font']:"");
                $links_font = ((array_key_exists('style_links_font', $configuration))?$configuration['style_links_font']:"");
                $content_font = ((array_key_exists('style_content_font', $configuration))?$configuration['style_content_font']:"");

                if ($attachment_url) {
                    $css_bg_img = 'background-image: url('.esc_url($attachment_url).');';
                    $css_bg_color = '';
                }elseif ($photo_url) {
                    $css_bg_img = 'background-image: url('.esc_url($photo_url).');';
                    $css_bg_color = '';
                }else{
                    $css_bg_img = '';
                    $css_bg_color = 'background-color: '.esc_attr($body_bg_color).' !important;';
                }

                if (isset($_GET['scroll']) && $_GET['scroll'] == 'off') {
                    $css .= 'html::-webkit-scrollbar {
                        display: none;
                    }';
                }

                $attachment_url = '';
                if ($css_bg_img || $css_bg_color) {
                    $css .= 'body .meeek-bio-links-page{
                                '.$css_bg_img.'
                                '.$css_bg_color.'
                                background-size: cover;
                                background-position: center;
                                background-repeat: no-repeat;
                                background-attachment: fixed;
                                min-height: 100vh;
                            }';
                }
                $css .= '.meeek-bio-links-page-inner {
                            padding: '.esc_attr($configuration['container_tb_space']).'px 0;
                            width: '.esc_attr($configuration['container_width']).'px;
                            margin: 0 auto;
                        }';
                if ($settings) {
                    $logo_width = ((array_key_exists('meeeksaas_logo_width', $settings))?$settings['meeeksaas_logo_width']:"80");
                    $css .= '.meeek-bio-footer img,
                            .meeeksaas-splash-screen-loader .meeeksaas-preloader-image {
                                max-width: '.esc_attr($logo_width).'px;
                            }
                            body .meeeksaas-splash-screen-loader .meeeksaas-preloader-image {
                                left: calc(50% - '.esc_attr(intval($logo_width)/2).'px);
                            }';
                    
                    // Settings panel Custom CSS
                    $meeeksaas_css = ((array_key_exists('meeeksaas_css', $settings))?$settings['meeeksaas_css']:"");
                    $css .= $meeeksaas_css;

                    // Splash Screen
                    $splashscreen_bg = ((array_key_exists('meeeksaas_splashscreen_bg', $settings))?$settings['meeeksaas_splashscreen_bg']:"#dddddd");
                    $css .= 'body .meeeksaas-splash-screen-loader {
                                background: '.esc_attr($splashscreen_bg).';
                            }';

                }

                // FONTS
                $fonts = meeeksaas_googlefonts();
                $all_fonts = array();
                if (!empty($pagename_font) && $pagename_font != 'select') {
                    $css .= '.meeek-about-me-title {
                            font-family: '.esc_attr($fonts[$pagename_font]).';
                        }';
                    array_push($all_fonts, $pagename_font);
                }
                if (!empty($headings_font) && $headings_font != 'select') {
                    $css .= '.meeek-bio-links-inner-header-text {
                            font-family: '.esc_attr($fonts[$headings_font]).';
                        }';
                    array_push($all_fonts, $headings_font);
                }
                if (!empty($links_font) && $links_font != 'select') {
                    $css .= '.meeek-bio-links-description, .meeek-bio-links-paypal, .meeek-bio-links-venmo, .meeek-bio-links-phone, .meeek-accordion-title {
                            font-family: '.esc_attr($fonts[$links_font]).';
                        }';
                    array_push($all_fonts, $links_font);
                }
                if (!empty($content_font) && $content_font != 'select') {
                    $css .= '.meeek-about-me-description, p, .meeek-bio-links-inner-content{
                            font-family: '.esc_attr($fonts[$content_font]).';
                        }';
                    array_push($all_fonts, $content_font);
                }

                $fonts_string = '';
                if ($pagename_font || $headings_font || $links_font || $content_font) {
                    $i = 0;
                    $len = count($all_fonts);
                    foreach($all_fonts as $font){
                        if ($i == $len - 1) {
                            // last
                            $fonts_string .= $font;
                        }else{
                            $fonts_string .= $font . '|';
                        }
                        $i++;
                    }
                }
                // fonts url
                if ($settings) {
                    $meeeksaas_gfonts = ((array_key_exists('meeeksaas_gfonts', $settings))?$settings['meeeksaas_gfonts']:"off");
                    if ($meeeksaas_gfonts == 'on') {
                        // $css .= '.meeek-about-me-description, p, .meeek-bio-links-inner-content{
                        //         font-family: '.esc_attr($fonts[$content_font]).';
                        //     }';
                    }else{
                        if (!empty($fonts_string)) {
                            $fonts_url = add_query_arg( 'family', $fonts_string, "//fonts.googleapis.com/css" );
                            // enqueue fonts
                            wp_enqueue_style( 'meeeksaas-custom-fonts', $fonts_url, array(), '1.0.0' );
                        }
                    }
                }

            }

            // enqueue inline style
            wp_add_inline_style( 'meeek-custom', meeeksaas_minify_css($css) );
        }
    }
    add_action('wp_enqueue_scripts', 'meeeksaas_dynamic_css' );
}





function meeeksaas_frontend_sharing_panel(){

    $settings = get_option('mt-saas-settings');
    if ($settings) {
        $meeeksaas_sharing = ((array_key_exists('meeeksaas_sharing', $settings))?$settings['meeeksaas_sharing']:"off");
        if ($meeeksaas_sharing != 'on') {
            return;
        }
    }
    ?>
        <div class="meeeksaas-share-panel">
            <div id="meeeksaas-links-panel">
                <div id="meeeksaas-panel">
                    <?php
                    // Get current page URL
                    $url = esc_url(get_permalink());
                    // Get current page title
                    $title = str_replace( ' ', '%20', get_the_title());
                    // Get Post Thumbnail for pinterest
                    $thumbnail = '';
                    $thumbnail_url = '';
                    if(!empty($thumbnail)) {
                        $thumbnail_url = $thumbnail;
                    }
                    // Construct sharing URLs
                    $twitter_url = 'https://twitter.com/intent/tweet?text='.esc_html($title).'&amp;url='.esc_url($url).'&amp;via='.esc_attr(get_bloginfo( 'name' ));
                    $facebook_url = 'https://www.facebook.com/sharer/sharer.php?u='.esc_url($url);
                    $whatsapp_url = 'https://api.whatsapp.com/send?text='.esc_html($title) . ' ' . esc_url($url);
                    $linkedin_url = 'https://www.linkedin.com/shareArticle?mini=true&url='.esc_url($url).'&amp;title='.esc_html($title);
                    if(!empty($thumbnail)) {
                        $pinterest_url = 'https://pinterest.com/pin/create/button/?url='.esc_url($url).'&amp;media='.esc_url($thumbnail_url).'&amp;description='.esc_html($title);
                    }else {
                        $pinterest_url = 'https://pinterest.com/pin/create/button/?url='.esc_url($url).'&amp;description='.esc_html($title);
                    }
                    $email_url = 'mailto:?subject='.esc_html($title).'&amp;body='.esc_url($url);
                    $telegram_url = 'https://telegram.me/share/url?url=<'.esc_url($url).'>&text=<'.esc_html($title).'>';
                    ?>
                    <h3><?php esc_html_e('Share this link', 'meeeksaas'); ?></h3>
                    <div class="meeeksaas-social-box">
                        <a class="meeeksaas-social-btn meeeksaas-social-twitter" href="<?php echo  esc_url($twitter_url) ; ?>" target="_blank" rel="nofollow">
                            <span><i class="fa-brands fa-x-twitter"></i><?php esc_html_e('Share on X', 'meeeksaas'); ?></span>
                            <i class="fas fa-share"></i>
                        </a>
                        <a class="meeeksaas-social-btn meeeksaas-social-facebook" href="<?php echo esc_url($facebook_url); ?>" target="_blank" rel="nofollow">
                            <span><i class="fab fa-facebook"></i><?php esc_html_e('Share on Facebook', 'meeeksaas'); ?></span>
                            <i class="fas fa-share"></i>
                        </a>
                        <a class="meeeksaas-social-btn meeeksaas-social-whatsapp" href="<?php echo esc_url($whatsapp_url); ?>" target="_blank" rel="nofollow">
                            <span><i class="fab fa-whatsapp"></i><?php esc_html_e('Share on Whatsapp', 'meeeksaas'); ?></span>
                            <i class="fas fa-share"></i>
                        </a>
                        <a class="meeeksaas-social-btn meeeksaas-social-pinterest" href="<?php echo esc_url($pinterest_url); ?>" data-pin-custom="true" target="_blank" rel="nofollow">
                            <span><i class="fab fa-pinterest"></i><?php esc_html_e('Share on Pinterest', 'meeeksaas'); ?></span>
                            <i class="fas fa-share"></i>
                        </a>
                        <a class="meeeksaas-social-btn meeeksaas-social-linkedin" href="<?php echo esc_url($linkedin_url); ?>" target="_blank" rel="nofollow">
                            <span><i class="fab fa-linkedin-in"></i><?php esc_html_e('Share on Linkedin', 'meeeksaas'); ?></span>
                            <i class="fas fa-share"></i>
                        </a>
                        <a class="meeeksaas-social-btn meeeksaas-social-telegram" href="<?php echo esc_url($telegram_url); ?>" target="_blank" rel="nofollow">
                            <span><i class="fab fa-telegram-plane"></i><?php esc_html_e('Share on Telegram', 'meeeksaas'); ?></span>
                            <i class="fas fa-share"></i>
                        </a>
                        <a class="meeeksaas-social-btn meeeksaas-social-email" href="<?php echo esc_url($email_url); ?>" target="_blank" rel="nofollow">
                            <span><i class="fas fa-envelope"></i><?php esc_html_e('Share on Email', 'meeeksaas'); ?></span>
                            <i class="fas fa-share"></i>
                        </a>
                    </div>
                    <h3><?php esc_html_e('QR Code', 'meeeksaas'); ?></h3>
                    <div class="meeeksaas-qr-code text-center">
                        <?php do_action('meeeksaas_sharing_panel_qr', get_the_ID(), '200x200'); ?>
                    </div>
                </div>
                <div style="display: block; right: 0px;" class="meeeksaas-panel_button">
                    <a href="#" class="meeeksaas-toggle_sidebar">
                        <i class="fas fa-share-alt"></i>
                        <span><?php esc_html_e('Share', 'meeeksaas'); ?></span>
                    </a>
                    <div class="clearfix"></div>
                </div>
                <div style="display: none; right: 0px;" class="meeeksaas-panel_button meeeksaas_hide_button">
                    <i class="fas fa-times"></i>
                    <span><?php esc_html_e('Close', 'meeeksaas'); ?></span>
                </div>
            </div>
        </div>

    <?php 
}
add_action('meeeksaas_page_header', 'meeeksaas_frontend_sharing_panel');


/**
* Add Template Splash Screen (loading)
*
*/
function meeeksaas_frontend_splash_screen_loader(){

    $configuration = get_post_meta( get_the_ID(), 'meeek_configuration', true );
    
    if ($configuration) {
        $brand_logo_status = ((array_key_exists('brand_logo_status', $configuration))?$configuration['brand_logo_status']:"off");
        $brand_logo = MEEEKSAAS_LOGO_DARK_PATH;
        $settings = get_option('mt-saas-settings');
        if($settings){
            $splashscreen_status = ((array_key_exists('meeeksaas_splashscreen_status', $settings))?$settings['meeeksaas_splashscreen_status']:"off");
            $splashscreen_logo = ((array_key_exists('meeeksaas_splashscreen_logo', $settings))?$settings['meeeksaas_splashscreen_logo']:"dark");
            if ($splashscreen_status == 'on') {
                if ($splashscreen_logo == 'dark') {
                    // dark logo
                    $whitelabel_logo_dark_id = ((array_key_exists('meeeksaas_whitelabel_logo_dark_id', $settings))?$settings['meeeksaas_whitelabel_logo_dark_id']:"");
                    if (!empty($whitelabel_logo_dark_id)) {
                        $brand_logo = wp_get_attachment_url($whitelabel_logo_dark_id);
                    }
                }else{
                    // light logo
                    $whitelabel_logo_light_id = ((array_key_exists('meeeksaas_whitelabel_logo_id', $settings))?$settings['meeeksaas_whitelabel_logo_id']:"");
                    if (!empty($whitelabel_logo_dark_id)) {
                        $brand_logo = wp_get_attachment_url($whitelabel_logo_light_id);
                    }  
                }
            }
        }
        if(isset($splashscreen_status) && $splashscreen_status == 'on'){ ?>
            <div class="meeeksaas-splash-screen-loader">
                <img class="meeeksaas-preloader-image" src="<?php echo esc_url($brand_logo); ?>" alt="<?php echo get_bloginfo(); ?>" />
            </div>
        <?php }
    }
}
add_action('meeeksaas_page_header', 'meeeksaas_frontend_splash_screen_loader');


/**
* Edit as Admin link
*
*/
function meeeksaas_frontend_edit_as_admin(){
    $current_user = wp_get_current_user();
    if (user_can( $current_user, 'administrator' )) { ?>
        <a target="_blank" class="meeeksaas-edit-as-admin" href="<?php echo esc_url(admin_url('admin.php?page=meeek-page-builder&links_page='.get_the_ID().'&action=edit&tab=links')); ?>" alt="<?php echo get_the_title(); ?>"><i class="far fa-edit"></i> <?php esc_html_e('Edit Page', 'meeeksaas'); ?></a>
    <?php 
    }
}
add_action('meeeksaas_page_header', 'meeeksaas_frontend_edit_as_admin');



/**
* Add Template footer branding
*
*/
function meeeksaas_footer_branding(){
    $configuration = get_post_meta( get_the_ID(), 'meeek_configuration', true );
    
    if ($configuration) {
        $brand_logo_status = ((array_key_exists('brand_logo_status', $configuration))?$configuration['brand_logo_status']:"");
        $brand_logo = MEEEKSAAS_LOGO_DARK_PATH;
        $settings = get_option('mt-saas-settings');
        if($settings){
            $whitelabel_logo_dark_id = ((array_key_exists('meeeksaas_whitelabel_logo_dark_id', $settings))?$settings['meeeksaas_whitelabel_logo_dark_id']:"");
            if (!empty($whitelabel_logo_dark_id)) {
                $brand_logo = wp_get_attachment_url($whitelabel_logo_dark_id);
            }
        }

        if(isset($brand_logo_status) && $brand_logo_status == 'on'){ ?>
            <div class="meeek-bio-footer">
                <a href="<?php echo esc_url(home_url()); ?>">
                    <img src="<?php echo esc_url($brand_logo); ?>" alt="<?php echo get_bloginfo(); ?>" width="150" />
                </a>
            </div>
        <?php }
    }
}
add_action('meeeksaas_page_footer', 'meeeksaas_footer_branding');



// meeeksaas_logo_icon
/**
* Add Template footer branding
*
*/
function meeeksaas_usernav_branding(){
    $configuration = get_post_meta( get_the_ID(), 'meeek_configuration', true );
    
    $brand_logo = MEEEKSAAS_LOGO_DARK_PATH;
    $settings = get_option('mt-saas-settings');
    if($settings){
        $meeeksaas_logo_icon = ((array_key_exists('meeeksaas_logo_icon_id', $settings))?$settings['meeeksaas_logo_icon_id']:"");
        if (!empty($meeeksaas_logo_icon)) {
            $brand_logo = wp_get_attachment_url($meeeksaas_logo_icon);
        }
    }
    ?>
        <li class="meeeksaas-brand-icon">
            <a href="<?php echo esc_url(home_url()); ?>">
                <img src="<?php echo esc_url($brand_logo); ?>" alt="<?php echo get_bloginfo(); ?>" width="150" />
            </a>
        </li>
    <?php 
}
add_action('meeeksaas_before_user_nav_menu_items', 'meeeksaas_usernav_branding');


function meeeksaas_frontend_user_analytics($post_id = ''){
    $meeek_configuration = get_post_meta( $post_id, 'meeek_configuration', true );
    if ($meeek_configuration) {
        // G-C72LZJDWNP
        $ga_tag_id = ((array_key_exists('ga_tag_id', $meeek_configuration))?$meeek_configuration['ga_tag_id']:"");
        if (empty($ga_tag_id)) {
            return;
        }else{
            ?>
            <!-- Google tag (gtag.js) -->
            <script async src="https://www.googletagmanager.com/gtag/js?id=<?php echo esc_attr($ga_tag_id); ?>"></script>
            <script>
                window.dataLayer = window.dataLayer || [];
                function gtag(){dataLayer.push(arguments);}
                gtag('js', new Date());

                gtag('config', '<?php echo esc_attr($ga_tag_id); ?>');
            </script>
            <?php 
        }
    }
}
add_action('meeeksaas_before_head_metas', 'meeeksaas_frontend_user_analytics', 1);


require_once('my-account.stats.php');



add_filter('woocommerce_account_menu_items', 'meeek_remove_account_tabs', 999);
function meeek_remove_account_tabs($items) {
    // List of tabs to remove. Uncomment or add the tabs you want to disable.
    // unset($items['dashboard']);        // Remove Dashboard tab
    // unset($items['orders']);           // Remove Orders tab
    unset($items['downloads']);        // Remove Downloads tab
    unset($items['payment-methods']);        // Remove Downloads tab
    // unset($items['edit-address']);     // Remove Addresses tab
    // unset($items['payment-methods']);  // Remove Payment Methods tab
    // unset($items['edit-account']);     // Remove Account Details tab
    // unset($items['customer-logout']);  // Remove Logout tab
    
    return $items;
}



add_action('woocommerce_thankyou', 'meeek_auto_complete_woocommerce_order');
function meeek_auto_complete_woocommerce_order($order_id) {
    if (!$order_id) {
        return;
    }
    
    $order = wc_get_order($order_id);
    
    // Only change the status to 'completed' if the order is not already 'completed'
    if ($order->get_status() !== 'completed') {
        $order->update_status('completed');
    }
}
