<?php 
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

// Function to get total posts by the current logged-in user ID for a specific post type
function meeeksaas_get_total_posts_by_current_user() {
    // Get the current logged-in user's ID
    $current_user_id = get_current_user_id();

    // Check if a user is logged in
    if ($current_user_id == 0) {
        return 0; // No user is logged in, return 0
    }

    $args = array(
        'author' => $current_user_id,
        'post_type' => 'meeek-link',
        'post_status' => 'publish', // you can add other statuses if needed
        'posts_per_page' => -1 // get all posts
    );

    $query = new WP_Query($args);

    $total_posts = $query->found_posts;

    // Always use wp_reset_postdata() after a custom query
    wp_reset_postdata();

    return $total_posts;
}


function get_total_views_by_current_user($post_type = 'meeek-link') {
    global $wpdb;

    // Get the current logged-in user's ID
    $current_user_id = get_current_user_id();

    // Check if a user is logged in
    if ($current_user_id == 0) {
        return 0; // No user is logged in, return 0
    }

    // Query to get all post IDs of the given post type by the current user
    $args = array(
        'author' => $current_user_id,
        'post_type' => $post_type,
        'post_status' => 'publish', // you can add other statuses if needed
        'fields' => 'ids', // return only post IDs
        'posts_per_page' => -1 // get all posts
    );

    $posts = get_posts($args);

    if (empty($posts)) {
        return 0; // No posts found for the user, return 0
    }

    // Get the total views for these post IDs from the wp_meeeksaas_page_views table
    $post_ids = implode(',', $posts);
    $table_name = $wpdb->prefix . 'meeeksaas_page_views';
    $query = $wpdb->prepare(
        "SELECT SUM(views_count) FROM %i WHERE page_id IN ($post_ids)",
        $table_name,
    );

    // Fetch result
    $result = $wpdb->get_var($query);

    if (empty($result)) {
        return 0; // No posts found for the user, return 0
    }

    return $result;
}



/**
* WooCommerce accounts: My Dashboard quicklinks
*/
if (!function_exists('meeeksaas_my_account_quicklinks')) {
    function meeeksaas_my_account_quicklinks() {
        $url_builder = wc_get_account_endpoint_url('bio-link-builder');
        $url_links = wc_get_account_endpoint_url('my-link-pages');
        $url_plan = wc_get_account_endpoint_url('pricing-plan');
        $url_payments = wc_get_account_endpoint_url('orders');
        ?>

        <h3><strong><?php esc_html_e('Quick Links', 'meeeksaas'); ?></strong></h3>
        <div class="row">
            <div class="col-md-3 col-6">
                <div class="meeek-inner-quick-link relative">
                    <i class="fas fa-drafting-compass"></i>
                    <a href="<?php echo esc_url($url_builder); ?>"><?php esc_html_e('Create Bio Links Page', 'meeeksaas'); ?></a>
                </div>
            </div>
            <div class="col-md-3 col-6">
                <div class="meeek-inner-quick-link relative">
                    <i class="fas fa-link fa-fw"></i>
                    <a href="<?php echo esc_url($url_links); ?>"><?php esc_html_e('My Bio Links', 'meeeksaas'); ?></a>
                </div>
            </div>
            <div class="col-md-3 col-6">
                <div class="meeek-inner-quick-link relative">
                    <i class="fas fa-sticky-note fa-fw"></i>
                    <a href="<?php echo esc_url($url_plan); ?>"><?php esc_html_e('My Pricing Plan', 'meeeksaas'); ?></a>
                </div>
            </div>
            <div class="col-md-3 col-6">
                <div class="meeek-inner-quick-link relative">
                    <i class="fas fa-shopping-cart fa-fw"></i>
                    <a href="<?php echo esc_url($url_payments); ?>"><?php esc_html_e('My Payments', 'meeeksaas'); ?></a>
                </div>
            </div>
            <?php do_action('meeeksaas_after_account_quick_links'); ?>
        </div>

        <?php
    }
    add_action( 'woocommerce_account_dashboard', 'meeeksaas_my_account_quicklinks' );
    add_action( 'woocommerce_thankyou', 'meeeksaas_my_account_quicklinks', 1 );
}


/**
* WooCommerce accounts: My Dashboard quicklinks
*/
function meeeksaas_my_account_stats() {
    $pages = meeeksaas_get_total_posts_by_current_user();
    $total_views = get_total_views_by_current_user();
    $url_links = wc_get_account_endpoint_url('my-link-pages');
    $url_plan = wc_get_account_endpoint_url('pricing-plan');
    $all_benefits = meeeksaas_all_benefits();
    $my_benefits = meeeksaas_user_benefits();
    ?>

    <h3><strong><?php esc_html_e('Statistics', 'meeeksaas'); ?></strong></h3>
    <div class="row">
        <div class="col-md-4 col-6">
            <div class="meeek-inner-quick-stats relative">
                <span><?php echo esc_html($pages); ?></span>
                <a href="<?php echo esc_url($url_links); ?>"><?php esc_html_e('Link-in-Bio Pages', 'meeeksaas'); ?></a>
            </div>
        </div>
        <div class="col-md-4 col-6">
            <div class="meeek-inner-quick-stats relative">
                <span><?php echo esc_html($total_views); ?></span>
                <a href="#"><?php esc_html_e('Total Pageviews', 'meeeksaas'); ?></a>
            </div>
        </div>
        <?php do_action('meeeksaas_after_account_quick_stats'); ?>
    </div>

    <?php
}
add_action( 'woocommerce_account_dashboard', 'meeeksaas_my_account_stats' );

/**
* WooCommerce accounts: My Dashboard quicklinks
*/
function meeeksaas_my_account_stats_benefits() {
    $url_plan = wc_get_account_endpoint_url('pricing-plan');
    $all_benefits = meeeksaas_all_benefits();
    $my_benefits = meeeksaas_user_benefits();
    ?>

    <div class="col-md-4 col-sm-6 col-xs-6">
        <div class="meeek-inner-quick-stats relative">
            <span><?php echo count($my_benefits); ?>/<?php echo count($all_benefits); ?></span>
            <a href="<?php echo esc_url($url_plan); ?>"><?php esc_html_e('Account Benefits', 'meeeksaas'); ?></a>
        </div>
    </div>

    <?php
}
add_action( 'meeeksaas_after_account_quick_stats', 'meeeksaas_my_account_stats_benefits' );



